@@ -1,29 +1,31 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import print_function, unicode_literals, with_statement
 
 import argparse
 import atexit
 import gettext
-import io
 import os
 import site
+import subprocess
 import sys
 import threading
 import time
@@ -36,8 +38,9 @@ MAIN_DIR = os.path.abspath(os.path.realpath(os.path.expanduser(os.path.dirname(o
 PROG_DIR = os.path.abspath(os.path.realpath(os.path.expanduser(os.path.dirname(__file__))))
 LOCALE_DIR = os.path.join(PROG_DIR, 'locale')
 LIBS_DIR = os.path.join(PROG_DIR, 'libs')
+VERSION_FILE = os.path.join(PROG_DIR, 'version.txt')
+CHANGELOG_FILE = os.path.join(MAIN_DIR, 'CHANGELOG.md')
 REQS_FILE = os.path.join(MAIN_DIR, 'requirements.txt')
-CHANGELOG_FILE = os.path.join(MAIN_DIR, 'changelog.md')
 
 
 class Daemon(object):
@@ -64,7 +67,7 @@ class Daemon(object):
             if pid > 0:
                 # exit first parent
                 os._exit(0)
-        except OSError, e:
+        except OSError as e:
             sys.stderr.write("fork #1 failed: %d (%s)\n" % (e.errno, e.strerror))
             sys.exit(1)
 
@@ -77,7 +80,7 @@ class Daemon(object):
             if pid > 0:
                 # exit from second parent
                 os._exit(0)
-        except OSError, e:
+        except OSError as e:
             sys.stderr.write("fork #2 failed: %d (%s)\n" % (e.errno, e.strerror))
             sys.exit(1)
 
@@ -87,9 +90,9 @@ class Daemon(object):
         sys.stderr = sys.__stderr__
         sys.stdout.flush()
         sys.stderr.flush()
-        si = file(self.stdin, 'r')
-        so = file(self.stdout, 'a+')
-        se = file(self.stderr, 'a+', 0)
+        si = open(self.stdin, 'r')
+        so = open(self.stdout, 'a+')
+        se = open(self.stderr, 'a+')
         os.dup2(si.fileno(), sys.stdin.fileno())
         os.dup2(so.fileno(), sys.stdout.fileno())
         os.dup2(se.fileno(), sys.stderr.fileno())
@@ -97,7 +100,7 @@ class Daemon(object):
         # write pidfile
         atexit.register(self.delpid)
         self.pid = os.getpid()
-        file(self.pidfile, 'w+').write("%s\n" % self.pid)
+        open(self.pidfile, 'w+').write("%s\n" % self.pid)
 
     def delpid(self):
         if os.path.exists(self.pidfile):
@@ -109,7 +112,7 @@ class Daemon(object):
         """
         # Check for a pidfile to see if the daemon already runs
         try:
-            pf = file(self.pidfile, 'r')
+            pf = open(self.pidfile, 'r')
             pid = int(pf.read().strip())
             pf.close()
         except IOError:
@@ -130,7 +133,7 @@ class Daemon(object):
 
         # Get the pid from the pidfile
         try:
-            pf = file(self.pidfile, 'r')
+            pf = open(self.pidfile, 'r')
             pid = int(pf.read().strip())
             pf.close()
         except IOError:
@@ -146,7 +149,7 @@ class Daemon(object):
             while 1:
                 os.kill(pid, SIGTERM)
                 time.sleep(0.1)
-        except OSError, err:
+        except OSError as err:
             err = str(err)
             if err.find("No such process") > 0:
                 self.delpid()
@@ -167,9 +170,9 @@ def isVirtualEnv():
 
 
 def check_requirements():
-    # sickrage requires python 2.7.8+
-    if sys.version_info < (2, 7, 8):
-        sys.exit("Sorry, SiCKRAGE requires Python 2.7.8+")
+    # sickrage requires python 3.5+
+    if sys.version_info < (3, 5, 0):
+        sys.exit("Sorry, SiCKRAGE requires Python 3.5+")
 
     try:
         import OpenSSL
@@ -180,20 +183,20 @@ def check_requirements():
         if not v >= v_needed:
             print('OpenSSL installed but {} is needed while {} is installed. '
                   'Run `pip install -U pyopenssl`'.format(v_needed, v))
-    except:
+    except ImportError:
         print('OpenSSL not available, please install for better requests validation: '
               '`https://pyopenssl.readthedocs.org/en/latest/install.html`')
 
 
 def version():
     # Get the version number
-    with io.open(os.path.abspath(os.path.join(os.path.dirname(__file__), 'version.txt'))) as f:
+    with open(VERSION_FILE) as f:
         return f.read()
 
 
 def changelog():
     # Get the version number
-    with io.open(CHANGELOG_FILE) as f:
+    with open(CHANGELOG_FILE) as f:
         return f.read()
 
 
@@ -213,10 +216,15 @@ def main():
         sys.path.extend(remainder)
 
     # set system default language
-    gettext.install('messages', LOCALE_DIR, unicode=1, codeset='UTF-8', names=["ngettext"])
+    gettext.install('messages', LOCALE_DIR, codeset='UTF-8', names=["ngettext"])
 
     try:
-        from sickrage.core import Core
+        try:
+            from sickrage.core import Core
+        except ImportError:
+            print('Attempting to install SiCKRAGE missing requirements using pip')
+            subprocess.check_call([sys.executable, "-m", "pip", "install", "--no-cache-dir", "-r", REQS_FILE])
+            from sickrage.core import Core
 
         # main app instance
         app = Core()
@@ -229,13 +237,16 @@ def main():
         parser.add_argument('-d', '--daemon',
                             action='store_true',
                             help='Run as a daemon (*NIX ONLY)')
-        parser.add_argument('-q', '--quite',
+        parser.add_argument('-q', '--quiet',
                             action='store_true',
                             help='Disables logging to CONSOLE')
         parser.add_argument('-p', '--port',
                             default=0,
                             type=int,
                             help='Override default/configured port to listen on')
+        parser.add_argument('-H', '--host',
+                            default='',
+                            help='Override default/configured host to listen on')
         parser.add_argument('--dev',
                             action='store_true',
                             help='Enable developer mode')
@@ -254,13 +265,46 @@ def main():
         parser.add_argument('--nolaunch',
                             action='store_true',
                             help='Suppress launching web browser on startup')
+        parser.add_argument('--disable_updates',
+                            action='store_true',
+                            help='Disable application updates')
+        parser.add_argument('--web_root',
+                            default='',
+                            help='Overrides URL web root')
+        parser.add_argument('--db_type',
+                            default='sqlite',
+                            help='Database type: sqlite or mysql')
+        parser.add_argument('--db_prefix',
+                            default='sickrage',
+                            help='Database prefix you want prepended to database table names')
+        parser.add_argument('--db_host',
+                            default='localhost',
+                            help='Database hostname (not used for sqlite)')
+        parser.add_argument('--db_port',
+                            default='3306',
+                            help='Database port number (not used for sqlite)')
+        parser.add_argument('--db_username',
+                            default='sickrage',
+                            help='Database username (not used for sqlite)')
+        parser.add_argument('--db_password',
+                            default='sickrage',
+                            help='Database password (not used for sqlite)')
 
         # Parse startup args
         args = parser.parse_args()
-        app.quite = args.quite
+        app.quiet = args.quiet
         app.web_port = int(args.port)
+        app.web_host = args.host
+        app.web_root = args.web_root.lstrip('/').rstrip('/')
         app.no_launch = args.nolaunch
+        app.disable_updates = args.disable_updates
         app.developer = args.dev
+        app.db_type = args.db_type
+        app.db_prefix = args.db_prefix
+        app.db_host = args.db_host
+        app.db_port = args.db_port
+        app.db_username = args.db_username
+        app.db_password = args.db_password
         app.debug = args.debug
         app.data_dir = os.path.abspath(os.path.realpath(os.path.expanduser(args.datadir)))
         app.cache_dir = os.path.abspath(os.path.realpath(os.path.join(app.data_dir, 'cache')))
@@ -308,7 +352,7 @@ def main():
         # daemonize if requested
         if daemonize:
             app.no_launch = True
-            app.quite = True
+            app.quiet = True
             app.daemon = Daemon(pid_file, app.data_dir)
             app.daemon.daemonize()
             app.pid = app.daemon.pid
@@ -318,11 +362,6 @@ def main():
     except (SystemExit, KeyboardInterrupt):
         if app:
             app.shutdown()
-    except ImportError:
-        traceback.print_exc()
-        if os.path.isfile(REQS_FILE):
-            print("Failed to import required libs, please run "
-                  "'pip install --user -U -r {}' from console".format(REQS_FILE))
     except Exception:
         traceback.print_exc()
 
