@@ -1,24 +1,27 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import datetime
+import functools
 import os
 import platform
 import re
@@ -26,11 +29,10 @@ import shutil
 import socket
 import sys
 import threading
-import time
 import traceback
-import urllib
-import urlparse
 import uuid
+from urllib.parse import uses_netloc
+from urllib.request import FancyURLopener
 
 from apscheduler.schedulers.tornado import TornadoScheduler
 from apscheduler.triggers.interval import IntervalTrigger
@@ -39,17 +41,16 @@ from fake_useragent import UserAgent
 from keycloak.realm import KeycloakRealm
 from tornado.ioloop import IOLoop
 
-import adba
 import sickrage
+from sickrage.core.announcements import Announcements
 from sickrage.core.api import API
-from sickrage.core.caches.name_cache import NameCache
+from sickrage.core.caches.quicksearch_cache import QuicksearchCache
 from sickrage.core.common import SD, SKIPPED, WANTED
 from sickrage.core.config import Config
 from sickrage.core.databases.cache import CacheDB
 from sickrage.core.databases.main import MainDB
-from sickrage.core.helpers import findCertainShow, generate_secret, makeDir, get_lan_ip, restoreSR, \
-    getDiskSpaceUsage, getFreeSpace, launch_browser, torrent_webui_url
-from sickrage.core.helpers.encoding import get_sys_encoding, ek, patch_modules
+from sickrage.core.helpers import generate_secret, make_dir, get_lan_ip, restore_app_data, get_disk_space_usage, get_free_space, launch_browser, \
+    torrent_webui_url, encryption
 from sickrage.core.logger import Logger
 from sickrage.core.nameparser.validator import check_force_season_folders
 from sickrage.core.processors import auto_postprocessor
@@ -64,9 +65,11 @@ from sickrage.core.searchers.proper_searcher import ProperSearcher
 from sickrage.core.searchers.subtitle_searcher import SubtitleSearcher
 from sickrage.core.searchers.trakt_searcher import TraktSearcher
 from sickrage.core.tv.show import TVShow
+from sickrage.core.tv.show.helpers import get_show_list
 from sickrage.core.ui import Notifications
+from sickrage.core.updaters.rsscache_updater import RSSCacheUpdater
 from sickrage.core.updaters.show_updater import ShowUpdater
-from sickrage.core.updaters.tz_updater import update_network_dict
+from sickrage.core.updaters.tz_updater import TimeZoneUpdater
 from sickrage.core.upnp import UPNPClient
 from sickrage.core.version_updater import VersionUpdater
 from sickrage.core.webserver import WebServer
@@ -78,33 +81,57 @@ from sickrage.providers import SearchProviders
 class Core(object):
     def __init__(self):
         self.started = False
+        self.loading_shows = False
         self.daemon = None
-        self.io_loop = IOLoop().current()
+        self.io_loop = None
         self.pid = os.getpid()
-        self.showlist = []
 
-        self.tz = tz.tzwinlocal() if tz.tzwinlocal else tz.tzlocal()
+        try:
+            self.tz = tz.tzwinlocal() if tz.tzwinlocal else tz.tzlocal()
+        except Exception:
+            self.tz = tz.tzlocal()
+
+        self.shows = {}
+
+        self.private_key = None
+        self.public_key = None
+
+        self.main_db = None
+        self.cache_db = None
 
         self.config_file = None
         self.data_dir = None
         self.cache_dir = None
-        self.quite = None
+        self.quiet = None
         self.no_launch = None
+        self.disable_updates = None
         self.web_port = None
+        self.web_host = None
+        self.web_root = None
         self.developer = None
+        self.db_type = None
+        self.db_prefix = None
+        self.db_host = None
+        self.db_port = None
+        self.db_username = None
+        self.db_password = None
         self.debug = None
-        self.newest_version = None
         self.newest_version_string = None
 
+        self.oidc_client_id = 'sickrage-app'
+        self.oidc_client_secret = '5d4710b2-ca70-4d39-b5a3-0705e2c5e703'
+
         self.naming_ep_type = ("%(seasonnumber)dx%(episodenumber)02d",
                                "s%(seasonnumber)02de%(episodenumber)02d",
                                "S%(seasonnumber)02dE%(episodenumber)02d",
-                               "%(seasonnumber)02dx%(episodenumber)02d")
+                               "%(seasonnumber)02dx%(episodenumber)02d",
+                               "S%(seasonnumber)02d E%(episodenumber)02d")
         self.sports_ep_type = ("%(seasonnumber)dx%(episodenumber)02d",
                                "s%(seasonnumber)02de%(episodenumber)02d",
                                "S%(seasonnumber)02dE%(episodenumber)02d",
-                               "%(seasonnumber)02dx%(episodenumber)02d")
-        self.naming_ep_type_text = ("1x02", "s01e02", "S01E02", "01x02")
+                               "%(seasonnumber)02dx%(episodenumber)02d",
+                               "S%(seasonnumber)02 dE%(episodenumber)02d")
+        self.naming_ep_type_text = ("1x02", "s01e02", "S01E02", "01x02", "S01 E02",)
         self.naming_multi_ep_type = {0: ["-%(episodenumber)02d"] * len(self.naming_ep_type),
                                      1: [" - " + x for x in self.naming_ep_type],
                                      2: [x + "%(episodenumber)02d" for x in ("x", "e", "E", "x")]}
@@ -114,28 +141,27 @@ class Core(object):
 
         self.user_agent = 'SiCKRAGE.CE.1/({};{};{})'.format(platform.system(), platform.release(), str(uuid.uuid1()))
         self.languages = [language for language in os.listdir(sickrage.LOCALE_DIR) if '_' in language]
-        self.sys_encoding = get_sys_encoding()
         self.client_web_urls = {'torrent': '', 'newznab': ''}
 
-        self.adba_connection = None
-        self.notifier_providers = None
+        self.notifier_providers = {}
         self.metadata_providers = {}
-        self.search_providers = None
+        self.search_providers = {}
+        self.adba_connection = None
         self.log = None
         self.config = None
         self.alerts = None
-        self.main_db = None
-        self.cache_db = None
         self.scheduler = None
         self.wserver = None
         self.google_auth = None
-        self.name_cache = None
         self.show_queue = None
         self.search_queue = None
         self.postprocessor_queue = None
         self.version_updater = None
         self.show_updater = None
+        self.tz_updater = None
+        self.rsscache_updater = None
         self.daily_searcher = None
+        self.failed_snatch_searcher = None
         self.backlog_searcher = None
         self.proper_searcher = None
         self.trakt_searcher = None
@@ -143,33 +169,37 @@ class Core(object):
         self.auto_postprocessor = None
         self.upnp_client = None
         self.oidc_client = None
+        self.quicksearch_cache = None
+        self.announcements = None
+        self.api = None
 
     def start(self):
         self.started = True
 
+        self.io_loop = IOLoop.current()
+
         # thread name
         threading.currentThread().setName('CORE')
 
-        # patch modules with encoding kludge
-        patch_modules()
-
         # init core classes
+        self.api = API()
+        self.main_db = MainDB(self.db_type, self.db_prefix, self.db_host, self.db_port, self.db_username, self.db_password)
+        self.cache_db = CacheDB(self.db_type, self.db_prefix, self.db_host, self.db_port, self.db_username, self.db_password)
         self.notifier_providers = NotifierProviders()
         self.metadata_providers = MetadataProviders()
         self.search_providers = SearchProviders()
         self.log = Logger()
         self.config = Config()
         self.alerts = Notifications()
-        self.main_db = MainDB()
-        self.cache_db = CacheDB()
-        self.scheduler = TornadoScheduler()
+        self.scheduler = TornadoScheduler({'apscheduler.timezone': 'UTC'})
         self.wserver = WebServer()
-        self.name_cache = NameCache()
         self.show_queue = ShowQueue()
         self.search_queue = SearchQueue()
         self.postprocessor_queue = PostProcessorQueue()
         self.version_updater = VersionUpdater()
         self.show_updater = ShowUpdater()
+        self.tz_updater = TimeZoneUpdater()
+        self.rsscache_updater = RSSCacheUpdater()
         self.daily_searcher = DailySearcher()
         self.failed_snatch_searcher = FailedSnatchSearcher()
         self.backlog_searcher = BacklogSearcher()
@@ -178,30 +208,46 @@ class Core(object):
         self.subtitle_searcher = SubtitleSearcher()
         self.auto_postprocessor = AutoPostProcessor()
         self.upnp_client = UPNPClient()
+        self.quicksearch_cache = QuicksearchCache()
+        self.announcements = Announcements()
 
         # setup oidc client
         realm = KeycloakRealm(server_url='https://auth.sickrage.ca', realm_name='sickrage')
-        self.oidc_client = realm.open_id_connect(client_id='sickrage-app',
-                                                 client_secret='5d4710b2-ca70-4d39-b5a3-0705e2c5e703')
+        self.oidc_client = realm.open_id_connect(client_id=self.oidc_client_id, client_secret=self.oidc_client_secret)
 
-        # Check if we need to perform a restore first
+        # check available space
+        try:
+            self.log.info("Performing disk space checks")
+            total_space, available_space = get_free_space(self.data_dir)
+            if available_space < 100:
+                self.log.warning('Shutting down as SiCKRAGE needs some space to work. You\'ll get corrupted data otherwise. Only %sMB left', available_space)
+                return
+        except Exception:
+            self.log.error('Failed getting disk space: %s', traceback.format_exc())
+
+        # check if we need to perform a restore first
         if os.path.exists(os.path.abspath(os.path.join(self.data_dir, 'restore'))):
-            success = restoreSR(os.path.abspath(os.path.join(self.data_dir, 'restore')), self.data_dir)
-            print("Restoring SiCKRAGE backup: %s!\n" % ("FAILED", "SUCCESSFUL")[success])
+            success = restore_app_data(os.path.abspath(os.path.join(self.data_dir, 'restore')), self.data_dir)
+            self.log.info("Restoring SiCKRAGE backup: %s!" % ("FAILED", "SUCCESSFUL")[success])
             if success:
+                self.main_db = MainDB(self.db_type, self.db_prefix, self.db_host, self.db_port, self.db_username, self.db_password)
+                self.cache_db = CacheDB(self.db_type, self.db_prefix, self.db_host, self.db_port, self.db_username, self.db_password)
                 shutil.rmtree(os.path.abspath(os.path.join(self.data_dir, 'restore')), ignore_errors=True)
 
         # migrate old database file names to new ones
         if os.path.isfile(os.path.abspath(os.path.join(self.data_dir, 'sickbeard.db'))):
             if os.path.isfile(os.path.join(self.data_dir, 'sickrage.db')):
-                helpers.moveFile(os.path.join(self.data_dir, 'sickrage.db'),
-                                 os.path.join(self.data_dir, '{}.bak-{}'
-                                              .format('sickrage.db',
-                                                      datetime.datetime.now().strftime(
-                                                          '%Y%m%d_%H%M%S'))))
+                helpers.move_file(os.path.join(self.data_dir, 'sickrage.db'),
+                                  os.path.join(self.data_dir, '{}.bak-{}'
+                                               .format('sickrage.db',
+                                                       datetime.datetime.now().strftime(
+                                                           '%Y%m%d_%H%M%S'))))
 
-            helpers.moveFile(os.path.abspath(os.path.join(self.data_dir, 'sickbeard.db')),
-                             os.path.abspath(os.path.join(self.data_dir, 'sickrage.db')))
+            helpers.move_file(os.path.abspath(os.path.join(self.data_dir, 'sickbeard.db')),
+                              os.path.abspath(os.path.join(self.data_dir, 'sickrage.db')))
+
+        # init encryption public and private keys
+        encryption.initialize()
 
         # load config
         self.config.load()
@@ -217,80 +263,52 @@ class Core(object):
         self.log.logNr = self.config.log_nr
         self.log.logFile = os.path.join(self.data_dir, 'logs', 'sickrage.log')
         self.log.debugLogging = self.config.debug
-        self.log.consoleLogging = not self.quite
+        self.log.consoleLogging = not self.quiet
 
         # start logger
         self.log.start()
 
+        # perform database startup actions
+        for db in [self.main_db, self.cache_db]:
+            # perform integrity check
+            self.log.info("Performing integrity check on {} database".format(db.name))
+            db.integrity_check()
+
+            # migrate database
+            self.log.info("Performing migrations on {} database".format(db.name))
+            db.migrate()
+
+            # sync database repo
+            self.log.info("Performing sync on {} database".format(db.name))
+            db.sync_db_repo()
+
+            # cleanup
+            self.log.info("Performing cleanup on {} database".format(db.name))
+            db.cleanup()
+
         # user agent
         if self.config.random_user_agent:
             self.user_agent = UserAgent().random
 
-        urlparse.uses_netloc.append('scgi')
-        urllib.FancyURLopener.version = self.user_agent
+        uses_netloc.append('scgi')
+        FancyURLopener.version = self.user_agent
 
         # set torrent client web url
         torrent_webui_url(True)
 
-        # Check available space
-        try:
-            total_space, available_space = getFreeSpace(self.data_dir)
-            if available_space < 100:
-                self.log.error('Shutting down as SiCKRAGE needs some space to work. You\'ll get corrupted data '
-                               'otherwise. Only %sMB left', available_space)
-                return
-        except Exception:
-            self.log.error('Failed getting disk space: %s', traceback.format_exc())
+        # load quicksearch cache
+        self.quicksearch_cache.load()
 
-        # perform database startup actions
-        for db in [self.main_db, self.cache_db]:
-            # initialize database
-            db.initialize()
-
-            # check integrity of database
-            db.check_integrity()
-
-            # migrate database
-            db.migrate()
-
-            # misc database cleanups
-            db.cleanup()
-
-            # upgrade database
-            db.upgrade()
-
-        # compact main database
-        if self.config.last_db_compact < time.time() - 604800:  # 7 days
-            self.main_db.compact()
-            self.config.last_db_compact = int(time.time())
-
-        # load name cache
-        self.name_cache.load()
-
-        # load data for shows from database
-        self.load_shows()
-
-        if self.config.default_page not in ('home', 'schedule', 'history', 'news', 'IRC'):
+        if self.config.default_page not in ('schedule', 'history', 'IRC'):
             self.config.default_page = 'home'
 
         # cleanup cache folder
         for folder in ['mako', 'sessions', 'indexers']:
             try:
-                shutil.rmtree(os.path.join(sickrage.app.cache_dir, folder), ignore_errors=True)
+                shutil.rmtree(os.path.join(self.cache_dir, folder), ignore_errors=True)
             except Exception:
                 continue
 
-        # init anidb connection
-        if self.config.use_anidb:
-            def anidb_logger(msg):
-                return self.log.debug("AniDB: {} ".format(msg))
-
-            try:
-                self.adba_connection = adba.Connection(keepAlive=True, log=anidb_logger)
-                self.adba_connection.auth(self.config.anidb_username, self.config.anidb_password)
-            except Exception as e:
-                self.log.warning("AniDB exception msg: %r " % repr(e))
-
         if self.config.web_port < 21 or self.config.web_port > 65535:
             self.config.web_port = 8081
 
@@ -317,7 +335,6 @@ class Core(object):
             self.config.autopostprocessor_freq = self.config.min_autopostprocessor_freq
         if self.config.daily_searcher_freq < self.config.min_daily_searcher_freq:
             self.config.daily_searcher_freq = self.config.min_daily_searcher_freq
-        self.config.min_backlog_searcher_freq = self.backlog_searcher.get_backlog_cycle_time()
         if self.config.backlog_searcher_freq < self.config.min_backlog_searcher_freq:
             self.config.backlog_searcher_freq = self.config.min_backlog_searcher_freq
         if self.config.version_updater_freq < self.config.min_version_updater_freq:
@@ -330,14 +347,13 @@ class Core(object):
             self.config.proper_searcher_interval = 'daily'
         if self.config.showupdate_hour < 0 or self.config.showupdate_hour > 23:
             self.config.showupdate_hour = 0
-        if self.config.subtitles_languages[0] == '':
-            self.config.subtitles_languages = []
 
         # add version checker job
         self.scheduler.add_job(
             self.version_updater.run,
             IntervalTrigger(
-                hours=self.config.version_updater_freq
+                hours=self.config.version_updater_freq,
+                timezone='utc'
             ),
             name=self.version_updater.name,
             id=self.version_updater.name
@@ -345,12 +361,13 @@ class Core(object):
 
         # add network timezones updater job
         self.scheduler.add_job(
-            update_network_dict,
+            self.tz_updater.run,
             IntervalTrigger(
-                days=1
+                days=1,
+                timezone='utc'
             ),
-            name="TZUPDATER",
-            id="TZUPDATER"
+            name=self.tz_updater.name,
+            id=self.tz_updater.name
         )
 
         # add show updater job
@@ -358,18 +375,31 @@ class Core(object):
             self.show_updater.run,
             IntervalTrigger(
                 days=1,
-                start_date=datetime.datetime.now().replace(hour=self.config.showupdate_hour)
+                start_date=datetime.datetime.now().replace(hour=self.config.showupdate_hour),
+                timezone='utc'
             ),
             name=self.show_updater.name,
             id=self.show_updater.name
         )
 
+        # add rss cache updater job
+        self.scheduler.add_job(
+            self.rsscache_updater.run,
+            IntervalTrigger(
+                minutes=15,
+                timezone='utc'
+            ),
+            name=self.rsscache_updater.name,
+            id=self.rsscache_updater.name
+        )
+
         # add daily search job
         self.scheduler.add_job(
             self.daily_searcher.run,
             IntervalTrigger(
                 minutes=self.config.daily_searcher_freq,
-                start_date=datetime.datetime.now() + datetime.timedelta(minutes=4)
+                start_date=datetime.datetime.now() + datetime.timedelta(minutes=4),
+                timezone='utc'
             ),
             name=self.daily_searcher.name,
             id=self.daily_searcher.name
@@ -380,7 +410,8 @@ class Core(object):
             self.failed_snatch_searcher.run,
             IntervalTrigger(
                 hours=1,
-                start_date=datetime.datetime.now() + datetime.timedelta(minutes=4)
+                start_date=datetime.datetime.now() + datetime.timedelta(minutes=4),
+                timezone='utc'
             ),
             name=self.failed_snatch_searcher.name,
             id=self.failed_snatch_searcher.name
@@ -391,7 +422,8 @@ class Core(object):
             self.backlog_searcher.run,
             IntervalTrigger(
                 minutes=self.config.backlog_searcher_freq,
-                start_date=datetime.datetime.now() + datetime.timedelta(minutes=30)
+                start_date=datetime.datetime.now() + datetime.timedelta(minutes=30),
+                timezone='utc'
             ),
             name=self.backlog_searcher.name,
             id=self.backlog_searcher.name
@@ -401,7 +433,8 @@ class Core(object):
         self.scheduler.add_job(
             self.auto_postprocessor.run,
             IntervalTrigger(
-                minutes=self.config.autopostprocessor_freq
+                minutes=self.config.autopostprocessor_freq,
+                timezone='utc'
             ),
             name=self.auto_postprocessor.name,
             id=self.auto_postprocessor.name
@@ -411,8 +444,14 @@ class Core(object):
         self.scheduler.add_job(
             self.proper_searcher.run,
             IntervalTrigger(
-                minutes={'15m': 15, '45m': 45, '90m': 90, '4h': 4 * 60, 'daily': 24 * 60}[
-                    self.config.proper_searcher_interval]
+                minutes={
+                    '15m': 15,
+                    '45m': 45,
+                    '90m': 90,
+                    '4h': 4 * 60,
+                    'daily': 24 * 60
+                }[self.config.proper_searcher_interval],
+                timezone='utc'
             ),
             name=self.proper_searcher.name,
             id=self.proper_searcher.name
@@ -422,7 +461,8 @@ class Core(object):
         self.scheduler.add_job(
             self.trakt_searcher.run,
             IntervalTrigger(
-                hours=1
+                hours=1,
+                timezone='utc'
             ),
             name=self.trakt_searcher.name,
             id=self.trakt_searcher.name
@@ -432,30 +472,93 @@ class Core(object):
         self.scheduler.add_job(
             self.subtitle_searcher.run,
             IntervalTrigger(
-                hours=self.config.subtitle_searcher_freq
+                hours=self.config.subtitle_searcher_freq,
+                timezone='utc'
             ),
             name=self.subtitle_searcher.name,
             id=self.subtitle_searcher.name
         )
 
-        # start scheduler service
-        self.scheduler.start()
+        # add upnp client job
+        self.scheduler.add_job(
+            self.upnp_client.run,
+            IntervalTrigger(
+                seconds=self.upnp_client._nat_portmap_lifetime,
+                timezone='utc'
+            ),
+            name=self.upnp_client.name,
+            id=self.upnp_client.name
+        )
 
-        # start queue's
+        # add announcements job
+        self.scheduler.add_job(
+            self.announcements.run,
+            IntervalTrigger(
+                minutes=15,
+                timezone='utc'
+            ),
+            name=self.announcements.name,
+            id=self.announcements.name
+        )
+
+        # start queues
         self.search_queue.start()
         self.show_queue.start()
         self.postprocessor_queue.start()
 
-        # start upnp client
-        if self.config.enable_upnp:
-            self.upnp_client.start()
+        # fire off startup events
+        self.io_loop.add_callback(self.load_shows)
+        self.io_loop.add_callback(self.version_updater.run)
+        self.io_loop.add_callback(self.tz_updater.run)
+        self.io_loop.add_callback(self.announcements.run)
 
-        # start webserver
+        # start scheduler service
+        self.scheduler.start()
+
+        # start web server
         self.wserver.start()
 
-        # start ioloop
+        # launch browser window
+        if all([not sickrage.app.no_launch, sickrage.app.config.launch_browser]):
+            self.io_loop.add_callback(functools.partial(launch_browser, ('http', 'https')[sickrage.app.config.enable_https],
+                                                        sickrage.app.config.web_host, sickrage.app.config.web_port))
+
+        def started():
+            threading.currentThread().setName('CORE')
+            self.log.info("SiCKRAGE :: STARTED")
+            self.log.info("SiCKRAGE :: APP VERSION:[{}]".format(sickrage.version()))
+            self.log.info("SiCKRAGE :: CONFIG VERSION:[v{}]".format(self.config.config_version))
+            self.log.info("SiCKRAGE :: DATABASE VERSION:[v{}]".format(self.main_db.version))
+            self.log.info("SiCKRAGE :: DATABASE TYPE:[{}]".format(self.db_type))
+            self.log.info("SiCKRAGE :: URL:[{}://{}:{}{}]".format(('http', 'https')[self.config.enable_https],
+                                                                  self.config.web_host, self.config.web_port, self.config.web_root))
+
+        # start io_loop
+        self.io_loop.add_callback(started)
         self.io_loop.start()
 
+    def load_shows(self):
+        threading.currentThread().setName('CORE')
+
+        session = self.main_db.session()
+
+        self.log.info('Loading initial shows list')
+
+        self.loading_shows = True
+
+        self.shows = {}
+        for query in session.query(MainDB.TVShow).with_entities(MainDB.TVShow.indexer_id, MainDB.TVShow.indexer, MainDB.TVShow.name):
+            try:
+                self.log.info('Loading show {} and building caches'.format(query.name))
+                self.shows.update({(query.indexer_id, query.indexer): TVShow(query.indexer_id, query.indexer)})
+                self.quicksearch_cache.add_show(query.indexer_id)
+            except Exception as e:
+                self.log.debug('There was an error loading show: {}'.format(query.name))
+
+        self.loading_shows = False
+
+        self.log.info('Loading initial shows list finished')
+
     def shutdown(self, restart=False):
         if self.started:
             self.log.info('SiCKRAGE IS SHUTTING DOWN!!!')
@@ -464,41 +567,18 @@ class Core(object):
             if self.wserver:
                 self.wserver.shutdown()
 
-            # shutdown upnp client
-            if self.upnp_client:
-                self.upnp_client.shutdown()
-
-            # shutdown show queue
-            if self.show_queue:
-                self.log.debug("Shutting down show queue")
-                self.show_queue.shutdown()
-                del self.show_queue
-
-            # shutdown search queue
-            if self.search_queue:
-                self.log.debug("Shutting down search queue")
-                self.search_queue.shutdown()
-                del self.search_queue
-
-            # shutdown post-processor queue
-            if self.postprocessor_queue:
-                self.log.debug("Shutting down post-processor queue")
-                self.postprocessor_queue.shutdown()
-                del self.postprocessor_queue
-
             # log out of ADBA
             if self.adba_connection:
                 self.log.debug("Shutting down ANIDB connection")
                 self.adba_connection.stop()
 
-            # save all show and config settings
-            self.save_all()
+            # save shows
+            self.log.info('Saving all shows to the database')
+            for show in self.shows.values():
+                show.save()
 
-            # close databases
-            for db in [self.main_db, self.cache_db]:
-                if db.opened:
-                    self.log.debug("Shutting down {} database connection".format(db.name))
-                    db.close()
+            # save settings
+            self.config.save()
 
             # shutdown logging
             if self.log:
@@ -512,28 +592,5 @@ class Core(object):
 
         self.started = False
 
-        self.io_loop.stop()
-
-    def save_all(self):
-        # write all shows
-        self.log.info("Saving all shows to the database")
-        for show in self.showlist:
-            try:
-                show.saveToDB()
-            except Exception:
-                continue
-
-        # save config
-        self.config.save()
-
-    def load_shows(self):
-        """
-        Populates the showlist with shows from the database
-        """
-
-        for dbData in self.main_db.all('tv_shows'):
-            try:
-                self.log.debug("Loading data for show: [{}]".format(dbData['show_name']))
-                self.showlist += [TVShow(int(dbData['indexer']), int(dbData['indexer_id']))]
-            except Exception as e:
-                self.log.debug("Show error in [%s]: %s" % (dbData['location'], str(e)))
+        if self.io_loop:
+            self.io_loop.stop()
