@@ -2,9 +2,9 @@
 # URL: https://sickrage.ca/
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -15,14 +15,11 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
-
-from CodernityDB.database import RecordNotFound
 
 import sickrage
-from adba.aniDBerrors import AniDBCommandTimeoutError
+from sickrage.core.databases.main import MainDB
 
 
 class BlackAndWhiteList(object):
@@ -39,9 +36,16 @@ class BlackAndWhiteList(object):
         """
         Builds black and whitelist
         """
+
+        session = sickrage.app.main_db.session()
+
         sickrage.app.log.debug('Building black and white list for ' + str(self.show_id))
-        self.blacklist = self._load_list('blacklist')
-        self.whitelist = self._load_list('whitelist')
+
+        self.blacklist = self._load_list(session.query(MainDB.Blacklist).filter_by(show_id=self.show_id))
+        sickrage.app.log.debug('BWL: {} loaded keywords from {}: {}'.format(self.show_id, MainDB.Blacklist.__tablename__, self.blacklist))
+
+        self.whitelist = self._load_list(session.query(MainDB.Whitelist).filter_by(show_id=self.show_id))
+        sickrage.app.log.debug('BWL: {} loaded keywords from {}: {}'.format(self.show_id, MainDB.Whitelist.__tablename__, self.whitelist))
 
     def _add_keywords(self, table, values):
         """
@@ -50,22 +54,31 @@ class BlackAndWhiteList(object):
         :param table: database table to add keywords to
         :param values: Values to be inserted in table
         """
+
+        session = sickrage.app.main_db.session()
+
         for value in values:
-            sickrage.app.main_db.insert({
-                '_t': table,
+            session.add(table(**{
                 'show_id': self.show_id,
-                'keywork': value
-            })
+                'keyword': value
+            }))
+            session.commit()
 
     def set_black_keywords(self, values):
         """
         Sets blacklist to new value
 
         :param values: Complete list of keywords to be set as blacklist
+        :param session: Database session
         """
-        self._del_all_keywords('blacklist')
-        self._add_keywords('blacklist', values)
+
+        session = sickrage.app.main_db.session()
+        session.query(MainDB.Blacklist).filter_by(show_id=self.show_id).delete()
+        session.commit()
+
+        self._add_keywords(MainDB.Blacklist, values)
         self.blacklist = values
+
         sickrage.app.log.debug('Blacklist set to: %s' % self.blacklist)
 
     def set_white_keywords(self, values):
@@ -73,38 +86,28 @@ class BlackAndWhiteList(object):
         Sets whitelist to new value
 
         :param values: Complete list of keywords to be set as whitelist
+        :param session: Database session
         """
-        self._del_all_keywords('whitelist')
-        self._add_keywords('whitelist', values)
+        session = sickrage.app.main_db.session()
+        session.query(MainDB.Whitelist).filter_by(show_id=self.show_id).delete()
+        session.commit()
+
+        self._add_keywords(MainDB.Whitelist, values)
         self.whitelist = values
+
         sickrage.app.log.debug('Whitelist set to: %s' % self.whitelist)
 
-    def _del_all_keywords(self, table):
-        """
-        DB: Remove all keywords for current show
-
-        :param table: database table remove keywords from
-        """
-        try:
-            sickrage.app.main_db.delete(sickrage.app.main_db.get(table, self.show_id))
-        except RecordNotFound:
-            pass
-
-    def _load_list(self, table):
+    def _load_list(self, keyword_list):
         """
         DB: Fetch keywords for current show
 
-        :param table: Table to fetch list of keywords from
-
         :return: keywords in list
         """
         try:
-            groups = [x['keyword'] for x in sickrage.app.main_db.get_many(table, self.show_id)]
+            groups = [x.keyword for x in keyword_list]
         except KeyError:
             groups = []
 
-        sickrage.app.log.debug('BWL: ' + str(self.show_id) + ' loaded keywords from ' + table + ': ' + str(groups))
-
         return groups
 
     def is_valid(self, result):
@@ -145,32 +148,3 @@ class BlackAndWhiteList(object):
 
 class BlackWhitelistNoShowIDException(Exception):
     """No show_id was given"""
-
-
-def short_group_names(groups):
-    """
-    Find AniDB short group names for release groups
-
-    :param groups: list of groups to find short group names for
-    :return: list of shortened group names
-    """
-    groups = groups.split(",")
-    shortGroupList = []
-    if sickrage.app.adba_connection:
-        for groupName in groups:
-            try:
-                group = sickrage.app.adba_connection.group(gname=groupName)
-            except AniDBCommandTimeoutError:
-                sickrage.app.log.debug("Timeout while loading group from AniDB. Trying next group")
-            except Exception:
-                sickrage.app.log.debug("Failed while loading group from AniDB. Trying next group")
-            else:
-                for line in group.datalines:
-                    if line["shortname"]:
-                        shortGroupList.append(line["shortname"])
-                    else:
-                        if groupName not in shortGroupList:
-                            shortGroupList.append(groupName)
-    else:
-        shortGroupList = groups
-    return shortGroupList
