@@ -1,36 +1,40 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import datetime
+import functools
 import time
 
 import feedparser
-from CodernityDB.database import RecordNotFound
-from CodernityDB.index import IndexNotFoundException
+from sqlalchemy import orm
+from sqlalchemy.exc import IntegrityError
 
 import sickrage
-from sickrage.core.api.cache import ProviderCacheAPI
 from sickrage.core.common import Quality
-from sickrage.core.exceptions import AuthException, EpisodeNotFoundException
-from sickrage.core.helpers import findCertainShow, show_names, validate_url, is_ip_private
+from sickrage.core.databases.cache import CacheDB
+from sickrage.core.exceptions import AuthException
+from sickrage.core.helpers import show_names, validate_url, is_ip_private, try_int
 from sickrage.core.nameparser import InvalidNameException, NameParser, InvalidShowException
+from sickrage.core.tv.show.helpers import find_show
 from sickrage.core.websession import WebSession
 
 
@@ -42,9 +46,10 @@ class TVCache(object):
         self.search_strings = kwargs.pop('search_strings', dict(RSS=['']))
 
     def clear(self):
+        session = sickrage.app.cache_db.session()
         if self.shouldClearCache():
-            [sickrage.app.cache_db.delete(x) for x in
-             sickrage.app.cache_db.get_many('providers', self.providerID)]
+            session.query(CacheDB.Provider).filter_by(provider=self.providerID).delete()
+            session.commit()
 
     def _get_title_and_url(self, item):
         return self.provider._get_title_and_url(item)
@@ -65,9 +70,9 @@ class TVCache(object):
     def check_item(self, title, url):
         return True
 
-    def update(self):
+    def update(self, force=False):
         # check if we should update
-        if self.should_update():
+        if self.should_update() or force:
             try:
                 data = self._get_rss_data()
                 if not self._check_auth(data):
@@ -90,11 +95,12 @@ class TVCache(object):
 
         return True
 
-    def getRSSFeed(self, url, params=None):
+    def get_rss_feed(self, url, params=None):
         try:
             if self.provider.login():
-                resp = WebSession().get(url, params=params).text
-                return feedparser.parse(resp)
+                resp = WebSession().get(url, params=params)
+                if resp:
+                    return feedparser.parse(resp.text)
         except Exception as e:
             sickrage.app.log.debug("RSS Error: {}".format(e))
 
@@ -114,64 +120,70 @@ class TVCache(object):
         self.check_item(title, url)
 
         if title and url:
-            self.addCacheEntry(self._translateTitle(title), self._translateLinkURL(url), seeders, leechers, size)
+            self.add_cache_entry(self._translateTitle(title), self._translateLinkURL(url), seeders, leechers, size)
         else:
             sickrage.app.log.debug(
                 "The data returned from the " + self.provider.name + " feed is incomplete, this result is unusable")
 
     @property
     def last_update(self):
+        session = sickrage.app.cache_db.session()
+
         try:
-            dbData = sickrage.app.cache_db.get('lastUpdate', self.providerID)
-            lastTime = int(dbData["time"])
+            dbData = session.query(CacheDB.LastUpdate).filter_by(provider=self.providerID).one()
+            lastTime = int(dbData.time)
             if lastTime > int(time.mktime(datetime.datetime.today().timetuple())):
                 lastTime = 0
-        except (RecordNotFound, IndexNotFoundException):
+        except orm.exc.NoResultFound:
             lastTime = 0
 
         return datetime.datetime.fromtimestamp(lastTime)
 
     @last_update.setter
     def last_update(self, toDate):
+        session = sickrage.app.cache_db.session()
+
         try:
-            dbData = sickrage.app.cache_db.get('lastUpdate', self.providerID)
-            dbData['time'] = int(time.mktime(toDate.timetuple()))
-            sickrage.app.cache_db.update(dbData)
-        except (RecordNotFound, IndexNotFoundException):
-            sickrage.app.cache_db.insert({
-                '_t': 'lastUpdate',
+            dbData = session.query(CacheDB.LastUpdate).filter_by(provider=self.providerID).one()
+            dbData.time = int(time.mktime(toDate.timetuple()))
+        except orm.exc.NoResultFound:
+            session.add(CacheDB.LastUpdate(**{
                 'provider': self.providerID,
                 'time': int(time.mktime(toDate.timetuple()))
-            })
+            }))
+        finally:
+            session.commit()
 
     @property
     def last_search(self):
+        session = sickrage.app.cache_db.session()
+
         try:
-            dbData = sickrage.app.cache_db.get('lastSearch', self.providerID)
-            lastTime = int(dbData["time"])
+            dbData = session.query(CacheDB.LastSearch).filter_by(provider=self.providerID).one()
+            lastTime = int(dbData.time)
             if lastTime > int(time.mktime(datetime.datetime.today().timetuple())):
                 lastTime = 0
-        except (RecordNotFound, IndexNotFoundException):
+        except orm.exc.NoResultFound:
             lastTime = 0
 
         return datetime.datetime.fromtimestamp(lastTime)
 
     @last_search.setter
     def last_search(self, toDate):
+        session = sickrage.app.cache_db.session()
+
         try:
-            dbData = sickrage.app.cache_db.get('lastSearch', self.providerID)
-            dbData['time'] = int(time.mktime(toDate.timetuple()))
-            sickrage.app.cache_db.update(dbData)
-        except (RecordNotFound, IndexNotFoundException):
-            sickrage.app.cache_db.insert({
-                '_t': 'lastUpdate',
+            dbData = session.query(CacheDB.LastSearch).filter_by(provider=self.providerID).one()
+            dbData.time = int(time.mktime(toDate.timetuple()))
+        except orm.exc.NoResultFound:
+            session.add(CacheDB.LastSearch(**{
                 'provider': self.providerID,
                 'time': int(time.mktime(toDate.timetuple()))
-            })
+            }))
+        finally:
+            session.commit()
 
     def should_update(self):
-        if sickrage.app.developer: return True
-
         # if we've updated recently then skip the update
         if datetime.datetime.today() - self.last_update < datetime.timedelta(minutes=self.min_time):
             return False
@@ -183,19 +195,23 @@ class TVCache(object):
             return False
         return True
 
-    def addCacheEntry(self, name, url, seeders, leechers, size):
+    def add_cache_entry(self, name, url, seeders, leechers, size):
+        session = sickrage.app.cache_db.session()
+
         # check for existing entry in cache
-        if len([x for x in sickrage.app.cache_db.get_many('providers', self.providerID) if x['url'] == url]):
+        if session.query(CacheDB.Provider).filter_by(url=url).count():
             return
 
-        # ignore invalid urls
-        if not validate_url(url) and not url.startswith('magnet') \
-                or is_ip_private(url.split(r'//')[-1].split(r'/')[0]):
+        # ignore invalid and private IP address urls
+        if not validate_url(url):
+            if not url.startswith('magnet'):
+                return
+        elif is_ip_private(url.split(r'//')[-1].split(r'/')[0]):
             return
 
         try:
             # parse release name
-            parse_result = NameParser(validate_show=sickrage.app.config.enable_rss_cache_valid_shows).parse(name)
+            parse_result = NameParser(validate_show=True).parse(name)
             if parse_result.series_name and parse_result.quality != Quality.UNKNOWN:
                 season = parse_result.season_number if parse_result.season_number else 1
                 episodes = parse_result.episode_numbers
@@ -214,74 +230,78 @@ class TVCache(object):
                     version = parse_result.version
 
                     dbData = {
-                        '_t': 'providers',
                         'provider': self.providerID,
                         'name': name,
                         'season': season,
                         'episodes': episodeText,
-                        'indexerid': parse_result.indexerid,
+                        'series_id': parse_result.indexer_id,
                         'url': url,
                         'time': int(time.mktime(datetime.datetime.today().timetuple())),
                         'quality': quality,
                         'release_group': release_group,
                         'version': version,
-                        'seeders': seeders,
-                        'leechers': leechers,
-                        'size': size
+                        'seeders': try_int(seeders),
+                        'leechers': try_int(leechers),
+                        'size': try_int(size, -1)
                     }
 
                     # add to internal database
-                    sickrage.app.cache_db.insert(dbData)
+                    try:
+                        session.add(CacheDB.Provider(**dbData))
+                        session.commit()
+                        sickrage.app.log.debug("SEARCH RESULT:[{}] ADDED TO CACHE!".format(name))
+                    except IntegrityError:
+                        pass
 
                     # add to external provider cache database
                     if sickrage.app.config.enable_api_providers_cache and not self.provider.private:
                         try:
-                            ProviderCacheAPI().add(dbData)
-                        except Exception:
+                            sickrage.app.io_loop.run_in_executor(None, functools.partial(sickrage.app.api.provider_cache.add, data=dbData))
+                        except Exception as e:
                             pass
-
-                    sickrage.app.log.debug("SEARCH RESULT:[%s] ADDED TO CACHE!", name)
         except (InvalidShowException, InvalidNameException):
             pass
 
-    def search_cache(self, ep_obj, manualSearch=False, downCurQuality=False):
-        neededEps = {}
+    def search_cache(self, show_id, season, episode, manualSearch=False, downCurQuality=False):
+        cache_results = {}
         dbData = []
 
         # get data from external database
         if sickrage.app.config.enable_api_providers_cache and not self.provider.private:
             try:
-                dbData += ProviderCacheAPI().get(self.providerID,
-                                                 ep_obj.show.indexerid,
-                                                 ep_obj.season, ep_obj.episode)['data']
+                dbData += sickrage.app.api.provider_cache.get(self.providerID, show_id, season, episode)['data']
             except Exception:
                 pass
 
         # get data from internal database
-        dbData += [x for x in sickrage.app.cache_db.get_many('providers', self.providerID)]
+        session = sickrage.app.cache_db.session()
+        dbData += [x.as_dict() for x in session.query(CacheDB.Provider).filter_by(provider=self.providerID, series_id=show_id, season=season).filter(
+            CacheDB.Provider.episodes.contains("|{}|".format(episode)))]
 
-        # for each cache entry
-        for curResult in (x for x in dbData if x['indexerid'] == ep_obj.show.indexerid and x['season'] == ep_obj.season
-                                               and "|" + str(ep_obj.episode) + "|" in x['episodes']):
-            result = self.provider.getResult()
+        for curResult in dbData:
+            show_object = find_show(int(curResult["series_id"]))
+            if not show_object:
+                continue
 
-            # ignore invalid urls
-            if not validate_url(curResult["url"]) and not curResult["url"].startswith('magnet') \
-                    or is_ip_private(curResult["url"].split(r'//')[-1].split(r'/')[0]):
+            result = self.provider.get_result()
+
+            # ignore invalid and private IP address urls
+            if not validate_url(curResult["url"]):
+                if not curResult["url"].startswith('magnet'):
+                    continue
+            elif is_ip_private(curResult["url"].split(r'//')[-1].split(r'/')[0]):
                 continue
 
             # ignored/required words, and non-tv junk
-            if not show_names.filterBadReleases(curResult["name"]):
+            if not show_names.filter_bad_releases(curResult["name"]):
                 continue
 
             # get the show object, or if it's not one of our shows then ignore it
-            result.show = findCertainShow(int(curResult["indexerid"]))
-            if not result.show:
-                continue
+            result.show_id = int(curResult["series_id"])
 
             # skip if provider is anime only and show is not anime
-            if self.provider.anime_only and not result.show.is_anime:
-                sickrage.app.log.debug("" + str(result.show.name) + " is not an anime, skiping")
+            if self.provider.anime_only and not show_object.is_anime:
+                sickrage.app.log.debug("" + str(show_object.name) + " is not an anime, skiping")
                 continue
 
             # get season and ep data (ignoring multi-eps for now)
@@ -289,11 +309,8 @@ class TVCache(object):
             if curSeason == -1:
                 continue
 
-            try:
-                result.episodes = [result.show.getEpisode(curSeason, int(curEp)) for curEp in
-                                   filter(None, curResult["episodes"].split("|"))]
-            except EpisodeNotFoundException:
-                continue
+            result.season = curSeason
+            result.episodes = [int(curEp) for curEp in filter(None, curResult["episodes"].split("|"))]
 
             result.quality = int(curResult["quality"])
             result.release_group = curResult["release_group"]
@@ -301,20 +318,19 @@ class TVCache(object):
 
             # make sure we want the episode
             wantEp = False
-            for curEp in result.episodes:
-                if result.show.wantEpisode(curEp.season, curEp.episode, result.quality, manualSearch, downCurQuality):
+            for result_episode in result.episodes:
+                if show_object.want_episode(result.season, result_episode, result.quality, manualSearch, downCurQuality):
                     wantEp = True
 
             if not wantEp:
-                sickrage.app.log.info("Skipping " + curResult["name"] + " because we don't want an episode that's " +
-                                      Quality.qualityStrings[result.quality])
+                sickrage.app.log.info("Skipping " + curResult["name"] + " because we don't want an episode that's " + Quality.qualityStrings[result.quality])
                 continue
 
             # build a result object
             result.name = curResult["name"]
             result.url = curResult["url"]
 
-            sickrage.app.log.info("Found result " + result.name + " at " + result.url)
+            sickrage.app.log.info("Found cached {} result {}".format(result.type, result.name))
 
             result.seeders = curResult.get("seeders", -1)
             result.leechers = curResult.get("leechers", -1)
@@ -322,12 +338,12 @@ class TVCache(object):
             result.content = None
 
             # add it to the list
-            if ep_obj.episode not in neededEps:
-                neededEps[ep_obj.episode] = [result]
+            if episode not in cache_results:
+                cache_results[int(episode)] = [result]
             else:
-                neededEps[ep_obj.episode] += [result]
+                cache_results[int(episode)] += [result]
 
         # datetime stamp this search so cache gets cleared
         self.last_search = datetime.datetime.today()
 
-        return neededEps
+        return cache_results
