@@ -2,31 +2,27 @@
 # URL: https://sickrage.ca/
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import datetime
-import re
 import sys
+from collections import deque
 
-from dateutil import parser
-
-import sickrage
-from sickrage.core.common import Quality, dateFormat, dateTimeFormat
+from sickrage.core.common import Quality, dateTimeFormat
 
 
 class SearchResult(object):
@@ -34,14 +30,14 @@ class SearchResult(object):
     Represents a search result from an indexer.
     """
 
-    def __init__(self, episodes):
+    def __init__(self, season, episodes):
         self.provider = None
 
         # release name
         self.name = ""
 
-        # release show object
-        self.show = None
+        # release show ID
+        self.show_id = None
 
         # URL to the NZB/torrent file
         self.url = ""
@@ -49,7 +45,10 @@ class SearchResult(object):
         # used by some providers to store extra info associated with the result
         self.extraInfo = []
 
-        # list of TVEpisode objects that this result is associated with
+        # season that this result is associated with
+        self.season = season
+
+        # list of episodes that this result is associated with
         self.episodes = episodes
 
         # quality of the release
@@ -83,7 +82,7 @@ class SearchResult(object):
         self.ratio = None
 
         # result type
-        self.resultType = ''
+        self.type = ''
 
         # dict of files and their sizes
         self.files = {}
@@ -94,13 +93,14 @@ class SearchResult(object):
             return "Invalid provider, unable to print self"
 
         myString = self.provider.name + " @ " + self.url + "\n"
+
         myString += "Extra Info:\n"
-        for extra in self.extraInfo:
-            myString += "  " + extra + "\n"
+        myString += "  ".join(self.extraInfo) + "\n"
+
+        myString += "Season: " + str(self.season) + "\n"
 
         myString += "Episodes:\n"
-        for ep in self.episodes:
-            myString += "  " + str(ep) + "\n"
+        myString += "  ".join(map(str, self.episodes)) + "\n"
 
         myString += "Quality: " + Quality.qualityStrings[self.quality] + "\n"
         myString += "Name: " + self.name + "\n"
@@ -109,18 +109,15 @@ class SearchResult(object):
 
         return myString
 
-    def fileName(self):
-        return self.episodes[0].pretty_name() + "." + self.resultType
-
 
 class NZBSearchResult(SearchResult):
     """
     Regular NZB result with an URL to the NZB
     """
 
-    def __init__(self, episodes):
-        super(NZBSearchResult, self).__init__(episodes)
-        self.resultType = "nzb"
+    def __init__(self, season, episodes):
+        super(NZBSearchResult, self).__init__(season, episodes)
+        self.type = "nzb"
 
 
 class NZBDataSearchResult(SearchResult):
@@ -128,9 +125,9 @@ class NZBDataSearchResult(SearchResult):
     NZB result where the actual NZB XML data is stored in the extraInfo
     """
 
-    def __init__(self, episodes):
-        super(NZBDataSearchResult, self).__init__(episodes)
-        self.resultType = "nzbdata"
+    def __init__(self, season, episodes):
+        super(NZBDataSearchResult, self).__init__(season, episodes)
+        self.type = "nzbdata"
 
 
 class TorrentSearchResult(SearchResult):
@@ -138,61 +135,9 @@ class TorrentSearchResult(SearchResult):
     Torrent result with an URL to the torrent
     """
 
-    def __init__(self, episodes):
-        super(TorrentSearchResult, self).__init__(episodes)
-        self.resultType = "torrent"
-
-
-class AllShowsUI(object):
-    def __init__(self, config, log=None):
-        self.config = config
-        self.log = log
-
-    def selectSeries(self, allSeries, *args, **kwargs):
-        shows = []
-
-        # get all available shows
-        for curShow in allSeries:
-            try:
-                if not curShow['seriesname'] or curShow in shows:
-                    continue
-
-                if 'firstaired' not in curShow:
-                    curShow['firstaired'] = datetime.datetime.now().strftime("%Y-%m-%d")
-                    curShow['firstaired'] = re.sub("([-]0{2})+", "", curShow['firstaired'])
-                    fixDate = parser.parse(curShow['firstaired'], fuzzy=True).date()
-                    curShow['firstaired'] = fixDate.strftime(dateFormat)
-
-                shows += [curShow]
-            except Exception as e:
-                continue
-
-        return shows
-
-
-class ShowListUI(object):
-    """
-    Instead of prompting with a UI to pick the
-    desired result out of a list of shows it tries to be smart about it
-    based on what shows are in SiCKRAGE.
-    """
-
-    def __init__(self, config, log=None):
-        self.config = config
-        self.log = log
-
-    def selectSeries(self, allSeries, *args, **kwargs):
-        try:
-            # try to pick a show that's in my show list
-            showIDList = [int(x.indexerid) for x in sickrage.app.showlist]
-            for curShow in allSeries:
-                if int(curShow['id']) in showIDList:
-                    return curShow
-        except Exception:
-            pass
-
-        # if nothing matches then return first result
-        return allSeries[0]
+    def __init__(self, season, episodes):
+        super(TorrentSearchResult, self).__init__(season, episodes)
+        self.type = "torrent"
 
 
 class UIError(object):
@@ -223,18 +168,21 @@ class ErrorViewer(object):
     the list to be cleared.
     """
 
-    errors = []
+    def __init__(self):
+        self.errors = deque(maxlen=100)
 
     def add(self, error, ui=False):
         self.errors += [(error, UIError(error))[ui]]
 
-    @classmethod
-    def clear(cls):
-        cls.errors = []
+    def clear(self):
+        self.errors.clear()
 
     def get(self):
         return self.errors
 
+    def count(self):
+        return len(self.errors)
+
 
 class WarningViewer(object):
     """
@@ -242,31 +190,17 @@ class WarningViewer(object):
     the list to be cleared.
     """
 
-    errors = []
+    def __init__(self):
+        self.warnings = deque(maxlen=100)
 
-    def add(self, error, ui=False):
-        self.errors += [(error, UIWarning(error))[ui]]
+    def add(self, warning, ui=False):
+        self.warnings += [(warning, UIWarning(warning))[ui]]
 
-    @classmethod
-    def clear(cls):
-        cls.errors = []
+    def clear(self):
+        self.warnings.clear()
 
     def get(self):
-        return self.errors
+        return self.warnings
 
-
-class AttrDict(dict):
-    def __getattr__(self, name):
-        if name in self:
-            return self[name]
-        else:
-            raise AttributeError("No such attribute: " + name)
-
-    def __setattr__(self, name, value):
-        self[name] = value
-
-    def __delattr__(self, name):
-        if name in self:
-            del self[name]
-        else:
-            raise AttributeError("No such attribute: " + name)
+    def count(self):
+        return len(self.warnings)
