@@ -2,37 +2,30 @@
 # URL: https://sickrage.ca/
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function, unicode_literals
 
 import operator
-import os.path
 import re
+from collections import UserDict
+from functools import reduce
 
-from sickrage.core.helpers.metadata import getFileMetadata, getResolution
+import pathlib
 
-try:
-    from UserDict import UserDict
-except:
-    from collections import UserDict
-
-video_exts = ['3g2', '3gp', '3gp2', 'asf', 'avi', 'divx', 'flv', 'm4v', 'mk2',
-              'mka', 'mkv', 'mov', 'mp4', 'mp4a', 'mpeg', 'mpg', 'ogg', 'ogm',
-              'ogv', 'qt', 'ra', 'ram', 'rm', 'ts', 'wav', 'webm', 'wma', 'wmv']
+from sickrage.core.helpers.metadata import get_file_metadata, get_resolution
 
 ### CPU Presets for sleep timers
 cpu_presets = {
@@ -43,8 +36,7 @@ cpu_presets = {
 
 countryList = {'Australia': 'AU',
                'Canada': 'CA',
-               'USA': 'US'
-               }
+               'USA': 'US'}
 
 dateFormat = '%Y-%m-%d'
 dateTimeFormat = '%Y-%m-%d %H:%M:%S'
@@ -110,16 +102,22 @@ class Quality(object):
     UNKNOWN = 1 << 15  # 32768
 
     qualitySizes = {NONE: 0,
-                    UNKNOWN: 0,
-                    SDTV: 700,
-                    SDDVD: 700,
-                    HDTV: 1200,
-                    RAWHDTV: 1200,
-                    FULLHDTV: 1200,
-                    HDWEBDL: 1200,
-                    FULLHDWEBDL: 1400,
-                    HDBLURAY: 1200,
-                    FULLHDBLURAY: 1400}
+                    UNKNOWN: 500,
+                    SDTV: 1200,
+                    SDDVD: 1200,
+                    HDTV: 1500,
+                    RAWHDTV: 1500,
+                    FULLHDTV: 1500,
+                    HDWEBDL: 1500,
+                    FULLHDWEBDL: 1800,
+                    HDBLURAY: 1500,
+                    FULLHDBLURAY: 1800,
+                    UHD_4K_TV: 8000,
+                    UHD_8K_TV: 16000,
+                    UHD_4K_WEBDL: 8000,
+                    UHD_8K_WEBDL: 16000,
+                    UHD_4K_BLURAY: 8000,
+                    UHD_8K_BLURAY: 16000}
 
     qualityStrings = {NONE: "N/A",
                       UNKNOWN: "Unknown",
@@ -188,10 +186,10 @@ class Quality(object):
                       SNATCHED_BEST: _("Snatched (Best)"),
                       ARCHIVED: _("Archived"),
                       FAILED: _("Failed"),
-                      MISSED: _("Missed"),}
+                      MISSED: _("Missed"), }
 
     @staticmethod
-    def _getStatusStrings(status):
+    def _get_status_strings(status):
         """
         Returns string values associated with Status prefix
 
@@ -200,22 +198,24 @@ class Quality(object):
         """
         toReturn = {}
         for q in Quality.qualityStrings.keys():
-            toReturn[Quality.compositeStatus(status, q)] = Quality.statusPrefixes[status] + " (" + \
-                                                           Quality.qualityStrings[q] + ")"
+            toReturn[Quality.composite_status(status, q)] = Quality.statusPrefixes[status] + " (" + \
+                                                            Quality.qualityStrings[q] + ")"
         return toReturn
 
     @staticmethod
-    def combineQualities(anyQualities, bestQualities):
+    def combine_qualities(anyQualities, bestQualities):
         anyQuality = 0
         bestQuality = 0
+
         if anyQualities:
-            anyQuality = reduce(operator.or_, anyQualities)
+            anyQuality = reduce(operator.or_, anyQualities, anyQuality)
         if bestQualities:
-            bestQuality = reduce(operator.or_, bestQualities)
+            bestQuality = reduce(operator.or_, bestQualities, bestQuality)
+
         return anyQuality | (bestQuality << 16)
 
     @staticmethod
-    def splitQuality(quality):
+    def split_quality(quality):
         anyQualities = []
         bestQualities = []
 
@@ -228,7 +228,7 @@ class Quality(object):
         return sorted(anyQualities), sorted(bestQualities)
 
     @staticmethod
-    def nameQuality(name, anime=False):
+    def name_quality(name, anime=False):
         """
         Return The quality from an episode File renamed by SiCKRAGE
         If no quality is achieved it will try sceneQuality regex
@@ -238,11 +238,11 @@ class Quality(object):
         """
 
         # Try Scene names first
-        quality = Quality.sceneQuality(name, anime)
+        quality = Quality.scene_quality(name, anime)
         if quality != Quality.UNKNOWN:
             return quality
 
-        quality = Quality.qualityFromFileMeta(name)
+        quality = Quality.quality_from_file_meta(name)
         if quality != Quality.UNKNOWN:
             return quality
 
@@ -252,7 +252,7 @@ class Quality(object):
         return Quality.UNKNOWN
 
     @staticmethod
-    def sceneQuality(name, anime=False):
+    def scene_quality(name, anime=False):
         """
         Return The quality from the scene episode File
 
@@ -267,7 +267,7 @@ class Quality(object):
         if not name:
             return ret
 
-        name = os.path.basename(name)
+        name = pathlib.Path(name).name
 
         check_name = lambda l, func: func([re.search(x, name, re.I) for x in l])
 
@@ -295,14 +295,12 @@ class Quality(object):
 
             return ret
 
-        if (check_name(
-                [r"480p|\bweb\b|web.?dl|web(rip|mux|hd)|[sph]d.?tv|dsr|tv(rip|mux)|satrip", r"xvid|divx|[xh].?26[45]"],
-                all)
-                and not check_name([r"(720|1080)[pi]"], all)
+        if (check_name([r"480p|\bweb\b|web.?dl|web(rip|mux|hd)|[sph]d.?tv|dsr|tv(rip|mux)|satrip", r"xvid|divx|[xh].?26[45]"], all)
+                and not check_name([r"(720|1080|2160|4320)[pi]"], all)
                 and not check_name([r"hr.ws.pdtv.[xh].?26[45]"], any)):
             ret = Quality.SDTV
         elif (check_name([r"dvd(rip|mux)|b[rd](rip|mux)|blue?-?ray", r"xvid|divx|[xh].?26[45]"], all)
-              and not check_name([r"(720|1080)[pi]"], all)
+              and not check_name([r"(720|1080|2160|4320)[pi]"], all)
               and not check_name([r"hr.ws.pdtv.[xh].?26[45]"], any)):
             ret = Quality.SDDVD
         elif (check_name([r"720p", r"hd.?tv", r"[xh].?26[45]"], all)
@@ -343,15 +341,15 @@ class Quality(object):
         return ret
 
     @staticmethod
-    def compositeStatus(status, quality):
+    def composite_status(status, quality):
         return status + 100 * quality
 
     @staticmethod
-    def qualityDownloaded(status):
+    def quality_downloaded(status):
         return (status - DOWNLOADED) / 100
 
     @staticmethod
-    def splitCompositeStatus(status):
+    def split_composite_status(status):
         """Returns a tuple containing (status, quality)"""
         if status == UNKNOWN:
             return UNKNOWN, Quality.UNKNOWN
@@ -363,17 +361,17 @@ class Quality(object):
         return status, Quality.NONE
 
     @staticmethod
-    def statusFromCompositeStatus(status):
-        status, quality = Quality.splitCompositeStatus(status)
+    def status_from_composite_status(status):
+        status, quality = Quality.split_composite_status(status)
         return status
 
     @staticmethod
-    def qualityFromCompositeStatus(status):
-        status, quality = Quality.splitCompositeStatus(status)
+    def quality_from_composite_status(status):
+        status, quality = Quality.split_composite_status(status)
         return quality
 
     @staticmethod
-    def qualityFromFileMeta(filename):
+    def quality_from_file_meta(filename):
         """
         Get quality from file metadata
 
@@ -384,39 +382,39 @@ class Quality(object):
         data = {}
         quality = Quality.UNKNOWN
 
-        if os.path.isfile(filename):
-            meta = getFileMetadata(filename)
+        try:
+            if pathlib.Path(filename).is_file():
+                meta = get_file_metadata(filename)
 
-            try:
-                if meta.get('resolution_width'):
+                if meta.get('resolution_width') and meta.get('resolution_height'):
                     data['resolution_width'] = meta.get('resolution_width')
                     data['resolution_height'] = meta.get('resolution_height')
                     data['aspect'] = round(float(meta.get('resolution_width')) / meta.get('resolution_height', 1), 2)
                 else:
-                    data.update(getResolution(filename))
-            except:
-                return quality
+                    data.update(get_resolution(filename))
 
-            base_filename = os.path.basename(filename)
-            bluray = re.search(r"blue?-?ray|hddvd|b[rd](rip|mux)", base_filename, re.I) is not None
-            webdl = re.search(r"\bweb\b|web.?dl|web(rip|mux|hd)", base_filename, re.I) is not None
+                base_filename = pathlib.Path(filename).name
+                bluray = re.search(r"blue?-?ray|hddvd|b[rd](rip|mux)", base_filename, re.I) is not None
+                webdl = re.search(r"\bweb\b|web.?dl|web(rip|mux|hd)", base_filename, re.I) is not None
 
-            if 3240 < data['resolution_height']:
-                ret = ((Quality.UHD_8K_TV, Quality.UHD_8K_BLURAY)[bluray], Quality.UHD_8K_WEBDL)[webdl]
-            if 1620 < data['resolution_height'] <= 3240:
-                ret = ((Quality.UHD_4K_TV, Quality.UHD_4K_BLURAY)[bluray], Quality.UHD_4K_WEBDL)[webdl]
-            elif 800 < data['resolution_height'] <= 1620:
-                quality = ((Quality.FULLHDTV, Quality.FULLHDBLURAY)[bluray], Quality.FULLHDWEBDL)[webdl]
-            elif 680 < data['resolution_height'] < 800:
-                quality = ((Quality.HDTV, Quality.HDBLURAY)[bluray], Quality.HDWEBDL)[webdl]
-            elif data['resolution_height'] < 680:
-                quality = (Quality.SDTV, Quality.SDDVD)[
-                    re.search(r'dvd|b[rd]rip|blue?-?ray', base_filename, re.I) is not None]
+                if 3240 < data['resolution_height']:
+                    quality = ((Quality.UHD_8K_TV, Quality.UHD_8K_BLURAY)[bluray], Quality.UHD_8K_WEBDL)[webdl]
+                if 1620 < data['resolution_height'] <= 3240:
+                    quality = ((Quality.UHD_4K_TV, Quality.UHD_4K_BLURAY)[bluray], Quality.UHD_4K_WEBDL)[webdl]
+                elif 800 < data['resolution_height'] <= 1620:
+                    quality = ((Quality.FULLHDTV, Quality.FULLHDBLURAY)[bluray], Quality.FULLHDWEBDL)[webdl]
+                elif 680 < data['resolution_height'] < 800:
+                    quality = ((Quality.HDTV, Quality.HDBLURAY)[bluray], Quality.HDWEBDL)[webdl]
+                elif data['resolution_height'] < 680:
+                    quality = (Quality.SDTV, Quality.SDDVD)[
+                        re.search(r'dvd|b[rd]rip|blue?-?ray', base_filename, re.I) is not None]
+        except Exception:
+            pass
 
         return quality
 
     @staticmethod
-    def sceneQualityFromName(name, quality):
+    def scene_quality_from_name(name, quality):
         """
         Get scene naming parameters from filename and quality
 
@@ -476,7 +474,7 @@ class Quality(object):
             return ""
 
     @staticmethod
-    def statusFromName(name, assume=True, anime=False):
+    def status_from_name(name, assume=True, anime=False):
         """
         Get a status object from filename
 
@@ -485,8 +483,8 @@ class Quality(object):
         :param anime: boolean to enable anime parsing
         :return: Composite status/quality object
         """
-        quality = Quality.nameQuality(name, anime)
-        return Quality.compositeStatus(DOWNLOADED, quality)
+        quality = Quality.name_quality(name, anime)
+        return Quality.composite_status(DOWNLOADED, quality)
 
     DOWNLOADED = None
     SNATCHED = None
@@ -497,13 +495,13 @@ class Quality(object):
     IGNORED = None
 
 
-Quality.DOWNLOADED = [Quality.compositeStatus(DOWNLOADED, x) for x in Quality.qualityStrings.keys()]
-Quality.SNATCHED = [Quality.compositeStatus(SNATCHED, x) for x in Quality.qualityStrings.keys()]
-Quality.SNATCHED_PROPER = [Quality.compositeStatus(SNATCHED_PROPER, x) for x in Quality.qualityStrings.keys()]
-Quality.SNATCHED_BEST = [Quality.compositeStatus(SNATCHED_BEST, x) for x in Quality.qualityStrings.keys()]
-Quality.ARCHIVED = [Quality.compositeStatus(ARCHIVED, x) for x in Quality.qualityStrings.keys()]
-Quality.FAILED = [Quality.compositeStatus(FAILED, x) for x in Quality.qualityStrings.keys()]
-Quality.IGNORED = [Quality.compositeStatus(IGNORED, x) for x in Quality.qualityStrings.keys()]
+Quality.DOWNLOADED = [Quality.composite_status(DOWNLOADED, x) for x in Quality.qualityStrings.keys()]
+Quality.SNATCHED = [Quality.composite_status(SNATCHED, x) for x in Quality.qualityStrings.keys()]
+Quality.SNATCHED_PROPER = [Quality.composite_status(SNATCHED_PROPER, x) for x in Quality.qualityStrings.keys()]
+Quality.SNATCHED_BEST = [Quality.composite_status(SNATCHED_BEST, x) for x in Quality.qualityStrings.keys()]
+Quality.ARCHIVED = [Quality.composite_status(ARCHIVED, x) for x in Quality.qualityStrings.keys()]
+Quality.FAILED = [Quality.composite_status(FAILED, x) for x in Quality.qualityStrings.keys()]
+Quality.IGNORED = [Quality.composite_status(IGNORED, x) for x in Quality.qualityStrings.keys()]
 
 Quality.DOWNLOADED.sort()
 Quality.SNATCHED.sort()
@@ -512,18 +510,19 @@ Quality.SNATCHED_PROPER.sort()
 Quality.FAILED.sort()
 Quality.ARCHIVED.sort()
 
-HD720p = Quality.combineQualities([Quality.HDTV, Quality.HDWEBDL, Quality.HDBLURAY], [])
-HD1080p = Quality.combineQualities([Quality.FULLHDTV, Quality.FULLHDWEBDL, Quality.FULLHDBLURAY], [])
-UHD_4K = Quality.combineQualities([Quality.UHD_4K_TV, Quality.UHD_4K_WEBDL, Quality.UHD_4K_BLURAY], [])
-UHD_8K = Quality.combineQualities([Quality.UHD_8K_TV, Quality.UHD_8K_WEBDL, Quality.UHD_8K_BLURAY], [])
+HD720p = Quality.combine_qualities([Quality.HDTV, Quality.HDWEBDL, Quality.HDBLURAY], [])
+HD1080p = Quality.combine_qualities([Quality.FULLHDTV, Quality.FULLHDWEBDL, Quality.FULLHDBLURAY], [])
+UHD_4K = Quality.combine_qualities([Quality.UHD_4K_TV, Quality.UHD_4K_WEBDL, Quality.UHD_4K_BLURAY], [])
+UHD_8K = Quality.combine_qualities([Quality.UHD_8K_TV, Quality.UHD_8K_WEBDL, Quality.UHD_8K_BLURAY], [])
 
-SD = Quality.combineQualities([Quality.SDTV, Quality.SDDVD], [])
-HD = Quality.combineQualities([HD720p, HD1080p], [])
-UHD = Quality.combineQualities([UHD_4K, UHD_8K], [])
-ANY = Quality.combineQualities([SD, HD], [])
+SD = Quality.combine_qualities([Quality.SDTV, Quality.SDDVD], [])
+HD = Quality.combine_qualities([HD720p, HD1080p, Quality.RAWHDTV], [])
+UHD = Quality.combine_qualities([UHD_4K, UHD_8K], [])
+ANY = Quality.combine_qualities([SD, HD, UHD], [])
+ANY_PLUS_UNKNOWN = Quality.combine_qualities([Quality.UNKNOWN, SD, HD, UHD], [])
 
 # legacy template, cant remove due to reference in mainDB upgrade?
-BEST = Quality.combineQualities([Quality.SDTV, Quality.HDTV, Quality.HDWEBDL], [Quality.HDTV])
+BEST = Quality.combine_qualities([Quality.SDTV, Quality.HDTV, Quality.HDWEBDL], [Quality.HDTV])
 
 qualityPresets = (SD,
                   HD,
@@ -532,7 +531,8 @@ qualityPresets = (SD,
                   UHD,
                   UHD_4K,
                   UHD_8K,
-                  ANY)
+                  ANY,
+                  ANY_PLUS_UNKNOWN)
 
 qualityPresetStrings = {SD: "SD",
                         HD: "HD",
@@ -541,7 +541,8 @@ qualityPresetStrings = {SD: "SD",
                         UHD: "UHD",
                         UHD_4K: "UHD-4K",
                         UHD_8K: "UHD-8K",
-                        ANY: "Any"}
+                        ANY: "Any",
+                        ANY_PLUS_UNKNOWN: "Any + Unknown"}
 
 
 class StatusStrings(UserDict):
@@ -554,14 +555,14 @@ class StatusStrings(UserDict):
     Membership checks using __contains__ (i.e. 'x in y') do not raise a ValueError to match expected dict functionality
     """
 
-    # todo: Deprecate StatusStrings().statusStrings and use StatusStrings() directly
+    # todo: Deprecate StatusStrings().status_strings and use StatusStrings() directly
     # todo: Deprecate .has_key and switch to 'x in y'
     # todo: Switch from raising ValueError to a saner KeyError
     # todo: Raise KeyError when unable to resolve a missing key instead of returning ''
     # todo: Make key of None match dict() functionality
 
     @property
-    def statusStrings(self):  # for backwards compatibility
+    def status_strings(self):  # for backwards compatibility
         return self.data
 
     def __setitem__(self, key, value):
@@ -575,8 +576,9 @@ class StatusStrings(UserDict):
         the old StatusStrings is fully deprecated, then we will raise a KeyError instead, where appropriate.
         """
         if isinstance(key, int):  # if the key is already an int...
-            if key in self.keys() + Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED + Quality.FAILED:
-                status, quality = Quality.splitCompositeStatus(key)
+            if key in list(
+                    self.keys()) + Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED + Quality.FAILED:
+                status, quality = Quality.split_composite_status(key)
                 if quality == Quality.NONE:  # If a Quality is not listed... (shouldn't this be 'if not quality:'?)
                     return self[status]  # ...return the status...
                 else:
@@ -607,7 +609,8 @@ class StatusStrings(UserDict):
         try:
             # This will raise a ValueError if we can't convert the key to int
             return ((int(key) in self.data) or
-                    (int(key) in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED + Quality.FAILED))
+                    (int(
+                        key) in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED + Quality.FAILED))
         except ValueError:  # The key is not numeric and since we only want numeric keys...
             # ...and we don't want this function to fail...
             pass  # ...suppress the ValueError and do nothing, the key does not exist
