@@ -4,7 +4,6 @@ from base64 import b64decode
 from tornado.escape import json_encode
 
 import sickrage
-from sickrage.core.api.google import GoogleDriveAPI
 
 currentInfo = ''
 percentDone = 0
@@ -28,7 +27,7 @@ class GoogleDrive(object):
 
     def walk_drive(self, folder_id):
         dirs, nondirs = {}, {}
-        for item in GoogleDriveAPI().list_files(folder_id)['data']:
+        for item in sickrage.app.api.google.list_files(folder_id)['data']:
             if item['type'] == "application/vnd.google-apps.folder":
                 dirs.update({str(item['id']): item['name']})
             else:
@@ -42,7 +41,7 @@ class GoogleDrive(object):
 
     def sync_remote(self):
         main_folder = 'appDataFolder'
-        folder_id = GoogleDriveAPI().search_files(main_folder, sickrage.app.config.app_id)['data']
+        folder_id = sickrage.app.api.google.search_files(main_folder, sickrage.app.config.sub_id)['data']
 
         local_dirs = set()
         local_files = set()
@@ -52,28 +51,28 @@ class GoogleDrive(object):
             local_dirs.update(dirs)
             local_files.update(files)
 
-            folder = root.replace(sickrage.app.data_dir, '{}/{}'.format(main_folder, sickrage.app.config.app_id))
+            folder = root.replace(sickrage.app.data_dir, '{}/{}'.format(main_folder, sickrage.app.config.sub_id))
             folder = folder.replace('\\', '/')
             for f in files:
                 self.set_progress('Syncing {} to Google Drive'.format(os.path.join(root, f)), 0)
-                GoogleDriveAPI().upload(os.path.join(root, f), folder)
+                sickrage.app.api.google.upload(os.path.join(root, f), folder)
 
         # removing deleted local folders/files from google drive
         for drive_root, drive_folders, drive_files in self.walk_drive(folder_id):
             for folder_id, folder_name in drive_folders.items():
                 if folder_name not in local_dirs:
-                    GoogleDriveAPI().delete(folder_id)
+                    sickrage.app.api.google.delete(folder_id)
 
             for file_id, file_name in drive_files.items():
                 if file_name not in local_files:
-                    GoogleDriveAPI().delete(file_id)
+                    sickrage.app.api.google.delete(file_id)
 
     def sync_local(self):
         main_folder = 'appDataFolder'
-        folder_id = GoogleDriveAPI().search_files(main_folder, sickrage.app.config.app_id)['data']
+        folder_id = sickrage.app.api.google.search_files(main_folder, sickrage.app.config.sub_id)['data']
 
         for drive_root, drive_folders, drive_files in self.walk_drive(folder_id):
             folder = drive_root.replace(folder_id, sickrage.app.data_dir)
             folder = folder.replace('/', '\\')
             for file_id, name in drive_files.items():
-                content = b64decode(GoogleDriveAPI().download(file_id)).strip()
+                content = b64decode(sickrage.app.api.google.download(file_id)).strip()
