@@ -2,27 +2,25 @@
 # URL: https://sickrage.ca
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import locale
 
 import sickrage
-from sickrage.core.helpers import encoding
 
 date_presets = (
     '%Y-%m-%d',
@@ -90,11 +88,14 @@ date_presets = (
 time_presets = ('%I:%M:%S %p', '%H:%M:%S')
 
 
-class srDateTime(object):
+class SRDateTime(object):
     def __init__(self, dt, convert=False):
         self.dt = dt
         if convert and sickrage.app.config.timezone_display == 'local':
-            self.dt = dt.astimezone(sickrage.app.tz)
+            try:
+                self.dt = dt.astimezone(sickrage.app.tz)
+            except Exception as e:
+                pass
 
         self.has_locale = True
         self.en_US_norm = locale.normalize('en_US.utf-8')
@@ -140,7 +141,7 @@ class srDateTime(object):
             except Exception:
                 self.has_locale = False
 
-        return encoding.to_unicode(strt)
+        return strt
 
     # display Date in SickRage Format
     def srfdate(self, d_preset=None):
@@ -179,7 +180,7 @@ class srDateTime(object):
             except Exception:
                 pass
 
-        return encoding.to_unicode(strd)
+        return strd
 
     # display Datetime in SickRage Format
     def srfdatetime(self, show_seconds=False, d_preset=None, t_preset=None):
@@ -228,4 +229,4 @@ class srDateTime(object):
             except Exception:
                 self.has_locale = False
 
-        return encoding.to_unicode(strd)
+        return strd
