@@ -1,22 +1,24 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import datetime
 import os
@@ -49,8 +51,8 @@ class imdbPopular(object):
 
         try:
             data = WebSession().get(self.url,
-                                                    headers={'Referer': 'http://akas.imdb.com/'},
-                                                    params=self.params).text
+                                    headers={'Referer': 'http://akas.imdb.com/'},
+                                    params=self.params).text
         except Exception:
             return None
 
