@@ -1,23 +1,25 @@
 # -*- coding: utf-8 -*-
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 # all regexes are case insensitive
 
@@ -218,6 +220,20 @@ anime_regexes = [
      (?:(?:(?:[\[\(])(?P<extra_info>\d{3,4}[xp]?\d{0,4}[\.\w\s-]*)(?:[\]\)]))|(?:\d{3,4}[xp]))
      .*?
      '''),
+    ('anime_erai-raws',
+     # [Erai-raws] Full Metal Panic! Invisible Victory - 12 END [1080p].mkv
+     # [Erai-raws] A.I.C.O. Incarnation - 01 [1080p][Multiple Subtitle].mkv
+     r'''
+     ^(?:\[(?P<release_group>Erai-raws)\][\s\.])
+     (?:(?P<series_name>.+?)[\s\.]-[\s\.])
+     (?P<ep_ab_num>((?!(1080|720|480)[pi]))\d{1,3})
+     (-(?P<extra_ab_ep_num>((?!(1080|720|480)[pi])|(?![hx].?264))\d{1,3}))?
+     (?:v(?P<version>[0-9]))?
+     (?:[\w\.\s]*)
+     (?:(?:(?:[\[\(])(?P<extra_info>\d{3,4}[xp]?\d{0,4}[\.\w\s-]*)(?:[\]\)]))|(?:\d{3,4}[xp]))
+     (?:\[(?P<subs>.+?)?\])?
+     .*?
+     '''),
     ('anime_ultimate',
      r'''
      ^(?:\[(?P<release_group>.+?)\][ ._-]*)
@@ -277,16 +293,17 @@ anime_regexes = [
      '''),
     ('anime_standard_round',
      # [Stratos-Subs]_Infinite_Stratos_-_12_(1280x720_H.264_AAC)_[379759DB]
+     # [Stratos-Subs]_Infinite_Stratos_-_12_(1280x720_H.264_AAC) [379759DB]
      # [ShinBunBu-Subs] Bleach - 02-03 (CX 1280x720 x264 AAC)
      r'''
-     ^(\[(?P<release_group>.+?)\][ ._-]*)?                                    # Release Group and separator
-     (?P<series_name>.+?)[ ._-]+                                              # Show_Name and separator
-     (?P<ep_ab_num>((?!(1080|720|480)[pi])|(?![hx].?264))\d{1,3})                                                   # E01
-     (-(?P<extra_ab_ep_num>((?!(1080|720|480)[pi])|(?![hx].?264))\d{1,3}))?                                         # E02
-     (v(?P<version>[0-9]))?                                                   # version
-     [ ._-]+\((?P<extra_info>(CX[ ._-]?)?\d{3,4}[xp]?\d{0,4}[\.\w\s-]*)\)     # Source_Quality_Etc-
-     (\[(?P<crc>\w{8})\])?                                                    # CRC
-     .*?                                                                      # Separator and EOL
+     ^(\[(?P<release_group>.+?)\][ ._-]*)?                                        # Release Group and separator
+     (?P<series_name>.+?)[ ._-]+                                                  # Show_Name and separator
+     (?P<ep_ab_num>((?!(1080|720|480)[pi])|(?![hx].?264))\d{1,3})                 # E01
+     (-(?P<extra_ab_ep_num>((?!(1080|720|480)[pi])|(?![hx].?264))\d{1,3}))?       # E02
+     (v(?P<version>[0-9]))?                                                       # version
+     [ ._-]+\((?P<extra_info>(\w+[ ._-]?)?\d{3,4}[xp]?\d{0,4}[\.\w\s-]*)\)[ ._-]+ # Source_Quality_Etc-
+     (\[(?P<crc>\w{8})\])?                                                        # CRC
+     .*?                                                                          # Separator and EOL
      '''),
     ('anime_slash',
      # [SGKK] Bleach 312v1 [720p/MKV]
