@@ -2,30 +2,29 @@
 # URL: https://sickrage.ca
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import unicode_literals
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
+import datetime
 import os
 from datetime import date
 
 import sickrage
 from sickrage.core.common import DOWNLOADED, Quality
 from sickrage.core.nameparser import NameParser
-from sickrage.core.nameparser.episode import Episode
+from sickrage.core.tv.episode import TVEpisode
 
 name_presets = (
     '%SN - %Sx%0E - %EN',
@@ -50,6 +49,81 @@ name_sports_presets = (
 )
 
 
+class FakeEpisode(object):
+    def __init__(self, season, episode, absolute_number, name):
+        self.name = name
+        self.season = season
+        self.episode = episode
+        self.absolute_number = absolute_number
+        self.airdate = datetime.date(2010, 3, 9)
+        self.status = Quality.composite_status(DOWNLOADED, Quality.SDTV)
+        self.release_name = 'Show.Name.S02E03.HDTV.XviD-RLSGROUP'
+        self.release_group = 'RLSGROUP'
+        self.is_proper = True
+
+        self.show = FakeShow()
+        self.scene_season = season
+        self.scene_episode = episode
+        self.scene_absolute_number = absolute_number
+        self.related_episodes = []
+
+        self.session = sickrage.app.main_db.session()
+
+    def formatted_filename(self, *args, **kwargs):
+        return TVEpisode.formatted_filename(self, *args, **kwargs)
+
+    def _format_pattern(self, *args, **kwargs):
+        return TVEpisode._format_pattern(self, *args, **kwargs)
+
+    def _replace_map(self):
+        return TVEpisode._replace_map(self)
+
+    def _ep_name(self):
+        return TVEpisode._ep_name(self)
+
+    def _format_string(self, *args, **kwargs):
+        return TVEpisode._format_string(self, *args, **kwargs)
+
+    def formatted_dir(self, *args, **kwargs):
+        return TVEpisode.formatted_dir(self, *args, **kwargs)
+
+
+class FakeShow(object):
+    def __init__(self):
+        self.name = "Show Name"
+        self.genre = "Comedy"
+        self.indexer_id = 0o00001
+        self.air_by_date = 0
+        self.startyear = 2011
+        self.sports = 0
+        self.anime = 0
+        self.scene = 0
+
+    @property
+    def is_anime(self):
+        """
+        Find out if show is anime
+        :return: True if show is anime, False if not
+        """
+        return self.anime > 0
+
+    @property
+    def is_sports(self):
+        """
+        Find out if show is sports
+        :return: True if show is sports, False if not
+        """
+        return self.sports > 0
+
+    @property
+    def is_scene(self):
+        """
+        Find out if show is scene numbering
+        :return: True if show is scene numbering, False if not
+        """
+        return self.scene > 0
+
+
 def check_force_season_folders(pattern=None, multi=None, anime_type=None):
     """
     Checks if the name can still be parsed if you strip off the folders to determine if we need to force season folders
@@ -145,7 +219,7 @@ def validate_name(pattern, multi=None, anime_type=None, file_only=False, abd=Fal
 
     sickrage.app.log.debug("Trying to parse " + new_name)
 
-    parser = NameParser(True, showObj=ep.show, naming_pattern=True)
+    parser = NameParser(True, show_id=ep.show.indexer_id, naming_pattern=True)
 
     try:
         result = parser.parse(new_name)
@@ -161,14 +235,14 @@ def validate_name(pattern, multi=None, anime_type=None, file_only=False, abd=Fal
             return False
     elif anime_type != 3:
         if len(result.ab_episode_numbers) and result.ab_episode_numbers != [x.absolute_number for x in
-                                                                            [ep] + ep.relatedEps]:
+                                                                            [ep] + ep.related_episodes]:
             sickrage.app.log.debug("Absolute numbering incorrect in parsed episode, pattern isn't valid")
             return False
     else:
         if result.season_number != ep.season:
             sickrage.app.log.debug("Season number incorrect in parsed episode, pattern isn't valid")
             return False
-        if result.episode_numbers != [x.episode for x in [ep] + ep.relatedEps]:
+        if result.episode_numbers != [x.episode for x in [ep] + ep.related_episodes]:
             sickrage.app.log.debug("Episode numbering incorrect in parsed episode, pattern isn't valid")
             return False
 
@@ -177,50 +251,50 @@ def validate_name(pattern, multi=None, anime_type=None, file_only=False, abd=Fal
 
 def generate_sample_ep(multi=None, abd=False, sports=False, anime_type=None):
     # make a fake episode object
-    ep = Episode(2, 3, 3, "Ep Name")
+    ep = FakeEpisode(2, 3, 3, "Ep Name")
 
-    ep._status = Quality.compositeStatus(DOWNLOADED, Quality.HDTV)
-    ep._airdate = date(2011, 3, 9)
+    ep.status = Quality.composite_status(DOWNLOADED, Quality.HDTV)
+    ep.airdate = date(2011, 3, 9)
 
     if abd:
-        ep._release_name = 'Show.Name.2011.03.09.HDTV.XviD-RLSGROUP'
+        ep.release_name = 'Show.Name.2011.03.09.HDTV.XviD-RLSGROUP'
         ep.show.air_by_date = 1
     elif sports:
-        ep._release_name = 'Show.Name.2011.03.09.HDTV.XviD-RLSGROUP'
+        ep.release_name = 'Show.Name.2011.03.09.HDTV.XviD-RLSGROUP'
         ep.show.sports = 1
     else:
         if anime_type != 3:
             ep.show.anime = 1
-            ep._release_name = 'Show.Name.003.HDTV.XviD-RLSGROUP'
+            ep.release_name = 'Show.Name.003.HDTV.XviD-RLSGROUP'
         else:
-            ep._release_name = 'Show.Name.S02E03.HDTV.XviD-RLSGROUP'
+            ep.release_name = 'Show.Name.S02E03.HDTV.XviD-RLSGROUP'
 
     if multi is not None:
-        ep._name = "Ep Name (1)"
+        ep.name = "Ep Name (1)"
 
         if anime_type != 3:
             ep.show.anime = 1
 
-            ep._release_name = 'Show.Name.003-004.HDTV.XviD-RLSGROUP'
+            ep.release_name = 'Show.Name.003-004.HDTV.XviD-RLSGROUP'
 
-            second_ep = Episode(2, 4, 4, "Ep Name (2)")
-            second_ep._status = Quality.compositeStatus(DOWNLOADED, Quality.HDTV)
-            second_ep._release_name = ep.release_name
+            second_ep = FakeEpisode(2, 4, 4, "Ep Name (2)")
+            second_ep.status = Quality.composite_status(DOWNLOADED, Quality.HDTV)
+            second_ep.release_name = ep.release_name
 
-            ep.relatedEps.append(second_ep)
+            ep.related_episodes.append(second_ep)
         else:
-            ep._release_name = 'Show.Name.S02E03E04E05.HDTV.XviD-RLSGROUP'
+            ep.release_name = 'Show.Name.S02E03E04E05.HDTV.XviD-RLSGROUP'
 
-            second_ep = Episode(2, 4, 4, "Ep Name (2)")
-            second_ep._status = Quality.compositeStatus(DOWNLOADED, Quality.HDTV)
-            second_ep._release_name = ep.release_name
+            second_ep = FakeEpisode(2, 4, 4, "Ep Name (2)")
+            second_ep.status = Quality.composite_status(DOWNLOADED, Quality.HDTV)
+            second_ep.release_name = ep.release_name
 
-            third_ep = Episode(2, 5, 5, "Ep Name (3)")
-            third_ep._status = Quality.compositeStatus(DOWNLOADED, Quality.HDTV)
-            third_ep._release_name = ep.release_name
+            third_ep = FakeEpisode(2, 5, 5, "Ep Name (3)")
+            third_ep.status = Quality.composite_status(DOWNLOADED, Quality.HDTV)
+            third_ep.release_name = ep.release_name
 
-            ep.relatedEps.append(second_ep)
-            ep.relatedEps.append(third_ep)
+            ep.related_episodes.append(second_ep)
+            ep.related_episodes.append(third_ep)
 
     return ep
 
