@@ -2,32 +2,31 @@
 # URL: https://sickrage.ca
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
-import io
 import re
 from xml.etree import ElementTree
 
-import classes
 import sickrage
+from sickrage.core.classes import NZBDataSearchResult
 from sickrage.core.common import Quality
 from sickrage.core.nameparser import InvalidNameException, InvalidShowException, \
     NameParser
+from sickrage.core.tv.show.helpers import find_show
 from sickrage.core.websession import WebSession
 
 
@@ -41,22 +40,20 @@ def getSeasonNZBs(name, urlData, season):
     :return: dict of (episode files, xml matches)
     """
     try:
-        showXML = ElementTree.parse(urlData)
+        nzbElement = ElementTree.fromstring(urlData)
     except SyntaxError:
         sickrage.app.log.error("Unable to parse the XML of " + name + ", not splitting it")
         return {}, ''
 
     filename = name.replace(".nzb", "")
 
-    nzbElement = showXML.getroot()
-
     regex = '([\w\._\ ]+)[\. ]S%02d[\. ]([\w\._\-\ ]+)[\- ]([\w_\-\ ]+?)' % season
 
     sceneNameMatch = re.search(regex, filename, re.I)
     if sceneNameMatch:
         showName, qualitySection, groupName = sceneNameMatch.groups()
     else:
-        sickrage.app.log.error("Unable to parse " + name + " into a scene name. If it's a valid one log a bug.")
+        sickrage.app.log.error("Unable to parse " + name + " into a scene name. If it's a valid, log a bug.")
         return {}, ''
 
     regex = '(' + re.escape(showName) + '\.S%02d(?:[E0-9]+)\.[\w\._]+\-\w+' % season + ')'
@@ -66,7 +63,7 @@ def getSeasonNZBs(name, urlData, season):
     xmlns = None
 
     for curFile in nzbElement.getchildren():
-        xmlnsMatch = re.match("\{(http://[A-Za-z0-9_\./]+/nzb)\}file", curFile.tag)
+        xmlnsMatch = re.match("{(http://[A-Za-z0-9_./]+/nzb)\}file", curFile.tag)
         if not xmlnsMatch:
             continue
         else:
@@ -103,11 +100,11 @@ def saveNZB(nzbName, nzbString):
     :param nzbString: Content to write in file
     """
     try:
-        with io.open(nzbName + ".nzb", 'w') as nzb_fh:
+        with open(nzbName + ".nzb", 'w') as nzb_fh:
             nzb_fh.write(nzbString)
 
     except EnvironmentError as e:
-        sickrage.app.log.error("Unable to save NZB: {}".format(e))
+        sickrage.app.log.warning("Unable to save NZB: {}".format(e))
 
 
 def stripNS(element, ns):
@@ -118,22 +115,22 @@ def stripNS(element, ns):
     return element
 
 
-def splitNZBResult(result):
+def split_nzb_result(result):
     """
-    Split result into seperate episodes
+    Split result into separate episodes
 
     :param result: search result object
     :return: False upon failure, a list of episode objects otherwise
     """
-    urlData = WebSession().get(result.url, needBytes=True)
-    if urlData is None:
+    try:
+        url_data = WebSession().get(result.url, needBytes=True).text
+    except Exception:
         sickrage.app.log.error("Unable to load url " + result.url + ", can't download season NZB")
         return False
 
     # parse the season ep name
     try:
-        np = NameParser(False, showObj=result.show)
-        parse_result = np.parse(result.name)
+        parse_result = NameParser(False, show_id=result.show_id).parse(result.name)
     except InvalidNameException:
         sickrage.app.log.debug("Unable to parse the filename " + result.name + " into a valid episode")
         return False
@@ -143,60 +140,48 @@ def splitNZBResult(result):
 
     # bust it up
     season = parse_result.season_number if parse_result.season_number is not None else 1
+    separate_nzbs, xmlns = getSeasonNZBs(result.name, url_data, season)
 
-    separateNZBs, xmlns = getSeasonNZBs(result.name, urlData, season)
-
-    resultList = []
-
-    for newNZB in separateNZBs:
-
-        sickrage.app.log.debug("Split out " + newNZB + " from " + result.name)
+    result_list = []
+    for newNZB in separate_nzbs:
+        sickrage.app.log.debug("Split out {} from {}".format(newNZB, result.name))
 
         # parse the name
         try:
-            np = NameParser(False, showObj=result.show)
-            parse_result = np.parse(newNZB)
+            parse_result = NameParser(False, show_id=result.show_id).parse(newNZB)
         except InvalidNameException:
-            sickrage.app.log.debug("Unable to parse the filename " + newNZB + " into a valid episode")
+            sickrage.app.log.debug("Unable to parse the filename {} into a valid episode".format(newNZB))
             return False
         except InvalidShowException:
-            sickrage.app.log.debug("Unable to parse the filename " + newNZB + " into a valid show")
+            sickrage.app.log.debug("Unable to parse the filename {} into a valid show".format(newNZB))
             return False
 
         # make sure the result is sane
-        if (parse_result.season_number is not None and parse_result.season_number != season) or (
-                        parse_result.season_number is None and season != 1):
-            sickrage.app.log.warning(
-                "Found " + newNZB + " inside " + result.name + " but it doesn't seem to belong to the same season, ignoring it")
+        if (parse_result.season_number is not None and parse_result.season_number != season) or (parse_result.season_number is None and season != 1):
+            sickrage.app.log.warning("Found {} inside {} but it doesn't seem to belong to the same season, ignoring it".format(newNZB, result.name))
             continue
         elif len(parse_result.episode_numbers) == 0:
-            sickrage.app.log.warning(
-                "Found " + newNZB + " inside " + result.name + " but it doesn't seem to be a valid episode NZB, ignoring it")
+            sickrage.app.log.warning("Found {} inside {} but it doesn't seem to be a valid episode NZB, ignoring it".format(newNZB, result.name))
             continue
 
-        wantEp = True
+        want_ep = True
         for epNo in parse_result.episode_numbers:
-            if not result.extraInfo[0].wantEpisode(season, epNo, result.quality):
-                sickrage.app.log.info(
-                    "Ignoring result " + newNZB + " because we don't want an episode that is " +
-                    Quality.qualityStrings[result.quality])
-                wantEp = False
+            show_object = find_show(parse_result.indexer_id)
+            if not show_object.want_episode(parse_result.season_number, epNo, result.quality):
+                sickrage.app.log.info("Ignoring result {} because we don't want an episode that is {}".format(newNZB, Quality.qualityStrings[result.quality]))
+                want_ep = False
                 break
-        if not wantEp:
-            continue
 
-        # get all the associated episode objects
-        epObjList = []
-        for curEp in parse_result.episode_numbers:
-            epObjList.append(result.extraInfo[0].getEpisode(season, curEp))
+        if not want_ep:
+            continue
 
         # make a result
-        curResult = classes.NZBDataSearchResult(epObjList)
-        curResult.name = newNZB
-        curResult.provider = result.provider
-        curResult.quality = result.quality
-        curResult.extraInfo = [createNZBString(separateNZBs[newNZB], xmlns)]
+        cur_result = NZBDataSearchResult(season, parse_result.episode_numbers)
+        cur_result.name = newNZB
+        cur_result.provider = result.provider
+        cur_result.quality = result.quality
+        cur_result.extraInfo = [createNZBString(separate_nzbs[newNZB], xmlns)]
 
-        resultList.append(curResult)
+        result_list.append(cur_result)
 
-    return resultList
+    return result_list
