@@ -1,58 +1,57 @@
 # Author: Frank Fenton
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
+import datetime
 import os
 import threading
 import traceback
-from datetime import date
 
 import sickrage
 from sickrage.core.common import Quality
 from sickrage.core.common import SKIPPED, WANTED, UNKNOWN
-from sickrage.core.helpers import findCertainShow, sanitizeFileName, makeDir, chmodAsParent
+from sickrage.core.exceptions import EpisodeNotFoundException
+from sickrage.core.helpers import sanitize_file_name, make_dir, chmod_as_parent
 from sickrage.core.queues.search import BacklogQueueItem
-from sickrage.core.traktapi import srTraktAPI
+from sickrage.core.traktapi import TraktAPI
+from sickrage.core.databases.main import MainDB
+from sickrage.core.tv.show.helpers import find_show, get_show_list
 from sickrage.indexers import IndexerApi
 
 
-def setEpisodeToWanted(show, s, e):
+def set_episode_to_wanted(show, s, e):
     """
     Sets an episode to wanted, only if it is currently skipped
     """
-    epObj = show.getEpisode(int(s), int(e))
-    if epObj:
-        with epObj.lock:
-            if epObj.status != SKIPPED or epObj.airdate == date.fromordinal(1):
-                return
+    try:
+        epObj = show.get_episode(s, e)
+        if epObj.status != SKIPPED or not epObj.airdate > datetime.date.min:
+            return
 
-            sickrage.app.log.info("Setting episode %s S%02dE%02d to wanted" % (show.name, s, e))
-            # figure out what segment the episode is in and remember it so we can backlog it
+        sickrage.app.log.info("Setting episode %s S%02dE%02d to wanted" % (show.name, s, e))
 
-            epObj.status = WANTED
-            epObj.saveToDB()
+        epObj.status = WANTED
 
-        sickrage.app.search_queue.put(BacklogQueueItem(show, [epObj]))
+        sickrage.app.io_loop.add_callback(sickrage.app.search_queue.put, BacklogQueueItem(show.indexer_id, epObj.season, epObj.episode))
 
-        sickrage.app.log.info(
-            "Starting backlog search for %s S%02dE%02d because some episodes were set to wanted" % (
-                show.name, s, e))
+        sickrage.app.log.info("Starting backlog search for %s S%02dE%02d because some episodes were set to wanted" % (show.name, s, e))
+    except EpisodeNotFoundException as e:
+        pass
 
 
 class TraktSearcher(object):
@@ -67,7 +66,7 @@ class TraktSearcher(object):
         self.amActive = False
 
     def run(self, force=False):
-        if self.amActive or (not sickrage.app.config.use_trakt or sickrage.app.developer) and not force:
+        if self.amActive or not sickrage.app.config.use_trakt and not force:
             return
 
         self.amActive = True
@@ -83,68 +82,65 @@ class TraktSearcher(object):
         # add shows from tv watchlist
         if sickrage.app.config.trakt_sync_watchlist:
             try:
-                self.syncWatchlist()
+                self.sync_watchlist()
             except Exception:
                 sickrage.app.log.debug(traceback.format_exc())
 
         # add shows from tv collection
         if sickrage.app.config.trakt_sync:
             try:
-                self.syncCollection()
+                self.sync_collection()
             except Exception:
                 sickrage.app.log.debug(traceback.format_exc())
 
         self.amActive = False
 
-    def syncWatchlist(self):
-        if sickrage.app.config.trakt_sync_watchlist and sickrage.app.config.use_trakt:
-            sickrage.app.log.debug("Syncing SiCKRAGE with Trakt Watchlist")
+    def sync_watchlist(self):
+        sickrage.app.log.debug("Syncing SiCKRAGE with Trakt Watchlist")
 
-            self.removeShowFromSickRage()
+        self.remove_show_from_sick_rage()
 
-            if self._getShowWatchlist():
-                self.addShowToTraktWatchList()
-                self.updateShows()
+        if self._get_show_watchlist():
+            self.add_show_to_trakt_watch_list()
+            self.update_shows()
 
-            if self._getEpisodeWatchlist():
-                self.addEpisodesToTraktWatchList()
-                if sickrage.app.config.trakt_remove_show_from_sickrage:
-                    self.removeEpisodesFromTraktWatchList()
-                self.updateEpisodes()
+        if self._get_episode_watchlist():
+            self.add_episodes_to_trakt_watch_list()
+            if sickrage.app.config.trakt_remove_show_from_sickrage:
+                self.remove_episodes_from_trakt_watch_list()
+            self.update_episodes()
 
-    def syncCollection(self):
+    def sync_collection(self):
         sickrage.app.log.debug("Syncing SiCKRAGE with Trakt Collection")
-        if self._getShowCollection():
-            self.addEpisodesToTraktCollection()
+        if self._get_show_collection():
+            self.add_episodes_to_trakt_collection()
             if sickrage.app.config.trakt_sync_remove:
-                self.removeEpisodesFromTraktCollection()
+                self.remove_episodes_from_trakt_collection()
 
-    def findShowMatch(self, indexer, indexerid):
+    def find_show_match(self, indexer, indexer_id):
         traktShow = None
 
         try:
-            library = srTraktAPI()["sync/collection"].shows() or {}
+            library = TraktAPI()["sync/collection"].shows() or {}
             if not library:
                 sickrage.app.log.debug("No shows found in your library, aborting library update")
                 return
 
-            traktShow = [x for __, x in library.items() if
-                         int(indexerid) == int(x.ids[IndexerApi(indexer).trakt_id])]
+            traktShow = [x for __, x in library.items() if int(indexer_id) == int(x.ids[IndexerApi(indexer).trakt_id])]
         except Exception as e:
-            sickrage.app.log.warning(
-                "Could not connect to Trakt service. Aborting library check. Error: %s" % repr(e))
+            sickrage.app.log.warning("Could not connect to Trakt service. Aborting library check. Error: %s" % repr(e))
 
         return traktShow
 
-    def removeShowFromTraktLibrary(self, show_obj):
-        if self.findShowMatch(show_obj.indexer, show_obj.indexerid):
+    def remove_show_from_trakt_library(self, show_obj):
+        if self.find_show_match(show_obj.indexer, show_obj.indexer_id):
             # URL parameters
             data = {
                 'shows': [
                     {
                         'title': show_obj.name,
                         'year': show_obj.startyear,
-                        'ids': {IndexerApi(show_obj.indexer).trakt_id: show_obj.indexerid}
+                        'ids': {IndexerApi(show_obj.indexer).trakt_id: show_obj.indexer_id}
                     }
                 ]
             }
@@ -152,13 +148,13 @@ class TraktSearcher(object):
             sickrage.app.log.debug("Removing %s from tv library" % show_obj.name)
 
             try:
-                srTraktAPI()["sync/collection"].remove(data)
+                TraktAPI()["sync/collection"].remove(data)
             except Exception as e:
                 sickrage.app.log.warning(
                     "Could not connect to Trakt service. Aborting removing show %s from Trakt library. Error: %s" % (
                         show_obj.name, repr(e)))
 
-    def addShowToTraktLibrary(self, show_obj):
+    def add_show_to_trakt_library(self, show_obj):
         """
         Sends a request to trakt indicating that the given show and all its episodes is part of our library.
 
@@ -166,14 +162,14 @@ class TraktSearcher(object):
         """
         data = {}
 
-        if not self.findShowMatch(show_obj.indexer, show_obj.indexerid):
+        if not self.find_show_match(show_obj.indexer, show_obj.indexer_id):
             # URL parameters
             data = {
                 'shows': [
                     {
                         'title': show_obj.name,
                         'year': show_obj.startyear,
-                        'ids': {IndexerApi(show_obj.indexer).trakt_id: show_obj.indexerid}
+                        'ids': {IndexerApi(show_obj.indexer).trakt_id: show_obj.indexer_id}
                     }
                 ]
             }
@@ -182,143 +178,143 @@ class TraktSearcher(object):
             sickrage.app.log.debug("Adding %s to tv library" % show_obj.name)
 
             try:
-                srTraktAPI()["sync/collection"].add(data)
+                TraktAPI()["sync/collection"].add(data)
             except Exception as e:
-                sickrage.app.log.warning(
-                    "Could not connect to Trakt service. Aborting adding show %s to Trakt library. Error: %s" % (
-                        show_obj.name, repr(e)))
+                sickrage.app.log.warning("Could not connect to Trakt service. Aborting adding show %s to Trakt library. Error: %s" % (show_obj.name, repr(e)))
                 return
 
-    def addEpisodesToTraktCollection(self):
+    def add_episodes_to_trakt_collection(self):
         trakt_data = []
 
         sickrage.app.log.debug("COLLECTION::SYNC::START - Look for Episodes to Add to Trakt Collection")
 
-        for s in sickrage.app.showlist:
-            for e in sickrage.app.main_db.get_many('tv_episodes', s.indexerid):
+        for s in get_show_list():
+            for e in s.episodes:
                 trakt_id = IndexerApi(s.indexer).trakt_id
-                if not self._checkInList(trakt_id, str(e["showid"]), e["season"], e["episode"], 'Collection'):
-                    sickrage.app.log.debug(
-                        "Adding Episode %s S%02dE%02d to collection" % (s.name, e["season"], e["episode"]))
-                    trakt_data.append((e["showid"], s.indexer, s.name, s.startyear, e["season"], e["episode"]))
+                if not self._check_in_list(trakt_id, str(e.showid), e.season, e.episode, 'Collection'):
+                    sickrage.app.log.debug("Adding Episode %s S%02dE%02d to collection" % (s.name, e.season, e.episode))
+                    trakt_data.append((e.showid, s.indexer, s.name, s.startyear, e.season, e.episode))
 
         if len(trakt_data):
             try:
-                srTraktAPI()["sync/collection"].add(self.trakt_bulk_data_generate(trakt_data))
-                self._getShowCollection()
+                TraktAPI()["sync/collection"].add(self.trakt_bulk_data_generate(trakt_data))
+                self._get_show_collection()
             except Exception as e:
                 sickrage.app.log.warning("Could not connect to Trakt service. Error: %s" % e)
 
         sickrage.app.log.debug("COLLECTION::ADD::FINISH - Look for Episodes to Add to Trakt Collection")
 
-    def removeEpisodesFromTraktCollection(self):
+    def remove_episodes_from_trakt_collection(self):
         trakt_data = []
 
         sickrage.app.log.debug(
             "COLLECTION::REMOVE::START - Look for Episodes to Remove From Trakt Collection")
 
-        for s in sickrage.app.showlist:
-            for e in sickrage.app.main_db.get_many('tv_episodes', s.indexerid):
-                if e["location"]: continue
+        for s in get_show_list():
+            for e in s.episodes:
+                if e.location:
+                    continue
+
                 trakt_id = IndexerApi(s.indexer).trakt_id
-                if self._checkInList(trakt_id, str(e["showid"]), e["season"], e["episode"], 'Collection'):
+                if self._check_in_list(trakt_id, str(e.showid), e.season, e.episode, 'Collection'):
                     sickrage.app.log.debug(
-                        "Removing Episode %s S%02dE%02d from collection" % (s.name, e["season"], e["episode"]))
-                    trakt_data.append((e["showid"], s.indexer, s.name, s.startyear, e["season"], e["episode"]))
+                        "Removing Episode %s S%02dE%02d from collection" % (s.name, e.season, e.episode))
+                    trakt_data.append((e.showid, s.indexer, s.name, s.startyear, e.season, e.episode))
 
         if len(trakt_data):
             try:
-                srTraktAPI()["sync/collection"].remove(self.trakt_bulk_data_generate(trakt_data))
-                self._getShowCollection()
+                TraktAPI()["sync/collection"].remove(self.trakt_bulk_data_generate(trakt_data))
+                self._get_show_collection()
             except Exception as e:
                 sickrage.app.log.warning("Could not connect to Trakt service. Error: %s" % e)
 
         sickrage.app.log.debug(
             "COLLECTION::REMOVE::FINISH - Look for Episodes to Remove From Trakt Collection")
 
-    def removeEpisodesFromTraktWatchList(self):
+    def remove_episodes_from_trakt_watch_list(self):
         trakt_data = []
 
         sickrage.app.log.debug(
             "WATCHLIST::REMOVE::START - Look for Episodes to Remove from Trakt Watchlist")
 
-        for s in sickrage.app.showlist:
-            for e in sickrage.app.main_db.get_many('tv_episodes', s.indexerid):
+        for s in get_show_list():
+            for e in s.episodes:
                 trakt_id = IndexerApi(s.indexer).trakt_id
-                if self._checkInList(trakt_id, str(e["showid"]), e["season"], e["episode"]):
+                if self._check_in_list(trakt_id, str(e.showid), e.season, e.episode):
                     sickrage.app.log.debug(
-                        "Removing Episode %s S%02dE%02d from watchlist" % (s.name, e["season"], e["episode"]))
-                    trakt_data.append((e["showid"], s.indexer, s.name, s.startyear, e["season"], e["episode"]))
+                        "Removing Episode %s S%02dE%02d from watchlist" % (s.name, e.season, e.episode))
+                    trakt_data.append((e.showid, s.indexer, s.name, s.startyear, e.season, e.episode))
 
         if len(trakt_data):
             try:
                 data = self.trakt_bulk_data_generate(trakt_data)
-                srTraktAPI()["sync/watchlist"].remove(data)
-                self._getEpisodeWatchlist()
+                TraktAPI()["sync/watchlist"].remove(data)
+                self._get_episode_watchlist()
             except Exception as e:
                 sickrage.app.log.warning("Could not connect to Trakt service. Error: %s" % e)
 
         sickrage.app.log.debug(
             "WATCHLIST::REMOVE::FINISH - Look for Episodes to Remove from Trakt Watchlist")
 
-    def addEpisodesToTraktWatchList(self):
+    def add_episodes_to_trakt_watch_list(self):
+        session = sickrage.app.main_db.session()
+
         trakt_data = []
 
         sickrage.app.log.debug("WATCHLIST::ADD::START - Look for Episodes to Add to Trakt Watchlist")
 
-        for s in sickrage.app.showlist:
-            for e in sickrage.app.main_db.get_many('tv_episodes', s.indexerid):
-                if not e['status'] in Quality.SNATCHED + Quality.SNATCHED_PROPER + [UNKNOWN] + [WANTED]: continue
+        for s in get_show_list():
+            for e in session.query(MainDB.TVEpisode).filter_by(showid=s.indexer_id).filter(
+                    ~MainDB.TVEpisode.episode.in_(Quality.SNATCHED + Quality.SNATCHED_PROPER + [UNKNOWN] + [WANTED])):
                 trakt_id = IndexerApi(s.indexer).trakt_id
-                if self._checkInList(trakt_id, str(e["showid"]), e["season"], e["episode"]):
-                    sickrage.app.log.debug(
-                        "Adding Episode %s S%02dE%02d to watchlist" % (s.name, e["season"], e["episode"]))
-                    trakt_data.append((e["showid"], s.indexer, s.name, s.startyear, e["season"], e["episode"]))
+                if self._check_in_list(trakt_id, str(e.showid), e.season, e.episode):
+                    sickrage.app.log.debug("Adding Episode %s S%02dE%02d to watchlist" % (s.name, e.season, e.episode))
+                    trakt_data.append((e.showid, s.indexer, s.name, s.startyear, e.season, e.episode))
 
         if len(trakt_data):
             try:
                 data = self.trakt_bulk_data_generate(trakt_data)
-                srTraktAPI()["sync/watchlist"].add(data)
-                self._getEpisodeWatchlist()
+                TraktAPI()["sync/watchlist"].add(data)
+                self._get_episode_watchlist()
             except Exception as e:
                 sickrage.app.log.warning("Could not connect to Trakt service. Error %s" % e)
 
         sickrage.app.log.debug("WATCHLIST::ADD::FINISH - Look for Episodes to Add to Trakt Watchlist")
 
-    def addShowToTraktWatchList(self):
+    def add_show_to_trakt_watch_list(self):
         trakt_data = []
 
         sickrage.app.log.debug("SHOW_WATCHLIST::ADD::START - Look for Shows to Add to Trakt Watchlist")
 
-        for show in sickrage.app.showlist:
-            if not self._checkInList(IndexerApi(show.indexer).trakt_id, str(show.indexerid), 0, 0, 'Show'):
+        for show in get_show_list():
+            if not self._check_in_list(IndexerApi(show.indexer).trakt_id, str(show.indexer_id), 0, 0, 'Show'):
                 sickrage.app.log.debug(
                     "Adding Show: Indexer %s %s - %s to Watchlist" % (
-                        IndexerApi(show.indexer).trakt_id, str(show.indexerid), show.name))
+                        IndexerApi(show.indexer).trakt_id, str(show.indexer_id), show.name))
 
                 show_el = {'title': show.name,
                            'year': show.startyear,
-                           'ids': {IndexerApi(show.indexer).trakt_id: show.indexerid}}
+                           'ids': {IndexerApi(show.indexer).trakt_id: show.indexer_id}}
 
                 trakt_data.append(show_el)
 
         if len(trakt_data):
             try:
                 data = {'shows': trakt_data}
-                srTraktAPI()["sync/watchlist"].add(data)
-                self._getShowWatchlist()
+                TraktAPI()["sync/watchlist"].add(data)
+                self._get_show_watchlist()
             except Exception as e:
                 sickrage.app.log.warning("Could not connect to Trakt service. Error: %s" % e)
 
         sickrage.app.log.debug("SHOW_WATCHLIST::ADD::FINISH - Look for Shows to Add to Trakt Watchlist")
 
-    def removeShowFromSickRage(self):
+    def remove_show_from_sick_rage(self):
         sickrage.app.log.debug("SHOW_SICKRAGE::REMOVE::START - Look for Shows to remove from SiCKRAGE")
 
-        for show in sickrage.app.showlist:
+        for show in get_show_list():
             if show.status == "Ended":
                 try:
-                    progress = srTraktAPI()["shows"].get(show.imdbid)
+                    progress = TraktAPI()["shows"].get(show.imdb_id)
                 except Exception as e:
                     sickrage.app.log.warning(
                         "Could not connect to Trakt service. Aborting removing show %s from SiCKRAGE. Error: %s" % (
@@ -326,12 +322,12 @@ class TraktSearcher(object):
                     return
 
                 if progress.status in ['canceled', 'ended']:
-                    sickrage.app.show_queue.removeShow(show, full=True)
+                    sickrage.app.show_queue.remove_show(show.indexer_id, full=True)
                     sickrage.app.log.debug("Show: %s has been removed from SiCKRAGE" % show.name)
 
         sickrage.app.log.debug("SHOW_SICKRAGE::REMOVE::FINISH - Trakt Show Watchlist")
 
-    def updateShows(self):
+    def update_shows(self):
         sickrage.app.log.debug("SHOW_WATCHLIST::CHECK::START - Trakt Show Watchlist")
 
         if not len(self.ShowWatchlist):
@@ -350,21 +346,21 @@ class TraktSearcher(object):
 
             if trakt_id == IndexerApi(indexer).trakt_id:
                 if int(sickrage.app.config.trakt_method_add) != 2:
-                    self.addDefaultShow(indexer, indexer_id, show.title, SKIPPED)
+                    self.add_default_show(indexer, indexer_id, show.title, SKIPPED)
                 else:
-                    self.addDefaultShow(indexer, indexer_id, show.title, WANTED)
+                    self.add_default_show(indexer, indexer_id, show.title, WANTED)
 
                 if int(sickrage.app.config.trakt_method_add) == 1:
-                    newShow = findCertainShow(indexer_id)
+                    newShow = find_show(indexer_id)
 
                     if newShow is not None:
-                        setEpisodeToWanted(newShow, 1, 1)
+                        set_episode_to_wanted(newShow, 1, 1)
                     else:
                         self.todoWanted.append((indexer_id, 1, 1))
 
         sickrage.app.log.debug("SHOW_WATCHLIST::CHECK::FINISH - Trakt Show Watchlist")
 
-    def updateEpisodes(self):
+    def update_episodes(self):
         """
         Sets episodes to wanted that are in trakt watchlist
         """
@@ -386,33 +382,33 @@ class TraktSearcher(object):
             except KeyError:
                 continue
 
-            newShow = findCertainShow(indexer_id)
+            show_object = find_show(indexer_id)
 
             try:
-                if newShow is None:
+                if show_object is None:
                     if indexer_id not in managed_show:
-                        self.addDefaultShow(indexer, indexer_id, show.title, SKIPPED)
+                        self.add_default_show(indexer, indexer_id, show.title, SKIPPED)
                         managed_show.append(indexer_id)
 
                         for season_number, season in show.seasons.items():
                             for episode_number, _ in season.episodes.items():
                                 self.todoWanted.append((int(indexer_id), int(season_number), int(episode_number)))
                 else:
-                    if newShow.indexer == indexer:
+                    if show_object.indexer == indexer:
                         for season_number, season in show.seasons.items():
                             for episode_number, _ in season.episodes.items():
-                                setEpisodeToWanted(newShow, int(season_number), int(episode_number))
+                                set_episode_to_wanted(show_object, int(season_number), int(episode_number))
             except TypeError:
                 sickrage.app.log.debug("Could not parse the output from trakt for %s " % show.title)
 
         sickrage.app.log.debug("SHOW_WATCHLIST::CHECK::FINISH - Trakt Episode Watchlist")
 
     @staticmethod
-    def addDefaultShow(indexer, indexer_id, name, status):
+    def add_default_show(indexer, indexer_id, name, status):
         """
         Adds a new show with the default settings
         """
-        if not findCertainShow(int(indexer_id)):
+        if not find_show(int(indexer_id)):
             sickrage.app.log.info("Adding show " + str(indexer_id))
             root_dirs = sickrage.app.config.root_dirs.split('|')
 
@@ -422,37 +418,34 @@ class TraktSearcher(object):
                 location = None
 
             if location:
-                showPath = os.path.join(location, sanitizeFileName(name))
-                dir_exists = makeDir(showPath)
+                showPath = os.path.join(location, sanitize_file_name(name))
+                dir_exists = make_dir(showPath)
 
                 if not dir_exists:
                     sickrage.app.log.warning("Unable to create the folder %s , can't add the show" % showPath)
                     return
                 else:
-                    chmodAsParent(showPath)
+                    chmod_as_parent(showPath)
 
-                sickrage.app.show_queue.addShow(int(indexer), int(indexer_id), showPath,
-                                                default_status=status,
-                                                quality=int(sickrage.app.config.quality_default),
-                                                flatten_folders=int(sickrage.app.config.flatten_folders_default),
-                                                paused=sickrage.app.config.trakt_start_paused,
-                                                default_status_after=status,
-                                                skip_downloaded=sickrage.app.config.skip_downloaded_default)
+                sickrage.app.show_queue.add_show(int(indexer), int(indexer_id), showPath,
+                                                 default_status=status,
+                                                 quality=int(sickrage.app.config.quality_default),
+                                                 flatten_folders=int(sickrage.app.config.flatten_folders_default),
+                                                 paused=sickrage.app.config.trakt_start_paused,
+                                                 default_status_after=status,
+                                                 skip_downloaded=sickrage.app.config.skip_downloaded_default)
             else:
                 sickrage.app.log.warning(
                     "There was an error creating the show, no root directory setting found")
                 return
 
-    def manageNewShow(self, show):
-        sickrage.app.log.debug(
-            "Checking if trakt watch list wants to search for episodes from new show " + show.name)
-        episodes = [i for i in self.todoWanted if i[0] == show.indexerid]
-
-        for episode in episodes:
+    def manage_new_show(self, show):
+        sickrage.app.log.debug("Checking if trakt watch list wants to search for episodes from new show " + show.name)
+        for episode in [i for i in self.todoWanted if i[0] == show.indexer_id]:
             self.todoWanted.remove(episode)
-            setEpisodeToWanted(show, episode[1], episode[2])
+            set_episode_to_wanted(show, int(episode[1]), int(episode[2]))
 
-    def _checkInList(self, trakt_id, showid, season, episode, List=None):
+    def _check_in_list(self, trakt_id, showid, season, episode, List=None):
         """
          Check in the Watchlist or CollectionList for Show
          Is the Show, Season and Episode in the trakt_id list (tvdb / tvrage)
@@ -473,26 +466,26 @@ class TraktSearcher(object):
             except Exception:
                 return False
 
-    def _getShowWatchlist(self):
+    def _get_show_watchlist(self):
         """
         Get Watchlist and parse once into addressable structure
         """
         try:
             sickrage.app.log.debug("Getting Show Watchlist")
-            self.ShowWatchlist = srTraktAPI()["sync/watchlist"].shows() or {}
+            self.ShowWatchlist = TraktAPI()["sync/watchlist"].shows() or {}
         except Exception as e:
             sickrage.app.log.warning(
                 "Could not connect to trakt service, cannot download Show Watchlist: %s" % repr(e))
             return False
         return True
 
-    def _getEpisodeWatchlist(self):
+    def _get_episode_watchlist(self):
         """
          Get Watchlist and parse once into addressable structure
         """
         try:
             sickrage.app.log.debug("Getting Episode Watchlist")
-            self.EpisodeWatchlist = srTraktAPI()["sync/watchlist"].episodes() or {}
+            self.EpisodeWatchlist = TraktAPI()["sync/watchlist"].episodes() or {}
         except Exception as e:
             sickrage.app.log.warning(
                 "Could not connect to trakt service, cannot download Episode Watchlist: %s" % repr(e))
@@ -500,13 +493,13 @@ class TraktSearcher(object):
 
         return True
 
-    def _getShowCollection(self):
+    def _get_show_collection(self):
         """
         Get Collection and parse once into addressable structure
         """
         try:
             sickrage.app.log.debug("Getting Show Collection")
-            self.Collectionlist = srTraktAPI()["sync/collection"].shows() or {}
+            self.Collectionlist = TraktAPI()["sync/collection"].shows() or {}
         except Exception as e:
             sickrage.app.log.warning(
                 "Could not connect to trakt service, cannot download Show Collection: %s" % repr(e))
@@ -524,24 +517,24 @@ class TraktSearcher(object):
         shows = {}
         seasons = {}
 
-        for indexerid, indexer, show_name, startyear, season, episode in data:
-            if indexerid not in shows:
-                shows[indexerid] = {'title': show_name,
-                                    'year': startyear,
-                                    'ids': {IndexerApi(indexer).trakt_id: indexerid}}
+        for indexer_id, indexer, show_name, startyear, season, episode in data:
+            if indexer_id not in shows:
+                shows[indexer_id] = {'title': show_name,
+                                     'year': startyear,
+                                     'ids': {IndexerApi(indexer).trakt_id: indexer_id}}
 
-            if indexerid not in seasons:
-                seasons[indexerid] = {}
-            if season not in seasons[indexerid]:
-                seasons[indexerid] = {season: []}
-            if episode not in seasons[indexerid][season]:
-                seasons[indexerid][season] += [{'number': episode}]
+            if indexer_id not in seasons:
+                seasons[indexer_id] = {}
+            if season not in seasons[indexer_id]:
+                seasons[indexer_id] = {season: []}
+            if episode not in seasons[indexer_id][season]:
+                seasons[indexer_id][season] += [{'number': episode}]
 
-        for indexerid, seasonlist in seasons.items():
-            if 'seasons' not in shows[indexerid]: shows[indexerid]['seasons'] = []
+        for indexer_id, seasonlist in seasons.items():
+            if 'seasons' not in shows[indexer_id]: shows[indexer_id]['seasons'] = []
             for season, episodelist in seasonlist.items():
-                shows[indexerid]['seasons'] += [{'number': season, 'episodes': episodelist}]
+                shows[indexer_id]['seasons'] += [{'number': season, 'episodes': episodelist}]
 
-            show_list.append(shows[indexerid])
+            show_list.append(shows[indexer_id])
 
         return {'shows': show_list}
