@@ -1,26 +1,29 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import datetime
 
 import sickrage
+from sickrage.core.websocket import WebSocketMessage
 
 MESSAGE = 'notice'
 ERROR = 'error'
@@ -35,7 +38,7 @@ class Notifications(object):
         self._messages = []
         self._errors = []
 
-    def message(self, title, message=None):
+    def message(self, title, message=""):
         """
         Add a regular notification to the queue
 
@@ -43,9 +46,11 @@ class Notifications(object):
         message: The message portion of the notification
         """
 
-        self._messages.append(Notification(title, message, MESSAGE))
+        n = Notification(title, message, MESSAGE)
+        if not WebSocketMessage('notification', n.data).push():
+            self._messages.append(n)
 
-    def error(self, title, message=None):
+    def error(self, title, message=""):
         """
         Add an error notification to the queue
 
@@ -53,7 +58,9 @@ class Notifications(object):
         message: The message portion of the notification
         """
 
-        self._errors.append(Notification(title, message, ERROR))
+        n = Notification(title, message, ERROR)
+        if not WebSocketMessage('notification', n.data).push():
+            self._errors.append(n)
 
     def get_notifications(self, remote_ip='127.0.0.1'):
         """
@@ -79,16 +86,20 @@ class Notification(object):
 
     def __init__(self, title, message='', type=None, timeout=None):
         self.title = title
-
-        self.message = message
-        if isinstance(self.message, Exception):
-            self.message = self.message.message
-
+        self.message = str(message) if isinstance(message, Exception) else message
         self._when = datetime.datetime.now()
         self._seen = []
-        self.type = type or MESSAGE
+        self._type = type or MESSAGE
         self._timeout = timeout or datetime.timedelta(minutes=1)
 
+    @property
+    def data(self):
+        return {
+            'title': self.title,
+            'body': self.message,
+            'type': self._type
+        }
+
     def is_new(self, remote_ip='127.0.0.1'):
         """
         Returns True if the notification hasn't been displayed to the current client (aka IP address).
@@ -117,11 +128,10 @@ class ProgressIndicator:
         self.currentStatus = currentStatus
 
 
-class ProgressIndicators():
+class ProgressIndicators:
     _pi = {'massUpdate': [],
            'massAdd': [],
-           'dailyShowUpdates': []
-           }
+           'dailyShowUpdates': []}
 
     @staticmethod
     def getIndicator(name):
@@ -141,7 +151,7 @@ class ProgressIndicators():
         ProgressIndicators._pi[name].append(indicator)
 
 
-class QueueProgressIndicator():
+class QueueProgressIndicator:
     """
     A class used by the UI to show the progress of the queue or a part of it.
     """
@@ -154,15 +164,15 @@ class QueueProgressIndicator():
         return len(self.queueItemList)
 
     def numFinished(self):
-        return len([x for x in self.queueItemList if not x.isInQueue()])
+        return len([x for x in self.queueItemList if not x.is_in_queue()])
 
     def numRemaining(self):
-        return len([x for x in self.queueItemList if x.isInQueue()])
+        return len([x for x in self.queueItemList if x.is_in_queue()])
 
     def nextName(self):
-        for curItem in [sickrage.app.show_queue.currentItem] + sickrage.app.show_queue.queue:
-            if curItem in self.queueItemList:
-                return curItem.name
+        for cur_item in self.queue_items:
+            if cur_item in self.queueItemList:
+                return cur_item.name
 
         return "Unknown"
 
@@ -176,7 +186,7 @@ class QueueProgressIndicator():
             return int(float(numFinished) / float(numTotal) * 100)
 
 
-class LoadingTVShow():
+class LoadingTVShow:
     def __init__(self, dir):
         self.dir = dir
         self.show = None
