@@ -1,51 +1,51 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import unicode_literals
-
-import io
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+import os
+import re
 import ssl
-import urllib2
+from urllib.parse import urlparse
 
 import certifi
-import cfscrape as cfscrape
 import requests
 from cachecontrol import CacheControlAdapter
+from cloudscraper import CloudScraper
 from fake_useragent import UserAgent
 from requests import Session
 from requests.utils import dict_from_cookiejar
+from urllib3 import disable_warnings
 
 import sickrage
-from sickrage.core.helpers import chmodAsParent, remove_file_failed
-from sickrage.core.helpers.encoding import to_unicode
+from sickrage.core import helpers
 
 
 def _add_proxies():
     if sickrage.app.config.proxy_setting:
         sickrage.app.log.debug("Using global proxy: " + sickrage.app.config.proxy_setting)
-        scheme, address = urllib2.splittype(sickrage.app.config.proxy_setting)
-        address = ('http://{}'.format(sickrage.app.config.proxy_setting),
-                   sickrage.app.config.proxy_setting)[scheme]
+        proxy = urlparse(sickrage.app.config.proxy_setting)
+        address = sickrage.app.config.proxy_setting if proxy.scheme else 'http://{}'.format(sickrage.app.config.proxy_setting)
         return {"http": address, "https": address}
 
 
 class WebSession(Session):
-    def __init__(self, proxies=None, cache=True):
+    def __init__(self, proxies=None, cache=True, cloudflare=False):
         super(WebSession, self).__init__()
 
         # setup caching adapter
@@ -57,8 +57,11 @@ class WebSession(Session):
         # add proxies
         self.proxies = proxies or _add_proxies()
 
+        # cloudflare
+        self.cloudflare = cloudflare
+
         # add hooks
-        self.hooks['response'] += [WebHooks.log_url, WebHooks.cloudflare]
+        self.hooks['response'] += [WebHooks.log_url]
 
     @staticmethod
     def _get_ssl_cert(verify):
@@ -70,29 +73,39 @@ class WebSession(Session):
         """
         return certifi.where() if all([sickrage.app.config.ssl_verify, verify]) else False
 
-    def request(self, method, url, verify=False, random_ua=False, *args, **kwargs):
+    def request(self, method, url, verify=False, random_ua=False, allow_post_redirects=False, *args, **kwargs):
         self.headers.update({'Accept-Encoding': 'gzip, deflate',
                              'User-Agent': (sickrage.app.user_agent, UserAgent().random)[random_ua]})
 
-        response = super(WebSession, self).request(method, url, verify=self._get_ssl_cert(verify), *args, **kwargs)
+        if not verify:
+            disable_warnings()
+
+        if allow_post_redirects and method == 'POST':
+            sickrage.app.log.debug('Retrieving redirect URL for {url}'.format(**{'url': url}))
+            response = super(WebSession, self).request(method, url, allow_redirects=False)
+            url = self.get_redirect_target(response) or url
 
         try:
+            response = super(WebSession, self).request(method, url, verify=self._get_ssl_cert(verify), *args, **kwargs)
+
+            # check of cloudflare handling is required
+            if self.cloudflare:
+                response = WebHelpers.cloudflare(self, response, **kwargs)
+
             # check web response for errors
             response.raise_for_status()
+
+            return response
         except requests.exceptions.SSLError as e:
             if ssl.OPENSSL_VERSION_INFO < (1, 0, 1, 5):
                 sickrage.app.log.info(
-                    "SSL Error requesting url: '{}' You have {}, try upgrading OpenSSL to 1.0.1e+".format(
-                        e.request.url, ssl.OPENSSL_VERSION))
+                    "SSL Error requesting url: '{}' You have {}, try upgrading OpenSSL to 1.0.1e+".format(e.request.url, ssl.OPENSSL_VERSION)
+                )
 
             if sickrage.app.config.ssl_verify:
                 sickrage.app.log.info(
-                    "SSL Error requesting url: '{}', try disabling cert verification in advanced settings".format(
-                        e.request.url))
-        except Exception:
-            pass
-
-        return response
+                    "SSL Error requesting url: '{}', try disabling cert verification in advanced settings".format(e.request.url)
+                )
 
     def download(self, url, filename, **kwargs):
         try:
@@ -100,15 +113,16 @@ class WebSession(Session):
             if r.status_code >= 400:
                 return False
 
-            with io.open(filename, 'wb') as f:
+            with open(filename, 'wb') as f:
                 for chunk in r.iter_content(chunk_size=1024):
                     if chunk:
                         f.write(chunk)
 
-            chmodAsParent(filename)
+            helpers.chmod_as_parent(filename)
         except Exception as e:
             sickrage.app.log.debug("Failed to download file from {} - ERROR: {}".format(url, e))
-            remove_file_failed(filename)
+            if os.path.exists(filename):
+                os.remove(filename)
             return False
 
         return True
@@ -141,39 +155,44 @@ class WebHooks(object):
         sickrage.app.log.debug('User-Agent: {}'.format(request.headers['User-Agent']))
 
         if request.method.upper() == 'POST':
-            if isinstance(request.body, unicode):
-                sickrage.app.log.debug('With post data: {}'.format(request.body))
-            else:
-                sickrage.app.log.debug('With post data: {}'.format(to_unicode(request.body)))
+            sickrage.app.log.debug('With post data: {!r}'.format(request.body.decode() if isinstance(request.body, bytes) else request.body))
 
+
+class WebHelpers(object):
     @staticmethod
-    def cloudflare(resp, **kwargs):
+    def cloudflare(session, resp, **kwargs):
         """
         Bypass CloudFlare's anti-bot protection.
         """
 
-        def is_cloudflare_challenge(resp):
-            """Check if the response is a Cloudflare challange.
-            Source: goo.gl/v8FvnD
-            """
-            return (
-                    resp.status_code == 503
-                    and resp.headers.get('Server', '').startswith('cloudflare')
-                    and b'jschl_vc' in resp.content
-                    and b'jschl_answer' in resp.content
-            )
+        def filtered_kwargs(kwargs):
+            """Filter kwargs to only contain arguments accepted by `requests.Session.send`."""
+            return {
+                k: v for k, v in kwargs.items()
+                if k in ('stream', 'timeout', 'verify', 'cert', 'proxies', 'allow_redirects')
+            }
 
-        if is_cloudflare_challenge(resp):
+        # def is_cloudflare_challenge(resp):
+        #     """Check if the response is a Cloudflare challange.
+        #     Source: goo.gl/v8FvnD
+        #     """
+        #     try:
+        #         return (resp.headers.get('Server', '').startswith('cloudflare')
+        #                 and resp.status_code in [429, 503]
+        #                 and re.search(r'action="/.*?__cf_chl_jschl_tk__=\S+".*?name="jschl_vc"\svalue=.*?', resp.text, re.M | re.DOTALL))
+        #     except AttributeError:
+        #         pass
+        #
+        #     return False
+
+        if CloudScraper.is_IUAM_Challenge(resp):
             sickrage.app.log.debug('CloudFlare protection detected, trying to bypass it')
 
-            # Get the session used or create a new one
-            session = getattr(resp, 'session', requests.Session())
-
             # Get the original request
             original_request = resp.request
 
             # Get the CloudFlare tokens and original user-agent
-            tokens, user_agent = cfscrape.get_tokens(original_request.url)
+            tokens, user_agent = CloudScraper.get_tokens(original_request.url)
 
             # Add CloudFlare tokens to the session cookies
             session.cookies.update(tokens)
@@ -192,10 +211,11 @@ class WebHooks(object):
 
             # Remove hooks from original request
             original_hooks = original_request.hooks
-            original_request.hooks = session.hooks
+            original_request.hooks = []
 
             # Resend the request
-            cf_resp = session.send(original_request, allow_redirects=True, **kwargs)
+            kwargs['allow_redirects'] = True
+            cf_resp = session.send(original_request, **filtered_kwargs(kwargs))
 
             if cf_resp.ok:
                 sickrage.app.log.debug('CloudFlare successfully bypassed.')
@@ -205,4 +225,7 @@ class WebHooks(object):
 
             return cf_resp
         else:
+            if CloudScraper.is_reCaptcha_Challenge(resp) or CloudScraper.is_Firewall_Blocked(resp):
+                sickrage.app.log.warning("Cloudflare captcha challenge or firewall detected, it can't be bypassed.")
+
             return resp
