@@ -1,28 +1,26 @@
 # Author: echel0n <echel0n@sickrage.ca>
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import unicode_literals
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
 import re
 
 import sickrage
-from sickrage.core.classes import ShowListUI
 from sickrage.indexers.config import indexerConfig
+from sickrage.indexers.ui import ShowListUI
 
 
 class IndexerApi(object):
@@ -31,7 +29,8 @@ class IndexerApi(object):
         self.module = indexerConfig[self.indexerID]['module']
 
     def indexer(self, *args, **kwargs):
-        return self.module(*args, **kwargs)
+        self.module.settings(*args, **kwargs)
+        return self.module
 
     @property
     def config(self):
@@ -64,33 +63,26 @@ class IndexerApi(object):
     def indexersByTraktID(self):
         return dict((x['trakt_id'], int(x['id'])) for x in indexerConfig.values())
 
-    def searchForShowID(self, regShowName, showid=None, ui=ShowListUI):
+    def search_for_show_id(self, show_name, custom_ui=None):
         """
         Contacts indexer to check for information on shows by showid
 
-        :param regShowName: Name of show
-        :param showid: Which indexer ID to look for
-        :param ui: Custom UI for indexer use
+        :param show_name: Name of show
+        :param custom_ui: Custom UI for indexer use
         :return:
         """
 
-        showNames = [re.sub('[. -]', ' ', regShowName)]
+        show_name = re.sub('[. -]', ' ', show_name)
 
         # Query Indexers for each search term and build the list of results
         lINDEXER_API_PARMS = self.api_params.copy()
-        lINDEXER_API_PARMS['custom_ui'] = ui
+        lINDEXER_API_PARMS['custom_ui'] = custom_ui or ShowListUI
         t = self.indexer(**lINDEXER_API_PARMS)
 
-        for name in showNames:
-            sickrage.app.log.debug("Trying to find show {} on indexer {}".format(name, self.name))
+        sickrage.app.log.debug("Trying to find show ID for show {} on indexer {}".format(show_name, self.name))
 
-            try:
-                search = t[showid] if showid else t[name]
-                seriesname = search['seriesname']
-                series_id = search['id']
-            except Exception:
-                continue
-
-            return seriesname, self.indexerID, int(series_id)
-
-        return None, None, None
+        try:
+            search = t[show_name]
+            return search['id']
+        except Exception:
+            pass
