@@ -1,36 +1,36 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import print_function, unicode_literals
 
 import functools
-import io
 import json
-import os
-import pickle
 import re
 import time
-import urlparse
 from base64 import urlsafe_b64decode
 from collections import OrderedDict
 from datetime import datetime
 from operator import itemgetter
+from urllib.parse import urljoin
 
+import requests
 from requests import RequestException
 from simplejson import JSONDecodeError
 from six import text_type
@@ -53,11 +53,11 @@ def login_required(f):
         if not obj.jwt_token:
             obj.authenticate()
 
-        try:
-            return f(obj, *args, **kwargs)
-        except tvdb_unauthorized:
-            obj.authenticate()
-            return f(obj, *args, **kwargs)
+        for i in range(3):
+            try:
+                return f(obj, *args, **kwargs)
+            except tvdb_unauthorized:
+                obj.authenticate()
 
     return wrapper
 
@@ -138,13 +138,13 @@ class Show(dict):
             return dict.__getitem__(self.data, key)
 
         # Data wasn't found, raise appropriate error
-        if key and (isinstance(key, int) or key.isdigit()):
+        if isinstance(key, int) or key.isdigit():
             # Season number x was not found
             raise tvdb_seasonnotfound("Could not find season {}".format(repr(key)))
         else:
             # If it's not numeric, it must be an attribute name, which
             # doesn't exist, so attribute error.
-            raise tvdb_attributenotfound("Cannot find attribute {}".format(repr(key)))
+            raise tvdb_attributenotfound("Cannot find show attribute {}".format(repr(key)))
 
     def airedOn(self, date):
         ret = self.search(str(date), 'firstaired')
@@ -210,10 +210,10 @@ class Season(dict):
             # Non-numeric request is for season-data
             return dict.__getitem__(self.data, key)
 
-        if key and (isinstance(key, int) or key.isdigit()):
+        if isinstance(key, int) or key.isdigit():
             raise tvdb_episodenotfound("Could not find episode {}".format(repr(key)))
         else:
-            raise tvdb_attributenotfound("Cannot find attribute {}".format(repr(key)))
+            raise tvdb_attributenotfound("Cannot find season attribute {}".format(repr(key)))
 
     def search(self, term=None, key=None):
         """Search all episodes in season, returns a list of matching Episode
@@ -250,7 +250,7 @@ class Episode(dict):
         try:
             return dict.__getitem__(self, key)
         except KeyError:
-            raise tvdb_attributenotfound("Cannot find attribute {}".format(repr(key)))
+            raise tvdb_attributenotfound("Cannot find episode attribute {}".format(repr(key)))
 
     def search(self, term=None, key=None):
         """Search episode data for term, if it matches, return the Episode (self).
@@ -267,7 +267,7 @@ class Episode(dict):
             if isinstance(cur_value, dict) or key is None or cur_value is None:
                 continue
 
-            cur_key, cur_value = unicode(cur_key).lower(), unicode(cur_value).lower()
+            cur_key, cur_value = str(cur_key).lower(), str(cur_value).lower()
             if cur_key != key:
                 continue
             if cur_value.find(term.lower()) > -1:
@@ -296,12 +296,41 @@ class Actor(dict):
 
 class Tvdb:
     """Create easy-to-use interface to name of season/episode name
-    >>> t = Tvdb()
-    >>> t['Scrubs'][1][24]['episodename']
-    'My Last Day'
     """
 
-    def __init__(self,
+    def __init__(self):
+        self.config = {
+            'api': {
+                'version': '3.0.0',
+                'lang': 'en',
+                'base': "https://api.thetvdb.com",
+                'login': '/login',
+                'refresh': '/refresh_token',
+                'languages': '/languages',
+                'getSeries': "/search/series?name={name}",
+                'getSeriesIMDB': "/search/series?imdbId={id}",
+                'getSeriesZap2It': "/search/series?zap2itId={id}",
+                'series': "/series/{id}",
+                'episodes': "/series/{id}/episodes",
+                'episode_info': "/episodes/{id}",
+                'actors': "/series/{id}/actors",
+                'updated': "/updated/query?fromTime={time}",
+                'images': {
+                    'fanart': "/series/{id}/images/query?keyType=fanart&subKey=graphical",
+                    'banner': "/series/{id}/images/query?keyType=fanart&subKey=text",
+                    'poster': "/series/{id}/images/query?keyType=poster",
+                    'series': "/series/{id}/images/query?keyType=series",
+                    'season': "/series/{id}/images/query?keyType=season&subKey={season}",
+                    'seasonwide': "/series/{id}/images/query?keyType=seasonwide&subKey={season}",
+                    'params': "/series/{id}/images/query/params",
+                    'prefix': "https://www.thetvdb.com/banners/{value}"
+                }
+            }
+        }
+
+        self.shows = ShowCache()
+
+    def settings(self,
                  debug=False,
                  cache=True,
                  custom_ui=None,
@@ -311,52 +340,9 @@ class Tvdb:
                  proxy=None,
                  headers=None):
 
-        if headers is None:
-            headers = {}
-
-        self.shows = ShowCache()
-        if os.path.isfile(os.path.join(sickrage.app.data_dir, 'thetvdb.db')):
-            with io.open(os.path.join(sickrage.app.data_dir, 'thetvdb.db'), 'rb') as fp:
-                try:
-                    self.shows = ShowCache(pickle.load(fp))
-                except:
-                    pass
-
-        self.config = dict(apikey=apikey, debug_enabled=debug, custom_ui=custom_ui, cache_enabled=cache,
-                           dvdorder=dvdorder, proxy=proxy, api={}, headers=headers)
-
-        # api base url
-        self.config['api']['base'] = "https://api.thetvdb.com"
-
-        # api-v2 urls
-        self.config['api']['login'] = '/login'
-        self.config['api']['refresh'] = '/refresh_token'
-        self.config['api']['languages'] = '/languages'
-        self.config['api']['getSeries'] = "/search/series?name={name}"
-        self.config['api']['getSeriesIMDB'] = "/search/series?imdbId={id}"
-        self.config['api']['getSeriesZap2It'] = "/search/series?zap2itId={id}"
-        self.config['api']['series'] = "/series/{id}"
-        self.config['api']['episodes'] = "/series/{id}/episodes"
-        self.config['api']['episode_info'] = "/episodes/{id}"
-        self.config['api']['actors'] = "/series/{id}/actors"
-        self.config['api']['updated'] = "/updated/query?fromTime={time}"
-
-        self.config['api']['images'] = {}
-        self.config['api']['images']['fanart'] = "/series/{id}/images/query?keyType=fanart&subKey=graphical"
-        self.config['api']['images']['banner'] = "/series/{id}/images/query?keyType=fanart&subKey=text"
-        self.config['api']['images']['poster'] = "/series/{id}/images/query?keyType=poster"
-        self.config['api']['images']['series'] = "/series/{id}/images/query?keyType=series"
-        self.config['api']['images']['season'] = "/series/{id}/images/query?keyType=season&subKey={season}"
-        self.config['api']['images']['seasonwide'] = "/series/{id}/images/query?keyType=seasonwide&subKey={season}"
-        self.config['api']['images']['prefix'] = "http://thetvdb.com/banners/{value}"
-
-        # api-v2 language
-        self.config['api']['lang'] = 'en'
-
-        # language to translate into
-        self.config['language'] = language
-        if language not in self.languages:
-            self.config['language'] = None
+        self.config.update({'apikey': apikey, 'debug_enabled': debug, 'custom_ui': custom_ui, 'cache_enabled': cache,
+                            'dvdorder': dvdorder, 'proxy': proxy, 'headers': headers or {},
+                            'language': language if language in self.languages else None})
 
     @property
     def jwt_token(self):
@@ -366,10 +352,16 @@ class Tvdb:
     def jwt_token(self, value):
         if self.jwt_token != value:
             setattr(self, '_jwt_token', value)
+            self.jwt_payload = self.get_jwt_payload(self.jwt_token)
 
     @property
     def jwt_payload(self):
-        return getattr(self, '_jwt_payload', self.get_jwt_payload(self.token))
+        return getattr(self, '_jwt_payload', {})
+
+    @jwt_payload.setter
+    def jwt_payload(self, value):
+        if self.jwt_payload != value:
+            setattr(self, '_jwt_payload', value)
 
     @property
     def jwt_expiration(self):
@@ -384,7 +376,7 @@ class Tvdb:
         return self.jwt_expiration <= time.time()
 
     def logout(self):
-        self.token = None
+        self.jwt_token = None
 
     def _refresh(self):
         self.jwt_token = self._request('get', self.config['api']['refresh'])['token']
@@ -393,13 +385,14 @@ class Tvdb:
         self.jwt_token = self._request('post', self.config['api']['login'], json={'apikey': self.config['apikey']})['token']
 
     def authenticate(self):
-        try:
-            if not self.jwt_token or self.jwt_is_expired:
-                self._login()
-            elif self.jwt_time_remaining < 7200:
-                self._refresh()
-        except Exception as e:
-            self.logout()
+        for i in range(0, 3):
+            try:
+                if not self.jwt_token or self.jwt_is_expired:
+                    return self._login()
+                elif self.jwt_time_remaining < 7200:
+                    return self._refresh()
+            except Exception as e:
+                self.logout()
 
     def jwt_decode(self, data):
         # make sure data is binary
@@ -438,33 +431,40 @@ class Tvdb:
         finally:
             return result
 
-    def _request(self, method, url, lang=None, **kwargs):
+    def _request(self, method, url, lang=None, retries=3, **kwargs):
+        self.config['headers'].update({'Authorization': 'Bearer {}'.format(self.jwt_token)})
         self.config['headers'].update({'Content-type': 'application/json'})
-        self.config['headers']['Authorization'] = 'Bearer {}'.format(self.jwt_token)
         self.config['headers'].update({'Accept-Language': lang or self.config['language']})
+        self.config['headers'].update({'Accept': 'application/vnd.thetvdb.v{}'.format(self.config['api']['version'])})
 
-        # get response from theTVDB
-        try:
-            resp = WebSession(cache=self.config['cache_enabled']).request(
-                method, urlparse.urljoin(self.config['api']['base'], url), headers=self.config['headers'],
-                timeout=sickrage.app.config.indexer_timeout, **kwargs
-            )
-        except Exception as e:
-            raise tvdb_error(str(e))
-
-        # handle requests exceptions
-        try:
-            if resp.status_code == 401:
-                raise tvdb_unauthorized(resp.json()['Error'])
-            elif resp.status_code >= 400:
-                raise tvdb_error(resp.json()['Error'])
-        except JSONDecodeError:
+        error_message = None
+        for i in range(retries):
             try:
-                resp.raise_for_status()
-            except RequestException as e:
-                raise tvdb_error(str(e))
+                # get response from theTVDB
+                resp = WebSession(cache=self.config['cache_enabled']).request(
+                    method, urljoin(self.config['api']['base'], url), headers=self.config['headers'],
+                    timeout=sickrage.app.config.indexer_timeout, verify=False, **kwargs
+                )
 
-        return to_lowercase(resp.json())
+                resp.raise_for_status()
+
+                return to_lowercase(resp.json())
+            except requests.exceptions.HTTPError as e:
+                status_code = e.response.status_code
+                error_message = e.response.text
+
+                if 'application/json' in e.response.headers.get('content-type', ''):
+                    error_message = e.response.json().get('Error', error_message)
+
+                if status_code == 401:
+                    raise tvdb_unauthorized(error_message)
+                elif status_code == 504:
+                    error_message = "Unable to connect to TheTVDB"
+            except Exception as e:
+                error_message = "{!r}".format(e)
+
+        if error_message:
+            raise tvdb_error(error_message)
 
     def _setItem(self, sid, seas, ep, attrib, value):
         """Creates a new episode, creating Show(), Season() and
@@ -499,9 +499,6 @@ class Tvdb:
 
         self.shows[sid].data[key] = value
 
-        with io.open(os.path.join(sickrage.app.data_dir, 'thetvdb.db'), 'wb') as fp:
-            pickle.dump(self.shows, fp)
-
     def _cleanData(self, data):
         """Cleans up strings returned by TheTVDB.com
 
@@ -510,7 +507,7 @@ class Tvdb:
         - Trailing whitespace
         """
 
-        return data.replace("&amp;", "&").strip() if isinstance(data, basestring) else data
+        return data.replace("&amp;", "&").strip() if isinstance(data, str) else data
 
     @login_required
     def search(self, series):
@@ -557,19 +554,16 @@ class Tvdb:
 
         try:
             # get series info in english
-            series_info = self._request('get',
-                                        self.config['api']['series'].format(id=sid),
-                                        lang=self.config['api']['lang']
-                                        )['data']
+            series_info = self._request('get', self.config['api']['series'].format(id=sid), lang=self.config['api']['lang'])['data']
 
             # translate if required to provided language
             if not self.config['language'] == self.config['api']['lang']:
-                series_info.update((k, v) for k, v in self._request('get',
-                                                                    self.config['api']['series'].format(id=sid)
-                                                                    )['data'].iteritems() if v)
-        except Exception:
-            sickrage.app.log.debug("[{}]: Series result returned zero".format(sid))
-            raise tvdb_error("[{}]: Series result returned zero".format(sid))
+                series_info.update((k, v) for k, v in self._request('get', self.config['api']['series'].format(id=sid))['data'].items() if v)
+        except tvdb_unauthorized:
+            raise tvdb_unauthorized
+        except Exception as e:
+            sickrage.app.log.debug("[{}]: Series result returned zero, ERROR: {}".format(sid, e))
+            raise tvdb_error("[{}]: Series result returned zero, ERROR: {}".format(sid, e))
 
         # get series data
         for k, v in series_info.items():
@@ -586,29 +580,28 @@ class Tvdb:
         # Parse episode data
         sickrage.app.log.debug('Getting all episode data for {}'.format(sid))
 
-        p = 1
         episodes = []
-        while True:
-            try:
-                episode_info = self._request('get',
-                                             self.config['api']['episodes'].format(id=sid),
-                                             lang=self.config['api']['lang'],
-                                             params={'page': p}
-                                             )['data']
+        page = pages = 1
 
+        while True:
+            if page > pages:
+                break
+
+            episode_info = self._request('get', self.config['api']['episodes'].format(id=sid), lang=self.config['api']['lang'], params={'page': page})
+
+            pages = episode_info['links']['last']
+
+            try:
                 # translate if required to provided language
                 if not self.config['language'] == self.config['api']['lang']:
-                    intl_episode_info = self._request('get',
-                                                      self.config['api']['episodes'].format(id=sid),
-                                                      params={'page': p})
+                    intl_episode_info = self._request('get', self.config['api']['episodes'].format(id=sid), params={'page': page})
+                    for d1, d2 in zip(episode_info['data'], intl_episode_info['data']):
+                        d1.update((k, v) for k, v in d2.items() if v)
+                        episodes.append(d1)
+                else:
+                    episodes += episode_info['data']
 
-                    for i, x in enumerate(episode_info):
-                        x.update((k, v) for k, v in intl_episode_info['data'][i].iteritems() if v)
-                        episode_info[i] = x
-
-                episodes += episode_info
-
-                p += 1
+                page += 1
             except tvdb_error:
                 break
 
@@ -616,6 +609,7 @@ class Tvdb:
             sickrage.app.log.debug('Series results incomplete')
             return
 
+        episode_incomplete = False
         for cur_ep in episodes:
             try:
                 use_dvd = False
@@ -630,7 +624,7 @@ class Tvdb:
                 if seasnum is None or epno is None:
                     raise Exception
             except Exception as e:
-                sickrage.app.log.warning("Episode has incomplete season/episode numbers, skipping!")
+                episode_incomplete = True
                 continue
 
             seas_no = int(float(seasnum))
@@ -647,34 +641,76 @@ class Tvdb:
                 self._setItem(sid, seas_no, ep_no, k, v)
 
             # add episode image url
-            image_url = self.config['api']['images']['prefix'].format(
-                value='episodes/{}/{}.jpg'.format(sid, cur_ep['id']))
+            image_url = self.config['api']['images']['prefix'].format(value='episodes/{}/{}.jpg'.format(sid, cur_ep['id']))
             self._setItem(sid, seas_no, ep_no, 'filename', image_url)
 
+        if episode_incomplete:
+            sickrage.app.log.debug("{}: Series has incomplete season/episode numbers".format(sid))
+
         # set last updated
         self._setShowData(sid, 'last_updated', int(time.mktime(datetime.now().timetuple())))
 
         return self.shows[int(sid)]
 
+    @login_required
+    def image_key_types(self, sid, season=None, language='en'):
+        key_types = {}
+
+        try:
+            data = self._request('get', self.config['api']['images']['params'].format(id=sid), language)['data']
+        except tvdb_error:
+            return key_types
+
+        for item in data:
+            key_type = item['keytype']
+            resolution = item['resolution']
+            subkey = item['subkey']
+
+            has_image = False
+            if season and "season" in key_type:
+                if season in subkey:
+                    has_image = True
+            elif key_type in ['fanart', 'series', 'poster']:
+                if 'graphical' in subkey or len(resolution):
+                    has_image = True
+
+            if language not in key_types:
+                key_types.update({
+                    key_type: has_image
+                })
+
+        return key_types
+
     @login_required
     def images(self, sid, key_type='poster', season=None):
         sickrage.app.log.debug('Getting {} images for {}'.format(key_type, sid))
 
-        try:
-            if not season:
-                images = self._request('get', self.config['api']['images'][key_type].format(id=sid),
-                                       self.config['api']['lang'])['data']
-            else:
-                images = self._request('get', self.config['api']['images'][key_type].format(id=sid, season=season),
-                                       self.config['api']['lang'])['data']
-        except tvdb_error:
+        images = []
+        for language in [self.config['api']['lang'], self.config['language']]:
+            try:
+                if not self.image_key_types(sid, season, language).get(key_type):
+                    continue
+
+                if not season:
+                    images = self._request('get', self.config['api']['images'][key_type].format(id=sid), language)['data']
+                else:
+                    images = self._request('get', self.config['api']['images'][key_type].format(id=sid, season=season), language)['data']
+            except tvdb_unauthorized:
+                raise tvdb_unauthorized
+            except tvdb_error:
+                continue
+
+        # unable to retrieve images in languages wanted
+        if not images:
             return []
 
         for i, image in enumerate(images):
-            if season and int(image['subkey']) != season: continue
+            if season and int(image['subkey']) != season:
+                continue
             image["score"] = image["ratingsinfo"]["average"] * image["ratingsinfo"]["count"]
             for k, v in image.items():
-                if not all([k, v]): continue
+                if not all([k, v]):
+                    continue
                 v = (v, self.config['api']['images']['prefix'].format(value=v))[k in ['filename', 'thumbnail']]
                 images[i][k] = v
 
@@ -695,6 +731,8 @@ class Tvdb:
                     curActor[k] = v
 
                 cur_actors.append(curActor)
+        except tvdb_unauthorized:
+            raise tvdb_unauthorized
         except Exception:
             sickrage.app.log.debug('Actors result returned zero')
 
@@ -713,12 +751,11 @@ class Tvdb:
         # return {l['abbreviation']: l['id'] for l in self._request('get', self.config['api']['languages'])}
 
     def __getitem__(self, key):
-        if isinstance(key, (int, long)):
+        if isinstance(key, int):
             if key in self.shows:
                 if self.config['cache_enabled']:
                     return self.shows[key]
-                else:
-                    del self.shows[key]
+                del self.shows[key]
             return self._getShowData(key)
         return self._getSeries(key)
 
