@@ -18,9 +18,7 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-import rtorrentlib.compat
 import rtorrentlib.file
-# from rtorrent.rpc import Method
 import rtorrentlib.peer
 import rtorrentlib.rpc
 import rtorrentlib.tracker
@@ -138,7 +136,7 @@ class Torrent:
         results = m.call()[0]  # only sent one call, only need first result
 
         offset_method_index = retriever_methods.index(
-            rtorrentlib.rpc.find_method("f.get_offset"))
+            rtorrentlib.rpc.find_method("f.offset"))
 
         # make a list of the offsets of all the files, sort appropriately
         offset_list = sorted([r[offset_method_index] for r in results])
@@ -303,7 +301,7 @@ class Torrent:
         m = rtorrentlib.rpc.Multicall(self)
 
         field = "custom{0}".format(key)
-        self.multicall_add(m, "d.get_{0}".format(field))
+        self.multicall_add(m, "d.{0}".format(field))
         setattr(self, field, m.call()[-1])
 
         return (getattr(self, field))
@@ -325,7 +323,7 @@ class Torrent:
         self._assert_custom_key_valid(key)
         m = rtorrentlib.rpc.Multicall(self)
 
-        self.multicall_add(m, "d.set_custom{0}".format(key), value)
+        self.multicall_add(m, "d.custom{0}.set".format(key), value)
 
         return(m.call()[-1])
 
@@ -354,7 +352,7 @@ class Torrent:
 
         @note: Variable where the result for this method is stored Torrent.hash_checking_queued"""
         m = rtorrentlib.rpc.Multicall(self)
-        self.multicall_add(m, "d.get_hashing")
+        self.multicall_add(m, "d.hashing")
         self.multicall_add(m, "d.is_hash_checking")
         results = m.call()
 
@@ -396,86 +394,86 @@ methods = [
     Method(Torrent, 'is_hash_checking', 'd.is_hash_checking',
            boolean=True,
            ),
-    Method(Torrent, 'get_peers_max', 'd.get_peers_max'),
-    Method(Torrent, 'get_tracker_focus', 'd.get_tracker_focus'),
-    Method(Torrent, 'get_skip_total', 'd.get_skip_total'),
-    Method(Torrent, 'get_state', 'd.get_state'),
-    Method(Torrent, 'get_peer_exchange', 'd.get_peer_exchange'),
-    Method(Torrent, 'get_down_rate', 'd.get_down_rate'),
-    Method(Torrent, 'get_connection_seed', 'd.get_connection_seed'),
-    Method(Torrent, 'get_uploads_max', 'd.get_uploads_max'),
-    Method(Torrent, 'get_priority_str', 'd.get_priority_str'),
+    Method(Torrent, 'get_peers_max', 'd.peers_max'),
+    Method(Torrent, 'get_tracker_focus', 'd.tracker_focus'),
+    Method(Torrent, 'get_skip_total', 'd.skip_total'),
+    Method(Torrent, 'get_state', 'd.state'),
+    Method(Torrent, 'get_peer_exchange', 'd.peer_exchange'),
+    Method(Torrent, 'get_down_rate', 'd.down_rate'),
+    Method(Torrent, 'get_connection_seed', 'd.connection_seed'),
+    Method(Torrent, 'get_uploads_max', 'd.uploads_max'),
+    Method(Torrent, 'get_priority_str', 'd.priority_str'),
     Method(Torrent, 'is_open', 'd.is_open',
            boolean=True,
            ),
-    Method(Torrent, 'get_peers_min', 'd.get_peers_min'),
-    Method(Torrent, 'get_peers_complete', 'd.get_peers_complete'),
-    Method(Torrent, 'get_tracker_numwant', 'd.get_tracker_numwant'),
-    Method(Torrent, 'get_connection_current', 'd.get_connection_current'),
-    Method(Torrent, 'is_complete', 'd.get_complete',
+    Method(Torrent, 'get_peers_min', 'd.peers_min'),
+    Method(Torrent, 'get_peers_complete', 'd.peers_complete'),
+    Method(Torrent, 'get_tracker_numwant', 'd.tracker_numwant'),
+    Method(Torrent, 'get_connection_current', 'd.connection_current'),
+    Method(Torrent, 'is_complete', 'd.complete',
            boolean=True,
            ),
-    Method(Torrent, 'get_peers_connected', 'd.get_peers_connected'),
-    Method(Torrent, 'get_chunk_size', 'd.get_chunk_size'),
-    Method(Torrent, 'get_state_counter', 'd.get_state_counter'),
-    Method(Torrent, 'get_base_filename', 'd.get_base_filename'),
-    Method(Torrent, 'get_state_changed', 'd.get_state_changed'),
-    Method(Torrent, 'get_peers_not_connected', 'd.get_peers_not_connected'),
-    Method(Torrent, 'get_directory', 'd.get_directory'),
+    Method(Torrent, 'get_peers_connected', 'd.peers_connected'),
+    Method(Torrent, 'get_chunk_size', 'd.chunk_size'),
+    Method(Torrent, 'get_state_counter', 'd.state_counter'),
+    Method(Torrent, 'get_base_filename', 'd.base_filename'),
+    Method(Torrent, 'get_state_changed', 'd.state_changed'),
+    Method(Torrent, 'get_peers_not_connected', 'd.peers_not_connected'),
+    Method(Torrent, 'get_directory', 'd.directory'),
     Method(Torrent, 'is_incomplete', 'd.incomplete',
            boolean=True,
            ),
-    Method(Torrent, 'get_tracker_size', 'd.get_tracker_size'),
+    Method(Torrent, 'get_tracker_size', 'd.tracker_size'),
     Method(Torrent, 'is_multi_file', 'd.is_multi_file',
            boolean=True,
            ),
-    Method(Torrent, 'get_local_id', 'd.get_local_id'),
-    Method(Torrent, 'get_ratio', 'd.get_ratio',
+    Method(Torrent, 'get_local_id', 'd.local_id'),
+    Method(Torrent, 'get_ratio', 'd.ratio',
            post_process_func=lambda x: x / 1000.0,
            ),
-    Method(Torrent, 'get_loaded_file', 'd.get_loaded_file'),
-    Method(Torrent, 'get_max_file_size', 'd.get_max_file_size'),
-    Method(Torrent, 'get_size_chunks', 'd.get_size_chunks'),
+    Method(Torrent, 'get_loaded_file', 'd.loaded_file'),
+    Method(Torrent, 'get_max_file_size', 'd.max_file_size'),
+    Method(Torrent, 'get_size_chunks', 'd.size_chunks'),
     Method(Torrent, 'is_pex_active', 'd.is_pex_active',
            boolean=True,
            ),
-    Method(Torrent, 'get_hashing', 'd.get_hashing'),
-    Method(Torrent, 'get_bitfield', 'd.get_bitfield'),
-    Method(Torrent, 'get_local_id_html', 'd.get_local_id_html'),
-    Method(Torrent, 'get_connection_leech', 'd.get_connection_leech'),
-    Method(Torrent, 'get_peers_accounted', 'd.get_peers_accounted'),
-    Method(Torrent, 'get_message', 'd.get_message'),
+    Method(Torrent, 'get_hashing', 'd.hashing'),
+    Method(Torrent, 'get_bitfield', 'd.bitfield'),
+    Method(Torrent, 'get_local_id_html', 'd.local_id_html'),
+    Method(Torrent, 'get_connection_leech', 'd.connection_leech'),
+    Method(Torrent, 'get_peers_accounted', 'd.peers_accounted'),
+    Method(Torrent, 'get_message', 'd.message'),
     Method(Torrent, 'is_active', 'd.is_active',
            boolean=True,
            ),
-    Method(Torrent, 'get_size_bytes', 'd.get_size_bytes'),
-    Method(Torrent, 'get_ignore_commands', 'd.get_ignore_commands'),
-    Method(Torrent, 'get_creation_date', 'd.get_creation_date'),
-    Method(Torrent, 'get_base_path', 'd.get_base_path'),
-    Method(Torrent, 'get_left_bytes', 'd.get_left_bytes'),
-    Method(Torrent, 'get_size_files', 'd.get_size_files'),
-    Method(Torrent, 'get_size_pex', 'd.get_size_pex'),
+    Method(Torrent, 'get_size_bytes', 'd.size_bytes'),
+    Method(Torrent, 'get_ignore_commands', 'd.ignore_commands'),
+    Method(Torrent, 'get_creation_date', 'd.creation_date'),
+    Method(Torrent, 'get_base_path', 'd.base_path'),
+    Method(Torrent, 'get_left_bytes', 'd.left_bytes'),
+    Method(Torrent, 'get_size_files', 'd.size_files'),
+    Method(Torrent, 'get_size_pex', 'd.size_pex'),
     Method(Torrent, 'is_private', 'd.is_private',
            boolean=True,
            ),
-    Method(Torrent, 'get_max_size_pex', 'd.get_max_size_pex'),
-    Method(Torrent, 'get_num_chunks_hashed', 'd.get_chunks_hashed',
+    Method(Torrent, 'get_max_size_pex', 'd.max_size_pex'),
+    Method(Torrent, 'get_num_chunks_hashed', 'd.chunks_hashed',
            aliases=("get_chunks_hashed",)),
     Method(Torrent, 'get_num_chunks_wanted', 'd.wanted_chunks'),
-    Method(Torrent, 'get_priority', 'd.get_priority'),
-    Method(Torrent, 'get_skip_rate', 'd.get_skip_rate'),
-    Method(Torrent, 'get_completed_bytes', 'd.get_completed_bytes'),
-    Method(Torrent, 'get_name', 'd.get_name'),
-    Method(Torrent, 'get_completed_chunks', 'd.get_completed_chunks'),
-    Method(Torrent, 'get_throttle_name', 'd.get_throttle_name'),
-    Method(Torrent, 'get_free_diskspace', 'd.get_free_diskspace'),
-    Method(Torrent, 'get_directory_base', 'd.get_directory_base'),
-    Method(Torrent, 'get_hashing_failed', 'd.get_hashing_failed'),
-    Method(Torrent, 'get_tied_to_file', 'd.get_tied_to_file'),
-    Method(Torrent, 'get_down_total', 'd.get_down_total'),
-    Method(Torrent, 'get_bytes_done', 'd.get_bytes_done'),
-    Method(Torrent, 'get_up_rate', 'd.get_up_rate'),
-    Method(Torrent, 'get_up_total', 'd.get_up_total'),
+    Method(Torrent, 'get_priority', 'd.priority'),
+    Method(Torrent, 'get_skip_rate', 'd.skip_rate'),
+    Method(Torrent, 'get_completed_bytes', 'd.completed_bytes'),
+    Method(Torrent, 'get_name', 'd.name'),
+    Method(Torrent, 'get_completed_chunks', 'd.completed_chunks'),
+    Method(Torrent, 'get_throttle_name', 'd.throttle_name'),
+    Method(Torrent, 'get_free_diskspace', 'd.free_diskspace'),
+    Method(Torrent, 'get_directory_base', 'd.directory_base'),
+    Method(Torrent, 'get_hashing_failed', 'd.hashing_failed'),
+    Method(Torrent, 'get_tied_to_file', 'd.tied_to_file'),
+    Method(Torrent, 'get_down_total', 'd.down_total'),
+    Method(Torrent, 'get_bytes_done', 'd.bytes_done'),
+    Method(Torrent, 'get_up_rate', 'd.up_rate'),
+    Method(Torrent, 'get_up_total', 'd.up_total'),
     Method(Torrent, 'is_accepting_seeders', 'd.accepting_seeders',
            boolean=True,
            ),
@@ -489,11 +487,11 @@ methods = [
            boolean=True,
            ),
     Method(Torrent, "get_time_started", "d.timestamp.started"),
-    Method(Torrent, "get_custom1", "d.get_custom1"),
-    Method(Torrent, "get_custom2", "d.get_custom2"),
-    Method(Torrent, "get_custom3", "d.get_custom3"),
-    Method(Torrent, "get_custom4", "d.get_custom4"),
-    Method(Torrent, "get_custom5", "d.get_custom5"),
+    Method(Torrent, "get_custom1", "d.custom1"),
+    Method(Torrent, "get_custom2", "d.custom2"),
+    Method(Torrent, "get_custom3", "d.custom3"),
+    Method(Torrent, "get_custom4", "d.custom4"),
+    Method(Torrent, "get_custom5", "d.custom5"),
 
     # MODIFIERS
     Method(Torrent, 'set_uploads_max', 'd.set_uploads_max'),
