@@ -2,8 +2,6 @@ from __future__ import absolute_import, division, print_function
 
 import os
 
-from six.moves import xrange
-
 PACKAGE_DIR = os.path.dirname(__file__)
 
 
@@ -41,7 +39,7 @@ def write_version(command):
     lines = contents.split('\n')
 
     # Update version attribute
-    for x in xrange(len(lines)):
+    for x in range(len(lines)):
         line = lines[x]
 
         if line.startswith('__version__ ='):
