@@ -1,22 +1,25 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+
 
-from __future__ import print_function, unicode_literals, with_statement
 
 import datetime
 import re
@@ -27,7 +30,6 @@ from decimal import Decimal
 from functools import partial
 
 import requests
-import six
 from dateutil.parser import parse as parse_date
 from lxml import etree
 from requests.compat import urljoin, urlparse
@@ -467,7 +469,7 @@ class Action(object):
         # Marshall the response to python data types
         out = {}
         for name, statevar in self.argsdef_out:
-            _, value = marshal_value(statevar['datatype'], soap_response[name])
+            __, value = marshal_value(statevar['datatype'], soap_response[name])
             out[name] = value
 
         return out
@@ -503,11 +505,11 @@ class Action(object):
                     assert Decimal('4.94065645841247E-324') <= v <= Decimal('1.79769313486232E308')
 
             elif datatype == 'char':
-                v = arg.decode('utf8') if six.PY2 or isinstance(arg, bytes) else arg
+                v = arg.decode('utf8') if isinstance(arg, bytes) else arg
                 assert len(v) == 1
 
             elif datatype == 'string':
-                v = arg.decode("utf8") if six.PY2 or isinstance(arg, bytes) else arg
+                v = arg.decode("utf8") if isinstance(arg, bytes) else arg
                 if argdef['allowed_values'] and v not in argdef['allowed_values']:
                     reasons.add('Value %r not in allowed values list' % arg)
 
