@@ -1,27 +1,30 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+
 
-from __future__ import unicode_literals
 
 import os
 
-from kodi_12plus import KODI_12PlusMetadata
-from sickrage.core.helpers import replaceExtension
+from sickrage.core.helpers import replace_extension
+from sickrage.metadata.kodi_12plus import KODI_12PlusMetadata
 
 
 class KODIMetadata(KODI_12PlusMetadata):
@@ -83,7 +86,7 @@ class KODIMetadata(KODI_12PlusMetadata):
         self.eg_season_all_banner = "<i>not supported</i>"
 
     # Override with empty methods for unsupported features
-    def create_season_banners(self, ep_obj):
+    def create_season_banners(self, show_obj, force=False):
         pass
 
     def create_season_all_banner(self, show_obj, force=False):
@@ -98,7 +101,7 @@ class KODIMetadata(KODI_12PlusMetadata):
         ep_obj: a TVEpisode instance for which to create the thumbnail
         """
         if os.path.isfile(ep_obj.location):
-            tbn_filename = replaceExtension(ep_obj.location, 'tbn')
+            tbn_filename = replace_extension(ep_obj.location, 'tbn')
         else:
             return None
 
