@@ -1,30 +1,32 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+
 
-from __future__ import unicode_literals
 
 import datetime
-import io
 import os
 
 import sickrage
 from sickrage.core.exceptions import ShowNotFoundException
-from sickrage.core.helpers import chmodAsParent
+from sickrage.core.helpers import chmod_as_parent
 from sickrage.indexers import IndexerApi
 from sickrage.indexers.exceptions import indexer_episodenotfound, \
     indexer_error, indexer_seasonnotfound, indexer_shownotfound
@@ -84,7 +86,7 @@ class TIVOMetadata(GenericMetadata):
         self.eg_season_all_banner = "<i>not supported</i>"
 
     # Override with empty methods for unsupported features
-    def retrieveShowMetadata(self, folder):
+    def retrieve_show_metadata(self, folder) ->(int, str, int):
         # no show metadata generated, we abort this lookup function
         return None, None, None
 
@@ -163,7 +165,7 @@ class TIVOMetadata(GenericMetadata):
 
         data = ""
 
-        eps_to_write = [ep_obj] + ep_obj.relatedEps
+        eps_to_write = [ep_obj] + ep_obj.related_episodes
 
         indexer_lang = ep_obj.show.lang or sickrage.app.config.indexer_default_language
 
@@ -176,7 +178,7 @@ class TIVOMetadata(GenericMetadata):
                 lINDEXER_API_PARMS['dvdorder'] = True
 
             t = IndexerApi(ep_obj.show.indexer).indexer(**lINDEXER_API_PARMS)
-            myShow = t[ep_obj.show.indexerid]
+            myShow = t[ep_obj.show.indexer_id]
         except indexer_shownotfound as e:
             raise ShowNotFoundException(str(e))
         except indexer_error as e:
@@ -185,7 +187,6 @@ class TIVOMetadata(GenericMetadata):
             return False
 
         for curEpToWrite in eps_to_write:
-
             try:
                 myEp = myShow[curEpToWrite.season][curEpToWrite.episode]
             except (indexer_episodenotfound, indexer_seasonnotfound):
@@ -195,7 +196,7 @@ class TIVOMetadata(GenericMetadata):
                 return None
 
             if ep_obj.season == 0 and not getattr(myEp, 'firstaired', None):
-                myEp["firstaired"] = str(datetime.date.fromordinal(1))
+                myEp["firstaired"] = str(datetime.date.min)
 
             if not (getattr(myEp, 'episodename', None) and getattr(myEp, 'firstaired', None)):
                 return None
@@ -246,11 +247,11 @@ class TIVOMetadata(GenericMetadata):
             # This must be entered as yyyy-mm-ddThh:mm:ssZ (the t is capitalized and never changes, the Z is also
             # capitalized and never changes). This is the original air date of the episode.
             # NOTE: Hard coded the time to T00:00:00Z as we really don't know when during the day the first run happened.
-            if curEpToWrite.airdate != datetime.date.fromordinal(1):
+            if curEpToWrite.airdate > datetime.date.min:
                 data += ("originalAirDate : " + str(curEpToWrite.airdate) + "T00:00:00Z\n")
 
             # This shows up at the beginning of the description on the Program screen and on the Details screen.
-            for actor in t.actors(int(ep_obj.show.indexerid)):
+            for actor in t.actors(int(ep_obj.show.indexer_id)):
                 if 'name' in actor and actor['name'].strip():
                     data += ("vActor : " + actor['name'].strip() + "\n")
 
@@ -312,18 +313,18 @@ class TIVOMetadata(GenericMetadata):
             if not os.path.isdir(nfo_file_dir):
                 sickrage.app.log.debug("Metadata dir didn't exist, creating it at " + nfo_file_dir)
                 os.makedirs(nfo_file_dir)
-                chmodAsParent(nfo_file_dir)
+                chmod_as_parent(nfo_file_dir)
 
             sickrage.app.log.debug("Writing episode nfo file to " + nfo_file_path)
 
-            with io.open(nfo_file_path, 'w') as nfo_file:
+            with open(nfo_file_path, 'w') as nfo_file:
                 # Calling encode directly, b/c often descriptions have wonky characters.
-                nfo_file.write(data.encode("utf-8"))
+                nfo_file.write(data)
 
-            chmodAsParent(nfo_file_path)
+            chmod_as_parent(nfo_file_path)
 
         except EnvironmentError as e:
-            sickrage.app.log.error(
+            sickrage.app.log.warning(
                 "Unable to write file to " + nfo_file_path + " - are you sure the folder is writable? {}".format(e))
             return False
 
