@@ -1,25 +1,29 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import importlib
+import inspect
 import os
+import pkgutil
 import re
 
 import sickrage
@@ -99,26 +103,9 @@ class Notifiers(object):
 class NotifierProviders(dict):
     def __init__(self):
         super(NotifierProviders, self).__init__()
-
-        pregex = re.compile('^(.*)\.py$', re.IGNORECASE)
-        names = [pregex.match(m) for m in os.listdir(os.path.dirname(__file__))]
-
-        for name in names:
-            try:
-                klass = self._get_klass(name.group(1))
+        for (__, name, __) in pkgutil.iter_modules([os.path.dirname(__file__)]):
+            imported_module = importlib.import_module('.' + name, package='sickrage.notifiers')
+            for __, klass in inspect.getmembers(imported_module,
+                                                predicate=lambda o: inspect.isclass(o) and issubclass(o, Notifiers) and o is not Notifiers):
                 self[klass().id] = klass()
-            except:
-                continue
-
-    @staticmethod
-    def _get_klass(name):
-        import inspect
-
-        try:
-            return dict(
-                inspect.getmembers(
-                    importlib.import_module('.{}'.format(name), 'sickrage.notifiers'),
-                    predicate=lambda o: inspect.isclass(o) and issubclass(o, Notifiers) and o is not Notifiers)
-            ).values()[0]
-        except:
-            pass
\ No newline at end of file
+                break
