@@ -1,27 +1,30 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+from urllib.parse import urlencode
 
-from __future__ import unicode_literals
-
-import urllib
-import urllib2
+import requests
+from requests import RequestException
 
 import sickrage
+from sickrage.core.websession import WebSession
 from sickrage.notifiers import Notifiers
 
 API_URL = "https://new.boxcar.io/api/notifications"
@@ -46,42 +49,37 @@ class Boxcar2Notifier(Notifiers):
         returns: True if the message succeeded, False otherwise
         """
 
-        # build up the URL and parameters
-        # more info goes here - https://boxcar.uservoice.com/knowledgebase/articles/306788-how-to-send-your-boxcar-account-a-notification
+        # build up the URL and parameters more info goes here -
+        # https://boxcar.uservoice.com/knowledgebase/articles/306788-how-to-send-your-boxcar-account-a-notification
         msg = msg.strip()
-        curUrl = API_URL
 
-        data = urllib.urlencode({
+        data = urlencode({
             'user_credentials': accesstoken,
             'notification[title]': "SiCKRAGE : " + title + ' : ' + msg,
             'notification[long_message]': msg,
             'notification[sound]': "notifier-2"
         })
 
-        # send the request to boxcar2
         try:
-            req = urllib2.Request(curUrl)
-            handle = urllib2.urlopen(req, data, timeout=60)
-            handle.close()
-
-        except urllib2.HTTPError as e:
+            # send the request to boxcar2
+            WebSession().get(API_URL, data=data, timeout=120)
+        except requests.exceptions.HTTPError as e:
             # if we get an error back that doesn't have an error code then who knows what's really happening
-            if not hasattr(e, 'code'):
-                sickrage.app.log.error("Boxcar2 notification failed.{}".format(e))
-                return False
-            else:
-                sickrage.app.log.warning("Boxcar2 notification failed. Error code: " + str(e.code))
+            sickrage.app.log.warning("Boxcar2 notification failed. Error code: {}".format(e.response.status_code))
 
             # HTTP status 404
-            if e.code == 404:
+            if e.response.status_code == 404:
                 sickrage.app.log.warning("Access token is invalid. Check it.")
                 return False
 
             # If you receive an HTTP status code of 400, it is because you failed to send the proper parameters
-            elif e.code == 400:
-                sickrage.app.log.error("Wrong data send to boxcar2")
+            elif e.response.status_code == 400:
+                sickrage.app.log.warning("Wrong data send to boxcar2")
                 return False
 
+            sickrage.app.log.error("Boxcar2 notification failed.")
+            return False
+
         sickrage.app.log.debug("Boxcar2 notification successful.")
         return True
 
