@@ -1,27 +1,25 @@
 # Author: echel0n <echel0n@sickrage.ca>
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import json
 
 import requests
-import six
 
 import sickrage
 from sickrage.notifiers import Notifiers
@@ -68,16 +66,13 @@ class DiscordNotifier(Notifiers):
         sickrage.app.log.info("Sending discord message: " + message)
         sickrage.app.log.info("Sending discord message  to url: " + discord_webhook)
 
-        if isinstance(message, six.text_type):
-            message = message.encode('utf-8')
-
         headers = {"Content-Type": "application/json"}
+
         try:
-            r = requests.post(discord_webhook, data=json.dumps(dict(content=message,
-                                                                    username=discord_name,
-                                                                    avatar_url=avatar_icon,
-                                                                    tts=discord_tts)), headers=headers)
-            r.raise_for_status()
+            requests.post(discord_webhook, data=json.dumps(dict(content=message,
+                                                                username=discord_name,
+                                                                avatar_url=avatar_icon,
+                                                                tts=discord_tts)), headers=headers)
         except Exception as e:
             sickrage.app.log.warning("Unable to send Discord message: {}".format(e))
             return False
