@@ -1,28 +1,30 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import json
-import urllib
-import urllib2
+from urllib.parse import urlencode
 
 import sickrage
+from sickrage.core.websession import WebSession
 from sickrage.notifiers import Notifiers
 
 
@@ -67,22 +69,21 @@ class EMBYNotifier(Notifiers):
         values = {'Name': 'SiCKRAGE', 'Description': message,
                   'ImageUrl': 'https://www.sickrage.ca/favicon.ico'}
         data = json.dumps(values)
+
+        headers = {
+            'X-MediaBrowser-Token': emby_apikey,
+            'Content-Type': 'application/json'
+        }
+
         try:
-            req = urllib2.Request(url, data)
-            req.add_header('X-MediaBrowser-Token', emby_apikey)
-            req.add_header('Content-Type', 'application/json')
-
-            response = urllib2.urlopen(req)
-            result = response.read()
-            response.close()
-
-            sickrage.app.log.debug('EMBY: HTTP response: ' + result.replace('\n', ''))
-            return True
-
-        except (urllib2.URLError, IOError) as e:
-            sickrage.app.log.warning('EMBY: Warning: Couldn\'t contact Emby at ' + url + ' ' + e)
+            resp = WebSession().get(url, data=data, headers=headers)
+            sickrage.app.log.debug('EMBY: HTTP response: {}'.format(resp.text.replace('\n', '')))
+        except Exception as e:
+            sickrage.app.log.warning('EMBY: Warning: Couldn\'t contact Emby at {}: {}'.format(url, e))
             return False
 
+        return True
+
     def test_notify(self, host, emby_apikey):
         return self._notify_emby('This is a test notification from SiCKRAGE', host, emby_apikey)
 
@@ -111,24 +112,24 @@ class EMBYNotifier(Notifiers):
                 else:
                     sickrage.app.log.warning('EMBY: Provider unknown')
                     return False
-                query = '?%sid=%s' % (provider, show.indexerid)
+                query = '?%sid=%s' % (provider, show.indexer_id)
             else:
                 query = ''
 
             url = 'http://%s/emby/Library/Series/Updated%s' % (sickrage.app.config.emby_host, query)
             values = {}
-            data = urllib.urlencode(values)
+            data = urlencode(values)
+
+            headers = {
+                'X-MediaBrowser-Token': sickrage.app.config.emby_apikey,
+                'Content-Type': 'application/json'
+            }
+
             try:
-                req = urllib2.Request(url, data)
-                req.add_header('X-MediaBrowser-Token', sickrage.app.config.emby_apikey)
-
-                response = urllib2.urlopen(req)
-                result = response.read()
-                response.close()
-
-                sickrage.app.log.debug('EMBY: HTTP response: ' + result.replace('\n', ''))
-                return True
-
-            except (urllib2.URLError, IOError) as e:
-                sickrage.app.log.warning('EMBY: Warning: Couldn\'t contact Emby at ' + url + ' ' + e)
+                resp = WebSession().get(url, data=data, headers=headers)
+                sickrage.app.log.debug('EMBY: HTTP response: ' + resp.text.replace('\n', ''))
+            except Exception as e:
+                sickrage.app.log.warning('EMBY: Warning: Couldn\'t contact Emby at {}: {}'.format(url, e))
                 return False
+
+            return True
