@@ -1,33 +1,36 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import base64
-import httplib
 import json
 import socket
 import time
-import urllib
-import urllib2
+import uuid
+from urllib import parse
+from urllib.parse import unquote_plus, urlencode, unquote
 from xml.etree import ElementTree
 
 import sickrage
+from sickrage.core.websession import WebSession
 from sickrage.notifiers import Notifiers
 
 
@@ -69,13 +72,13 @@ class KODINotifier(Notifiers):
         # override socket timeout to reduce delay for this call alone
         socket.setdefaulttimeout(10)
 
-        checkCommand = '{"jsonrpc":"2.0","method":"JSONRPC.Version","id":1}'
+        checkCommand = {"jsonrpc": "2.0", "method": "JSONRPC.Version", "id": uuid.uuid4().hex}
         result = self._send_to_kodi_json(checkCommand, host, username, password)
 
         # revert back to default socket timeout
         socket.setdefaulttimeout(sickrage.app.config.socket_timeout)
 
-        if not result:
+        if not result or result is False or 'error' in result:
             # fallback to legacy HTTPAPI method
             testCommand = {'command': 'Help'}
             request = self._send_to_kodi(testCommand, host, username, password)
@@ -85,7 +88,7 @@ class KODINotifier(Notifiers):
             else:
                 return False
 
-        return result["result"]["version"]
+        return result["result"]["version"]["major"]
 
     def _notify_kodi(self, message, title="SiCKRAGE", host=None, username=None, password=None, force=False):
         """Internal wrapper for the notify_snatch and notify_download functions
@@ -128,22 +131,24 @@ class KODINotifier(Notifiers):
                 if kodiapi <= 4:
                     sickrage.app.log.debug("Detected KODI version <= 11, using KODI HTTP API")
                     command = {'command': 'ExecBuiltIn',
-                               'parameter': 'Notification(' + title.encode("utf-8") + ',' + message.encode(
-                                   "utf-8") + ')'}
+                               'parameter': 'Notification({},{})'.format(title.encode("utf-8"), message.encode("utf-8"))}
                     notifyResult = self._send_to_kodi(command, curHost, username, password)
                     if notifyResult:
                         result += curHost + ':' + str(notifyResult)
                 else:
                     sickrage.app.log.debug("Detected KODI version >= 12, using KODI JSON API")
-                    command = '{"jsonrpc":"2.0","method":"GUI.ShowNotification","params":{"title":"%s","message":"%s", "image": "%s"},"id":1}' % (
-                        title.encode("utf-8"), message.encode("utf-8"), self.sr_logo_url)
+
+                    command = {"jsonrpc": "2.0",
+                               "method": "GUI.ShowNotification",
+                               "params": {"title": title, "message": message, "image": self.sr_logo_url},
+                               "id": uuid.uuid4().hex}
+
                     notifyResult = self._send_to_kodi_json(command, curHost, username, password)
                     if notifyResult and notifyResult.get('result'):
-                        result += curHost + ':' + notifyResult["result"].decode(sickrage.app.sys_encoding)
+                        result += curHost + ':' + notifyResult["result"]
             else:
                 if sickrage.app.config.kodi_always_on or force:
-                    sickrage.app.log.warning(
-                        "Failed to detect KODI version for '" + curHost + "', check configuration and try again.")
+                    sickrage.app.log.warning("Failed to detect KODI version for '" + curHost + "', check configuration and try again.")
                 result += curHost + ':False'
 
         return result
@@ -215,41 +220,30 @@ class KODINotifier(Notifiers):
             sickrage.app.log.warning('No KODI host passed, aborting update')
             return False
 
-        for key in command:
-            if isinstance(command[key], unicode):
-                command[key] = command[key].encode('utf-8')
-
-        enc_command = urllib.urlencode(command)
+        enc_command = urlencode(command)
         sickrage.app.log.debug("KODI encoded API command: " + enc_command)
 
         url = 'http://%s/kodiCmds/kodiHttp/?%s' % (host, enc_command)
+
+        headers = {}
+
+        # if we have a password, use authentication
+        if password:
+            authheader = "Basic {}".format(base64.b64encode(bytes('{}:{}'.format(username, password).replace('\n', ''), 'utf-8')).decode('ascii'))
+            headers["Authorization"] = authheader
+            sickrage.app.log.debug("Contacting KODI (with auth header) via url: " + url)
+        else:
+            sickrage.app.log.debug("Contacting KODI via url: " + url)
+
         try:
-            req = urllib2.Request(url)
-            # if we have a password, use authentication
-            if password:
-                base64string = base64.encodestring('%s:%s' % (username, password))[:-1]
-                authheader = "Basic %s" % base64string
-                req.add_header("Authorization", authheader)
-                sickrage.app.log.debug("Contacting KODI (with auth header) via url: " + url)
-            else:
-                sickrage.app.log.debug("Contacting KODI via url: " + url)
-
-            try:
-                response = urllib2.urlopen(req)
-            except (httplib.BadStatusLine, urllib2.URLError) as e:
-                sickrage.app.log.debug("Couldn't contact KODI HTTP at %r : %r" % (url, e))
-                return False
-
-            result = response.read().decode(sickrage.app.sys_encoding)
-            response.close()
-
-            sickrage.app.log.debug("KODI HTTP response: " + result.replace('\n', ''))
-            return result
-
+            result = WebSession().get(url, headers=headers).text
         except Exception as e:
             sickrage.app.log.debug("Couldn't contact KODI HTTP at %r : %r" % (url, e))
             return False
 
+        sickrage.app.log.debug("KODI HTTP response: " + result.replace('\n', ''))
+        return result
+
     def _update_library(self, host=None, showName=None):
         """Handles updating KODI host via HTTP API
 
@@ -299,7 +293,7 @@ class KODINotifier(Notifiers):
                 sickrage.app.log.debug("Invalid response for " + showName + " on " + host)
                 return False
 
-            encSqlXML = urllib.quote(sqlXML, ':\\/<>')
+            encSqlXML = parse.quote(sqlXML, ':\\/<>')
             try:
                 et = ElementTree.fromstring(encSqlXML)
             except SyntaxError as e:
@@ -314,7 +308,7 @@ class KODINotifier(Notifiers):
 
             for path in paths:
                 # we do not need it double-encoded, gawd this is dumb
-                unEncPath = urllib.unquote(path.text).decode(sickrage.app.sys_encoding)
+                unEncPath = unquote(path.text)
                 sickrage.app.log.debug("KODI Updating " + showName + " on " + host + " at " + unEncPath)
                 updateCommand = {'command': 'ExecBuiltIn', 'parameter': 'KODI.updatelibrary(video, %s)' % (unEncPath)}
                 request = self._send_to_kodi(updateCommand, host)
@@ -365,45 +359,29 @@ class KODINotifier(Notifiers):
             sickrage.app.log.warning('No KODI host passed, aborting update')
             return False
 
-        command = command.encode('utf-8')
-        sickrage.app.log.debug("KODI JSON command: " + command)
+        sickrage.app.log.debug("KODI JSON command: {!r}".format(command))
+
+        url = 'http://%s/jsonrpc' % host
+
+        headers = {"Content-type": "application/json"}
+
+        # if we have a password, use authentication
+        if password:
+            authheader = "Basic {}".format(base64.b64encode(bytes('{}:{}'.format(username, password).replace('\n', ''), 'utf-8')).decode('ascii'))
+            headers["Authorization"] = authheader
+            sickrage.app.log.debug("Contacting KODI (with auth header) via url: " + url)
+        else:
+            sickrage.app.log.debug("Contacting KODI via url: " + url)
 
-        url = 'http://%s/jsonrpc' % (host)
         try:
-            req = urllib2.Request(url, command)
-            req.add_header("Content-type", "application/json")
-            # if we have a password, use authentication
-            if password:
-                base64string = base64.encodestring('%s:%s' % (username, password))[:-1]
-                authheader = "Basic %s" % base64string
-                req.add_header("Authorization", authheader)
-                sickrage.app.log.debug("Contacting KODI (with auth header) via url: " + url)
-            else:
-                sickrage.app.log.debug("Contacting KODI via url: " + url)
-
-            try:
-                response = urllib2.urlopen(req)
-            except (httplib.BadStatusLine, urllib2.URLError) as e:
-                if sickrage.app.config.kodi_always_on:
-                    sickrage.app.log.warning(
-                        "Error while trying to retrieve KODI API version for " + host + ": {}".format(e))
-                return False
-
-            # parse the json result
-            try:
-                result = json.load(response)
-                response.close()
-                sickrage.app.log.debug("KODI JSON response: " + str(result))
-                return result  # need to return response for parsing
-            except ValueError as e:
-                sickrage.app.log.warning("Unable to decode JSON: " + str(response.read()))
-                return False
-
-        except IOError as e:
+            result = WebSession().post(url, json=command, headers=headers).json()
+            sickrage.app.log.debug("KODI JSON response: " + str(result))
+            return result
+        except Exception as e:
             if sickrage.app.config.kodi_always_on:
-                sickrage.app.log.warning(
-                    "Warning: Couldn't contact KODI JSON API at " + url + " {}".format(e))
-            return False
+                sickrage.app.log.warning("Warning: Couldn't contact KODI JSON API at " + url + " {}".format(e))
+
+        return False
 
     def _update_library_json(self, host=None, showName=None):
         """Handles updating KODI host via HTTP JSON-RPC
@@ -428,23 +406,25 @@ class KODINotifier(Notifiers):
 
         # if we're doing per-show
         if showName:
-            showName = urllib.unquote_plus(showName)
+            showName = unquote_plus(showName)
             tvshowid = -1
             path = ''
 
             sickrage.app.log.debug("Updating library in KODI via JSON method for show " + showName)
 
             # let's try letting kodi filter the shows
-            showsCommand = '{"jsonrpc":"2.0","method":"VideoLibrary.GetTVShows","params":{"filter":{"field":"title","operator":"is","value":"%s"},"properties":["title"]},"id":"SiCKRAGE"}'
+            showsCommand = {"jsonrpc": "2.0", "method": "VideoLibrary.GetTVShows",
+                            "params": {"filter": {"field": "title", "operator": "is", "value": showName}, "properties": ["title"]},
+                            "id": uuid.uuid4().hex}
 
             # get tvshowid by showName
-            showsResponse = self._send_to_kodi_json(showsCommand % showName, host)
+            showsResponse = self._send_to_kodi_json(showsCommand, host)
 
             if showsResponse and "result" in showsResponse and "tvshows" in showsResponse["result"]:
                 shows = showsResponse["result"]["tvshows"]
             else:
                 # fall back to retrieving the entire show list
-                showsCommand = '{"jsonrpc":"2.0","method":"VideoLibrary.GetTVShows","id":1}'
+                showsCommand = {"jsonrpc": "2.0", "method": "VideoLibrary.GetTVShows", "id": uuid.uuid4().hex}
                 showsResponse = self._send_to_kodi_json(showsCommand, host)
 
                 if showsResponse and "result" in showsResponse and "tvshows" in showsResponse["result"]:
@@ -472,8 +452,11 @@ class KODINotifier(Notifiers):
 
             # lookup tv-show path if we don't already know it
             if not len(path):
-                pathCommand = '{"jsonrpc":"2.0","method":"VideoLibrary.GetTVShowDetails","params":{"tvshowid":%d, "properties": ["file"]},"id":1}' % (
-                    tvshowid)
+                pathCommand = {"jsonrpc": "2.0",
+                               "method": "VideoLibrary.GetTVShowDetails",
+                               "params": {"tvshowid": tvshowid, "properties": ["file"]},
+                               "id": uuid.uuid4().hex}
+
                 pathResponse = self._send_to_kodi_json(pathCommand, host)
 
                 path = pathResponse["result"]["tvshowdetails"]["file"]
@@ -482,30 +465,26 @@ class KODINotifier(Notifiers):
                 "Received Show: " + showName + " with ID: " + str(tvshowid) + " Path: " + path)
 
             if not len(path):
-                sickrage.app.log.warning(
-                    "No valid path found for " + showName + " with ID: " + str(tvshowid) + " on " + host)
+                sickrage.app.log.warning("No valid path found for " + showName + " with ID: " + str(tvshowid) + " on " + host)
                 return False
 
             sickrage.app.log.debug("KODI Updating " + showName + " on " + host + " at " + path)
-            updateCommand = '{"jsonrpc":"2.0","method":"VideoLibrary.Scan","params":{"directory":%s},"id":1}' % (
-                json.dumps(path))
+            updateCommand = {"jsonrpc": "2.0", "method": "VideoLibrary.Scan", "params": {"directory": path}, "id": uuid.uuid4().hex}
             request = self._send_to_kodi_json(updateCommand, host)
-            if not request:
-                sickrage.app.log.warning(
-                    "Update of show directory failed on " + showName + " on " + host + " at " + path)
+            if request is False:
+                sickrage.app.log.warning("Update of show directory failed on " + showName + " on " + host + " at " + path)
                 return False
 
             # catch if there was an error in the returned request
             for r in request:
                 if 'error' in r:
-                    sickrage.app.log.warning(
-                        "Error while attempting to update show directory for " + showName + " on " + host + " at " + path)
+                    sickrage.app.log.warning("Error while attempting to update show directory for " + showName + " on " + host + " at " + path)
                     return False
 
         # do a full update if requested
         else:
             sickrage.app.log.debug("Doing Full Library KODI update on host: " + host)
-            updateCommand = '{"jsonrpc":"2.0","method":"VideoLibrary.Scan","id":1}'
+            updateCommand = {"jsonrpc": "2.0", "method": "VideoLibrary.Scan", "id": uuid.uuid4().hex}
             request = self._send_to_kodi_json(updateCommand, host)
 
             if not request:
@@ -537,8 +516,7 @@ class KODINotifier(Notifiers):
             self._notify_kodi(update_text + new_version, title)
 
     def test_notify(self, host, username, password):
-        return self._notify_kodi("Testing KODI notifications from SiCKRAGE", "Test Notification", host, username,
-                                 password, force=True)
+        return self._notify_kodi("Testing KODI notifications from SiCKRAGE", "Test Notification", host, username, password, force=True)
 
     def update_library(self, showName=None):
         """Public wrapper for the update library functions to branch the logic for JSON-RPC or legacy HTTP API
@@ -566,13 +544,11 @@ class KODINotifier(Notifiers):
             for host in [x.strip() for x in sickrage.app.config.kodi_host.split(",")]:
                 if self._send_update_library(host, showName):
                     if sickrage.app.config.kodi_update_onlyfirst:
-                        sickrage.app.log.debug(
-                            "Successfully updated '" + host + "', stopped sending update library commands.")
+                        sickrage.app.log.debug("Successfully updated '" + host + "', stopped sending update library commands.")
                         return True
                 else:
                     if sickrage.app.config.kodi_always_on:
-                        sickrage.app.log.warning(
-                            "Failed to detect KODI version for '" + host + "', check configuration and try again.")
+                        sickrage.app.log.warning("Failed to detect KODI version for '" + host + "', check configuration and try again.")
                     result += 1
 
             # needed for the 'update kodi' submenu command
