@@ -1,30 +1,31 @@
 # Author: Nico Berlee http://nico.berlee.nl/
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
 import telnetlib
-import urllib
-import urllib2
+from urllib.parse import urlencode
 from xml.etree import ElementTree
 
+import requests
+
 import sickrage
+from sickrage.core.websession import WebSession
 from sickrage.notifiers import Notifiers
 
 
@@ -44,6 +45,7 @@ class NMJNotifier(Notifiers):
 
         # establish a terminal session to the PC
         terminal = False
+
         try:
             terminal = telnetlib.Telnet(host)
         except Exception:
@@ -70,7 +72,7 @@ class NMJNotifier(Notifiers):
             sickrage.app.config.nmj_database = database
         else:
             sickrage.app.log.warning(
-                "Could not get current NMJ database on %s, NMJ is probably not running!" % (host))
+                "Could not get current NMJ database on %s, NMJ is probably not running!" % host)
             return False
 
         # if the device is a remote host then try to parse the mounting URL and save it to the config
@@ -79,7 +81,7 @@ class NMJNotifier(Notifiers):
 
             if match:
                 mount = match.group().replace("127.0.0.1", host)
-                sickrage.app.log.debug("Found mounting url on the Popcorn Hour in configuration: %s" % (mount))
+                sickrage.app.log.debug("Found mounting url on the Popcorn Hour in configuration: %s" % mount)
                 sickrage.app.config.nmj_mount = mount
             else:
                 sickrage.app.log.warning(
@@ -120,19 +122,12 @@ class NMJNotifier(Notifiers):
 
         # if a mount URL is provided then attempt to open a handle to that URL
         if mount:
+            sickrage.app.log.debug("Try to mount network drive via url: %s" % mount)
+
             try:
-                req = urllib2.Request(mount)
-                sickrage.app.log.debug("Try to mount network drive via url: %s" % (mount))
-                handle = urllib2.urlopen(req)
-            except IOError as e:
-                if hasattr(e, 'reason'):
-                    sickrage.app.log.warning(
-                        "NMJ: Could not contact Popcorn Hour on host %s: %s" % (host, e.reason))
-                elif hasattr(e, 'code'):
-                    sickrage.app.log.warning("NMJ: Problem with Popcorn Hour on host %s: %s" % (host, e.code))
-                return False
-            except Exception as e:
-                sickrage.app.log.error("NMJ: Unknown exception: {}".format(e))
+                WebSession().get(mount)
+            except requests.exceptions.HTTPError as e:
+                sickrage.app.log.warning("NMJ: Problem with Popcorn Hour on host %s: %s" % (host, e.response.status_code))
                 return False
 
         # build up the request URL and parameters
@@ -143,29 +138,21 @@ class NMJNotifier(Notifiers):
             "arg2": "background",
             "arg3": ""
         }
-        params = urllib.urlencode(params)
+        params = urlencode(params)
         updateUrl = UPDATE_URL % {"host": host, "params": params}
 
         # send the request to the server
+        sickrage.app.log.debug("Sending NMJ scan update command via url: %s" % updateUrl)
+
         try:
-            req = urllib2.Request(updateUrl)
-            sickrage.app.log.debug("Sending NMJ scan update command via url: %s" % (updateUrl))
-            handle = urllib2.urlopen(req)
-            response = handle.read()
-        except IOError as e:
-            if hasattr(e, 'reason'):
-                sickrage.app.log.warning(
-                    "NMJ: Could not contact Popcorn Hour on host %s: %s" % (host, e.reason))
-            elif hasattr(e, 'code'):
-                sickrage.app.log.warning("NMJ: Problem with Popcorn Hour on host %s: %s" % (host, e.code))
-            return False
-        except Exception as e:
-            sickrage.app.log.error("NMJ: Unknown exception: {}".format(e))
+            resp = WebSession().get(updateUrl)
+        except requests.exceptions.HTTPError as e:
+            sickrage.app.log.warning("NMJ: Problem with Popcorn Hour on host %s: %s" % (host, e.response.status_code))
             return False
 
         # try to parse the resulting XML
         try:
-            et = ElementTree.fromstring(response)
+            et = ElementTree.fromstring(resp.text)
             result = et.findtext("returnValue")
         except SyntaxError as e:
             sickrage.app.log.error("Unable to parse XML returned from the Popcorn Hour: {}".format(e))
@@ -175,9 +162,9 @@ class NMJNotifier(Notifiers):
         if int(result) > 0:
             sickrage.app.log.error("Popcorn Hour returned an errorcode: {}".format(result))
             return False
-        else:
-            sickrage.app.log.info("NMJ started background scan")
-            return True
+
+        sickrage.app.log.info("NMJ started background scan")
+        return True
 
     def _notifyNMJ(self, host=None, database=None, mount=None, force=False):
         """
