@@ -2,29 +2,28 @@
 # URL: https://sickrage.ca
 # Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
-import socket
-from httplib import HTTPException, HTTPSConnection
-from ssl import SSLError
-from urllib import urlencode
+from urllib.parse import urlencode
+
+import requests
 
 import sickrage
+from sickrage.core.websession import WebSession
 from sickrage.notifiers import Notifiers
 
 
@@ -64,7 +63,6 @@ class PushalotNotifier(Notifiers):
                                message=update_text + new_version)
 
     def _sendPushalot(self, pushalot_authorizationtoken=None, event=None, message=None, force=False):
-
         if not sickrage.app.config.use_pushalot and not force:
             return False
 
@@ -72,29 +70,21 @@ class PushalotNotifier(Notifiers):
         sickrage.app.log.debug("Pushalot message: " + message)
         sickrage.app.log.debug("Pushalot api: " + pushalot_authorizationtoken)
 
-        http_handler = HTTPSConnection("pushalot.com")
-
         data = {'AuthorizationToken': pushalot_authorizationtoken,
-                'Title': event.encode('utf-8'),
-                'Body': message.encode('utf-8')}
+                'Title': event,
+                'Body': message}
 
         try:
-            http_handler.request("POST",
-                                 "/api/sendmessage",
-                                 headers={'Content-type': "application/x-www-form-urlencoded"},
-                                 body=urlencode(data))
-        except (SSLError, HTTPException, socket.error):
-            sickrage.app.log.error("Pushalot notification failed.")
-            return False
-        response = http_handler.getresponse()
-        request_status = response.status
+            WebSession().post("https://pushalot.com/api/sendmessage",
+                              headers={'Content-type': "application/x-www-form-urlencoded"},
+                              data=urlencode(data))
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 410:
+                sickrage.app.log.warning("Pushalot auth failed: %s" % e.response.text)
+                return False
 
-        if request_status == 200:
-            sickrage.app.log.debug("Pushalot notifications sent.")
-            return True
-        elif request_status == 410:
-            sickrage.app.log.error("Pushalot auth failed: %s" % response.reason)
-            return False
-        else:
             sickrage.app.log.error("Pushalot notification failed.")
             return False
+
+        sickrage.app.log.debug("Pushalot notifications sent.")
+        return True
