@@ -4,22 +4,21 @@
 #
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage. If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import sickrage
 from sickrage.core.caches.tv_cache import TVCache
@@ -35,9 +34,9 @@ class Anizb(NZBProvider):
         super(Anizb, self).__init__('Anizb', 'https://anizb.org', False)
 
         # URLs
-        self.urls.update({
-            'rss': '{base_url}/'.format(**self.urls),
-            'api': '{base_url}/api/?q='.format(**self.urls)
+        self._urls.update({
+            'rss': '{base_url}/'.format(**self._urls),
+            'api': '{base_url}/api/?q='.format(**self._urls)
         })
 
         # Miscellaneous Options
@@ -48,7 +47,7 @@ class Anizb(NZBProvider):
         # Cache
         self.cache = TVCache(self)
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         """Start searching for anime using the provided search_strings. Used for backlog and daily."""
         results = []
 
@@ -66,7 +65,7 @@ class Anizb(NZBProvider):
                         sickrage.app.log.debug('No data returned from provider')
                         continue
 
-                    if not response.text.startswith('<?xml'):
+                    if not response.startswith('<?xml'):
                         sickrage.app.log.info('Expected xml but got something else, is your mirror failing?')
                         continue
 
@@ -93,4 +92,4 @@ class Anizb(NZBProvider):
                                 sickrage.app.log.error('Failed parsing provider.')
                                 continue
 
-            return results
\ No newline at end of file
+            return results
