@@ -1,22 +1,24 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import datetime
 import re
@@ -30,8 +32,8 @@ class BinSearchProvider(NZBProvider):
         super(BinSearchProvider, self).__init__("BinSearch", 'http://www.binsearch.info', False)
         self.supports_backlog = False
 
-        self.urls.update({
-            'rss': '{base_url}/rss.php'.format(**self.urls)
+        self._urls.update({
+            'rss': '{base_url}/rss.php'.format(**self._urls)
         })
 
         self.cache = BinSearchCache(self)
@@ -89,7 +91,7 @@ class BinSearchCache(TVCache):
 
             for group in ['alt.binaries.hdtv', 'alt.binaries.hdtv.x264', 'alt.binaries.tv', 'alt.binaries.tvseries']:
                 search_params = {'max': 50, 'g': group}
-                for item in self.getRSSFeed(self.provider.urls['rss'], search_params).get('entries', []):
+                for item in self.get_rss_feed(self.provider.urls['rss'], search_params).get('entries', []):
                     self._parseItem(item)
 
         return True
