@@ -4,22 +4,21 @@
 #
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage. If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
 
@@ -47,10 +46,10 @@ class ArcheTorrentProvider(TorrentProvider):
         self.freeleech = False
 
         # URLs
-        self.urls.update({
-            'login': '{base_url}/account-login.php'.format(**self.urls),
-            'search': '{base_url}/torrents-search.php'.format(**self.urls),
-            'download': '{base_url}/download.php'.format(**self.urls),
+        self._urls.update({
+            'login': '{base_url}/account-login.php'.format(**self._urls),
+            'search': '{base_url}/torrents-search.php'.format(**self._urls),
+            'download': '{base_url}/download.php'.format(**self._urls),
         })
 
         # Proper Strings
@@ -82,7 +81,7 @@ class ArcheTorrentProvider(TorrentProvider):
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
