@@ -2,24 +2,21 @@
 #
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage. If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
-
-import re
 
 from requests.compat import urljoin
 from requests.utils import dict_from_cookiejar
@@ -32,7 +29,8 @@ from sickrage.providers import TorrentProvider
 
 class FileListProvider(TorrentProvider):
     def __init__(self):
-        super(FileListProvider, self).__init__('FileList', 'http://filelist.ro', True)
+        super(FileListProvider, self).__init__('FileList', 'https://filelist.ro', True)
+
         # Credentials
         self.username = None
         self.password = None
@@ -42,9 +40,9 @@ class FileListProvider(TorrentProvider):
         self.minleech = None
 
         # URLs
-        self.urls.update({
-            "login": "{base_url}/takelogin.php".format(**self.urls),
-            "search": "{base_url}/browse.php".format(**self.urls),
+        self._urls.update({
+            "login": "{base_url}/takelogin.php".format(**self._urls),
+            "search": "{base_url}/browse.php".format(**self._urls),
         })
 
         # Proper Strings
@@ -59,24 +57,25 @@ class FileListProvider(TorrentProvider):
 
         login_params = {
             "username": self.username,
-            "password": self.password
+            "password": self.password,
+            "ssl": 'yes'
         }
 
         try:
             response = self.session.post(self.urls["login"], data=login_params).text
         except Exception:
             sickrage.app.log.warning("Unable to connect to provider")
+            self.session.cookies.clear()
             return False
 
-        if re.search("Invalid Username/password", response) \
-                or re.search("<title>Login :: FileList.ro</title>", response) \
-                or re.search("Login esuat!", response):
+        if 'logout.php' not in response:
             sickrage.app.log.warning("Invalid username or password. Check your settings")
+            self.session.cookies.clear()
             return False
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
@@ -94,12 +93,10 @@ class FileListProvider(TorrentProvider):
             for search_string in search_strings[mode]:
                 if mode != "RSS":
                     sickrage.app.log.debug("Search string: {}".format(search_string))
-
-                search_params["search"] = search_string
-                search_url = self.urls["search"]
+                    search_params["search"] = search_string
 
                 try:
-                    data = self.session.get(search_url, params=search_params).text
+                    data = self.session.get(self.urls['search'], params=search_params).text
                     results += self.parse(data, mode)
                 except Exception:
                     sickrage.app.log.debug("No data returned from provider")
@@ -116,7 +113,7 @@ class FileListProvider(TorrentProvider):
 
         results = []
 
-        with bs4_parser(data, "html5lib") as html:
+        with bs4_parser(data) as html:
             torrent_rows = html.find_all("div", class_="torrentrow")
 
             # Continue only if at least one Release is found
@@ -164,9 +161,13 @@ class FileListProvider(TorrentProvider):
                     torrent_size = cells[labels.index("Size")].find("span").get_text(strip=True)
                     size = convert_size(torrent_size, -1)
 
-                    results += [
-                        {'title': title, 'link': download_url, 'size': size, 'seeders': seeders, 'leechers': leechers}
-                    ]
+                    results += [{
+                        'title': title,
+                        'link': download_url,
+                        'size': size,
+                        'seeders': seeders,
+                        'leechers': leechers
+                    }]
 
                     if mode != "RSS":
                         sickrage.app.log.debug("Found result: {}".format(title))
