@@ -3,25 +3,24 @@
 # Modified by 7ca for HDSpace
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
-import urllib
+from urllib.parse import quote_plus
 
 from requests.utils import dict_from_cookiejar
 
@@ -35,10 +34,10 @@ class HDSpaceProvider(TorrentProvider):
     def __init__(self):
         super(HDSpaceProvider, self).__init__("HDSpace", 'https://hd-space.org', True)
 
-        self.urls.update({
-            'login': '{base_url}/index.php?page=login'.format(**self.urls),
-            'search': '{base_url}/index.php?page=torrents&search=%s&active=1&options=0&category='.format(**self.urls),
-            'rss': '{base_url}/rss_torrents.php?feed=dl'.format(**self.urls)
+        self._urls.update({
+            'login': '{base_url}/index.php?page=login'.format(**self._urls),
+            'search': '{base_url}/index.php?page=torrents&search=%s&active=1&options=0&category='.format(**self._urls),
+            'rss': '{base_url}/rss_torrents.php?feed=dl'.format(**self._urls)
         })
 
         self.username = None
@@ -49,10 +48,10 @@ class HDSpaceProvider(TorrentProvider):
 
         self.categories = [15, 21, 22, 24, 25, 40]  # HDTV/DOC 1080/720, bluray, remux
         for cat in self.categories:
-            self.urls['search'] += str(cat) + '%%3B'
-            self.urls['rss'] += '&cat[]=' + str(cat)
+            self._urls['search'] += str(cat) + '%%3B'
+            self._urls['rss'] += '&cat[]=' + str(cat)
 
-        self.urls['search'] = self.urls['search'][:-4]  # remove extra %%3B
+        self._urls['search'] = self._urls['search'][:-4]  # remove extra %%3B
 
         self.cache = TVCache(self)
 
@@ -86,7 +85,7 @@ class HDSpaceProvider(TorrentProvider):
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
@@ -98,7 +97,7 @@ class HDSpaceProvider(TorrentProvider):
 
                 if mode != 'RSS':
                     sickrage.app.log.debug("Search string: %s" % search_string)
-                    searchURL = self.urls['search'] % (urllib.quote_plus(search_string.replace('.', ' ')),)
+                    searchURL = self.urls['search'] % (quote_plus(search_string.replace('.', ' ')),)
                 else:
                     searchURL = self.urls['search'] % ''
 
