@@ -2,25 +2,24 @@
 # Modified by jkaberg, https://github.com/jkaberg for SceneAccess
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
-from urlparse import urljoin
+from urllib.parse import urljoin
 
 from requests.utils import dict_from_cookiejar
 
@@ -34,9 +33,9 @@ class HDTorrentsProvider(TorrentProvider):
     def __init__(self):
         super(HDTorrentsProvider, self).__init__("HDTorrents", 'https://hd-torrents.org', True)
 
-        self.urls.update({
-            'login': '{base_url}/login.php'.format(**self.urls),
-            'search': '{base_url}/torrents.php'.format(**self.urls)
+        self._urls.update({
+            'login': '{base_url}/login.php'.format(**self._urls),
+            'search': '{base_url}/torrents.php'.format(**self._urls)
         })
 
         self.username = None
@@ -79,7 +78,7 @@ class HDTorrentsProvider(TorrentProvider):
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
