@@ -3,22 +3,21 @@
 #
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage. If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function, unicode_literals
 
 import re
 
@@ -46,10 +45,10 @@ class ImmortalseedProvider(TorrentProvider):
         self.freeleech = None
 
         # URLs
-        self.urls.update({
-            'login': '{base_url}/takelogin.php'.format(**self.urls),
-            'search': '{base_url}/browse.php'.format(**self.urls),
-            'rss': '{base_url}/rss.php'.format(**self.urls),
+        self._urls.update({
+            'login': '{base_url}/takelogin.php'.format(**self._urls),
+            'search': '{base_url}/browse.php'.format(**self._urls),
+            'rss': '{base_url}/rss.php'.format(**self._urls),
         })
 
         # Proper Strings
@@ -91,7 +90,7 @@ class ImmortalseedProvider(TorrentProvider):
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
         if not self.login():
             return results
@@ -152,12 +151,17 @@ class ImmortalseedProvider(TorrentProvider):
             # Skip column headers
             for result in torrent_rows[1:]:
                 try:
-                    title = result.find('div', class_='tooltip-target').get_text(strip=True)
+                    tooltip = result.find('div', class_='tooltip-target')
+                    if not tooltip:
+                        continue
+
+                    title = title.get_text(strip=True)
+
                     # skip if torrent has been nuked due to poor quality
                     if title.startswith('Nuked.'):
                         continue
-                    download_url = result.find(
-                        'img', title='Click to Download this Torrent in SSL!').parent['href']
+
+                    download_url = result.find('img', title='Click to Download this Torrent in SSL!').parent['href']
                     if not all([title, download_url]):
                         continue
 
@@ -189,7 +193,7 @@ class ImmortalseedCache(TVCache):
             'showrows': '50',
         }
 
-        return self.getRSSFeed(self.provider.urls['rss'], params=params)
+        return self.get_rss_feed(self.provider.urls['rss'], params=params)
 
     def _check_auth(self, data):
         return self.provider._check_auth_from_data(data)
