@@ -3,22 +3,21 @@
 #
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage. If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function, unicode_literals
 
 import re
 
@@ -32,10 +31,10 @@ class LimeTorrentsProvider(TorrentProvider):
     def __init__(self):
         super(LimeTorrentsProvider, self).__init__('LimeTorrents', 'https://www.limetorrents.cc', False)
 
-        self.urls.update({
-            'update': '{base_url}/post/updatestats.php'.format(**self.urls),
-            'search': '{base_url}/search/tv/%s/'.format(**self.urls),
-            'rss': '{base_url}/browse-torrents/TV-shows/'.format(**self.urls),
+        self._urls.update({
+            'update': '{base_url}/post/updatestats.php'.format(**self._urls),
+            'search': '{base_url}/search/tv/%s/'.format(**self._urls),
+            'rss': '{base_url}/browse-torrents/TV-shows/'.format(**self._urls),
         })
 
         self.minseed = None
@@ -46,7 +45,7 @@ class LimeTorrentsProvider(TorrentProvider):
 
         self.cache = TVCache(self)
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
         for mode in search_strings:
             sickrage.app.log.debug("Search Mode: {}".format(mode))
@@ -120,7 +119,7 @@ class LimeTorrentsProvider(TorrentProvider):
 
                     try:
                         self.session.get(self.urls['update'], timeout=30,
-                                                  params={'torrent_id': torrent_id, 'infohash': info_hash})
+                                         params={'torrent_id': torrent_id, 'infohash': info_hash})
                     except Exception:
                         pass
 
