@@ -1,25 +1,24 @@
 # Author: Seamus Wassman
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
-from urlparse import urljoin
+from urllib.parse import urljoin
 
 import requests
 
@@ -34,20 +33,20 @@ class MoreThanTVProvider(TorrentProvider):
     def __init__(self):
         super(MoreThanTVProvider, self).__init__("MoreThanTV", 'https://www.morethan.tv', True)
 
-        self.urls.update({
-            'login': '{base_url}/login.php'.format(**self.urls),
+        self._urls.update({
+            'login': '{base_url}/login.php'.format(**self._urls),
             'detail': '{base_url}/torrents.php'
-                      '?id=%s'.format(**self.urls),
+                      '?id=%s'.format(**self._urls),
             'search': '{base_url}/torrents.php'
                       '?tags_type=1'
                       '&order_by=time'
                       '&order_way=desc'
                       '&action=basic'
                       '&searchsubmit=1'
-                      '&searchstr=%s'.format(**self.urls),
+                      '&searchstr=%s'.format(**self._urls),
             'download': '{base_url}/torrents.php'
                         '?action=download'
-                        '&id=%s'.format(**self.urls)
+                        '&id=%s'.format(**self._urls)
         })
 
         self._uid = None
@@ -96,7 +95,7 @@ class MoreThanTVProvider(TorrentProvider):
                 sickrage.app.log.warning(
                     "Invalid username or password. Check your settings")
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
@@ -165,4 +164,4 @@ class MoreThanTVProvider(TorrentProvider):
                 except Exception:
                     sickrage.app.log.error("Failed parsing provider")
 
-        return results
\ No newline at end of file
+        return results
