@@ -1,22 +1,21 @@
 # coding=utf-8
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage. If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function, unicode_literals
 
 import re
 
@@ -46,11 +45,11 @@ class NcoreProvider(TorrentProvider):
 
         categories = '&'.join(['kivalasztott_tipus[]=' + x for x in categories])
 
-        self.urls.update({
-            'login': '{base_url}/login.php'.format(**self.urls),
+        self._urls.update({
+            'login': '{base_url}/login.php'.format(**self._urls),
             'search': ('{base_url}/torrents.php?{cats}&mire=%s&miben=name'
                        '&tipus=kivalasztottak_kozott&submit.x=0&submit.y=0&submit=Ok'
-                       '&tags=&searchedfrompotato=true&jsons=true').format(cats=categories, **self.urls),
+                       '&tags=&searchedfrompotato=true&jsons=true').format(cats=categories, **self._urls),
         })
 
         self.cache = TVCache(self)
@@ -77,7 +76,7 @@ class NcoreProvider(TorrentProvider):
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
@@ -142,4 +141,4 @@ class NcoreProvider(TorrentProvider):
             except Exception:
                 sickrage.app.log.error("Failed parsing provider")
 
-        return results
\ No newline at end of file
+        return results
