@@ -1,24 +1,27 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import datetime
+import uuid
 from time import sleep
 
 import sickrage
@@ -31,7 +34,7 @@ class RarbgProvider(TorrentProvider):
     def __init__(self):
         super(RarbgProvider, self).__init__("Rarbg", 'https://rarbg.com', False)
 
-        self.urls.update({
+        self._urls.update({
             'api': 'http://torrentapi.org/pubapi_v2.php'
         })
 
@@ -42,6 +45,8 @@ class RarbgProvider(TorrentProvider):
         self.token = None
         self.token_expires = None
 
+        self.app_id = 'sickrage-{}'.format(uuid.uuid1())
+
         self.proper_strings = ['{{PROPER|REPACK|REAL|RERIP}}']
 
         self.cache = TVCache(self)
@@ -53,12 +58,12 @@ class RarbgProvider(TorrentProvider):
         login_params = {
             'get_token': 'get_token',
             'format': 'json',
-            'app_id': 'sickrage',
+            'app_id': self.app_id,
         }
 
         try:
             response = self.session.get(self.urls['api'], params=login_params, random_ua=True).json()
-        except Exception:
+        except Exception as e:
             sickrage.app.log.warning("Unable to connect to provider")
             return False
 
@@ -71,7 +76,7 @@ class RarbgProvider(TorrentProvider):
 
         return self.token is not None
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         if not self.login():
@@ -79,7 +84,7 @@ class RarbgProvider(TorrentProvider):
 
         # Search Params
         search_params = {
-            'app_id': 'sickrage',
+            'app_id': self.app_id,
             'category': 'tv',
             'min_seeders': try_int(self.minseed),
             'min_leechers': try_int(self.minleech),
@@ -100,7 +105,7 @@ class RarbgProvider(TorrentProvider):
             else:
                 search_params['sort'] = self.sorting if self.sorting else 'seeders'
                 search_params['mode'] = 'search'
-                search_params['search_tvdb'] = ep_obj.show.indexerid
+                search_params['search_tvdb'] = show_id
 
             for search_string in search_strings[mode]:
                 if mode != 'RSS':
@@ -115,7 +120,7 @@ class RarbgProvider(TorrentProvider):
                     continue
 
                 # sleep 5 secs per request
-                sleep(5)
+                sleep(2)
 
                 try:
                     data = self.session.get(self.urls['api'], params=search_params, random_ua=True).json()
