@@ -1,22 +1,21 @@
 # Author: echel0n <echel0n@sickrage.ca>
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import sickrage
 from sickrage.core.caches.tv_cache import TVCache
@@ -28,8 +27,8 @@ class ShazbatProvider(TorrentProvider):
     def __init__(self):
         super(ShazbatProvider, self).__init__("Shazbat.tv", 'https://www.shazbat.tv', True)
 
-        self.urls.update({
-            'login': '{base_url}/login'.format(**self.urls)
+        self._urls.update({
+            'login': '{base_url}/login'.format(**self._urls)
         })
 
         self.supports_backlog = False
@@ -59,7 +58,7 @@ class ShazbatCache(TVCache):
         rss_url = self.provider.urls['base_url'] + '/rss/recent?passkey=' + self.provider.passkey + '&fname=true'
         sickrage.app.log.debug("Cache update URL: %s" % rss_url)
 
-        return self.getRSSFeed(rss_url)
+        return self.get_rss_feed(rss_url)
 
     def _check_auth(self, data):
         return self.provider._check_auth_from_data(data)
