@@ -1,22 +1,21 @@
 # Author: Mr_Orange
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
 
@@ -37,19 +36,16 @@ class TokyoToshokanProvider(TorrentProvider):
         self.minseed = None
         self.minleech = None
 
-        self.urls.update({
-            'search': '{base_url}/search.php'.format(**self.urls),
-            'rss': '{base_url}/rss.php'.format(**self.urls)
+        self._urls.update({
+            'search': '{base_url}/search.php'.format(**self._urls),
+            'rss': '{base_url}/rss.php'.format(**self._urls)
         })
 
         self.cache = TVCache(self, min_time=15)
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
-        if not ep_obj.show or not ep_obj.show.is_anime:
-            return results
-
         for mode in search_strings:
             sickrage.app.log.debug("Search Mode: {}".format(mode))
             for search_string in search_strings[mode]:
@@ -92,9 +88,12 @@ class TokyoToshokanProvider(TorrentProvider):
 
             for top, bot in zip(torrent_rows[a::2], torrent_rows[a + 1::2]):
                 try:
+                    title = download_url = ""
                     desc_top = top.find('td', class_='desc-top')
-                    title = desc_top.get_text(strip=True)
-                    download_url = desc_top.find('a')['href']
+                    if desc_top:
+                        title = desc_top.get_text(strip=True)
+                        download_url = desc_top.find('a')['href']
+
                     if not all([title, download_url]):
                         continue
 
@@ -115,4 +114,4 @@ class TokyoToshokanProvider(TorrentProvider):
                 except Exception:
                     sickrage.app.log.error("Failed parsing provider")
 
-        return results
\ No newline at end of file
+        return results
