@@ -1,28 +1,29 @@
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import re
 
 from requests.utils import dict_from_cookiejar
 
 import sickrage
+from sickrage.core import MainDB
 from sickrage.core.caches.tv_cache import TVCache
 from sickrage.core.exceptions import AuthException
-from sickrage.core.helpers import sanitizeSceneName, show_names, bs4_parser, try_int, convert_size
+from sickrage.core.helpers import sanitize_scene_name, show_names, bs4_parser, try_int, convert_size
+from sickrage.core.tv.show.helpers import find_show
 from sickrage.providers import TorrentProvider
 
 
@@ -30,10 +31,10 @@ class TVChaosUKProvider(TorrentProvider):
     def __init__(self):
         super(TVChaosUKProvider, self).__init__('TvChaosUK', 'https://www.tvchaosuk.com', True)
 
-        self.urls.update({
-            'login': '{base_url}/takelogin.php'.format(**self.urls),
-            'index': '{base_url}/index.php'.format(**self.urls),
-            'search': '{base_url}/browse.php'.format(**self.urls)
+        self._urls.update({
+            'login': '{base_url}/takelogin.php'.format(**self._urls),
+            'index': '{base_url}/index.php'.format(**self._urls),
+            'search': '{base_url}/browse.php'.format(**self._urls)
         })
 
         self.username = None
@@ -50,43 +51,46 @@ class TVChaosUKProvider(TorrentProvider):
 
         raise AuthException('Your authentication credentials for ' + self.name + ' are missing, check your config.')
 
-    def _get_season_search_strings(self, ep_obj):
+    def _get_season_search_strings(self, show_id, season, episode):
 
         search_string = {'Season': []}
 
-        for show_name in set(show_names.allPossibleShowNames(ep_obj.show)):
+        show_object = find_show(show_id)
+        episode_object = show_object.get_episode(season, episode)
+
+        for show_name in set(show_names.all_possible_show_names(show_id)):
             for sep in ' ', ' - ':
                 season_string = show_name + sep + 'Series '
-                if ep_obj.show.air_by_date or ep_obj.show.sports:
-                    season_string += str(ep_obj.airdate).split('-')[0]
-                elif ep_obj.show.anime:
-                    season_string += '%d' % ep_obj.scene_absolute_number
+                if show_object.air_by_date or show_object.sports:
+                    season_string += str(episode_object.airdate).split('-')[0]
+                elif show_object.anime:
+                    season_string += '%d' % episode_object.scene_absolute_number
                 else:
-                    season_string += '%d' % int(ep_obj.scene_season)
+                    season_string += '%d' % int(episode_object.scene_season)
 
                 search_string['Season'].append(re.sub(r'\s+', ' ', season_string.replace('.', ' ').strip()))
 
         return [search_string]
 
-    def _get_episode_search_strings(self, ep_obj, add_string=''):
+    def _get_episode_search_strings(self, show_id, season, episode, add_string=''):
 
         search_string = {'Episode': []}
 
-        if not ep_obj:
-            return []
+        show_object = find_show(show_id)
+        episode_object = show_object.get_episode(season, episode)
 
-        for show_name in set(show_names.allPossibleShowNames(ep_obj.show)):
+        for show_name in set(show_names.all_possible_show_names(show_id)):
             for sep in ' ', ' - ':
-                ep_string = sanitizeSceneName(show_name) + sep
-                if ep_obj.show.air_by_date:
-                    ep_string += str(ep_obj.airdate).replace('-', '|')
-                elif ep_obj.show.sports:
-                    ep_string += str(ep_obj.airdate).replace('-', '|') + '|' + ep_obj.airdate.strftime('%b')
-                elif ep_obj.show.anime:
-                    ep_string += '%i' % int(ep_obj.scene_absolute_number)
+                ep_string = sanitize_scene_name(show_name) + sep
+                if show_object.air_by_date:
+                    ep_string += str(episode_object.airdate).replace('-', '|')
+                elif show_object.sports:
+                    ep_string += str(episode_object.airdate).replace('-', '|') + '|' + episode_object.airdate.strftime('%b')
+                elif show_object.anime:
+                    ep_string += '%i' % int(episode_object.scene_absolute_number)
                 else:
-                    ep_string += sickrage.app.naming_ep_type[2] % {'seasonnumber': ep_obj.scene_season,
-                                                                   'episodenumber': ep_obj.scene_episode}
+                    ep_string += sickrage.app.naming_ep_type[2] % {'seasonnumber': episode_object.scene_season,
+                                                                   'episodenumber': episode_object.scene_episode}
 
                 if add_string:
                     ep_string += ' %s' % add_string
@@ -114,7 +118,7 @@ class TVChaosUKProvider(TorrentProvider):
 
         return True
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         search_params = {
