@@ -2,22 +2,21 @@
 # Author: adaur <adaur.underground@gmail.com>
 # URL: https://sickrage.ca
 #
-# This file is part of SickRage.
+# This file is part of SiCKRAGE.
 #
-# SickRage is free software: you can redistribute it and/or modify
+# SiCKRAGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# SickRage is distributed in the hope that it will be useful,
+# SiCKRAGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
 
 import sickrage
 from sickrage.core.caches.tv_cache import TVCache
@@ -29,7 +28,7 @@ class XthorProvider(TorrentProvider):
     def __init__(self):
         super(XthorProvider, self).__init__("Xthor", "https://xthor.to", True)
 
-        self.urls.update({
+        self._urls.update({
             'search': "https://api.xthor.to"
         })
 
@@ -53,7 +52,7 @@ class XthorProvider(TorrentProvider):
 
         return False
 
-    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
+    def search(self, search_strings, age=0, show_id=None, season=None, episode=None, **kwargs):
         results = []
 
         # check for auth
